Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3AdvancedSettingsSpeechSettings
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3AdvancedSettingsSpeechSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
Define behaviors of speech to text detection.
Instance Attribute Summary collapse
-
#endpointer_sensitivity ⇒ Fixnum
Sensitivity of the speech model that detects the end of speech.
-
#models ⇒ Hash<String,String>
Mapping from language to Speech-to-Text model.
-
#no_speech_timeout ⇒ String
Timeout before detecting no speech.
-
#use_timeout_based_endpointing ⇒ Boolean
(also: #use_timeout_based_endpointing?)
Use timeout based endpointing, interpreting endpointer sensitivity as seconds of timeout value.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3AdvancedSettingsSpeechSettings
constructor
A new instance of GoogleCloudDialogflowCxV3AdvancedSettingsSpeechSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3AdvancedSettingsSpeechSettings
Returns a new instance of GoogleCloudDialogflowCxV3AdvancedSettingsSpeechSettings.
241 242 243 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 241 def initialize(**args) update!(**args) end |
Instance Attribute Details
#endpointer_sensitivity ⇒ Fixnum
Sensitivity of the speech model that detects the end of speech. Scale from 0
to 100.
Corresponds to the JSON property endpointerSensitivity
219 220 221 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 219 def endpointer_sensitivity @endpointer_sensitivity end |
#models ⇒ Hash<String,String>
Mapping from language to Speech-to-Text model. The mapped Speech-to-Text model
will be selected for requests from its corresponding language. For more
information, see Speech models.
Corresponds to the JSON property models
227 228 229 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 227 def models @models end |
#no_speech_timeout ⇒ String
Timeout before detecting no speech.
Corresponds to the JSON property noSpeechTimeout
232 233 234 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 232 def no_speech_timeout @no_speech_timeout end |
#use_timeout_based_endpointing ⇒ Boolean Also known as: use_timeout_based_endpointing?
Use timeout based endpointing, interpreting endpointer sensitivity as seconds
of timeout value.
Corresponds to the JSON property useTimeoutBasedEndpointing
238 239 240 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 238 def use_timeout_based_endpointing @use_timeout_based_endpointing end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
246 247 248 249 250 251 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 246 def update!(**args) @endpointer_sensitivity = args[:endpointer_sensitivity] if args.key?(:endpointer_sensitivity) @models = args[:models] if args.key?(:models) @no_speech_timeout = args[:no_speech_timeout] if args.key?(:no_speech_timeout) @use_timeout_based_endpointing = args[:use_timeout_based_endpointing] if args.key?(:use_timeout_based_endpointing) end |