Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3AgentAnswerFeedbackSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

Settings for answer feedback collection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowCxV3AgentAnswerFeedbackSettings

Returns a new instance of GoogleCloudDialogflowCxV3AgentAnswerFeedbackSettings.



464
465
466
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 464

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enable_answer_feedbackBoolean Also known as: enable_answer_feedback?

Optional. If enabled, end users will be able to provide answer feedback to Dialogflow responses. Feature works only if interaction logging is enabled in the Dialogflow agent. Corresponds to the JSON property enableAnswerFeedback

Returns:

  • (Boolean)


461
462
463
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 461

def enable_answer_feedback
  @enable_answer_feedback
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



469
470
471
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 469

def update!(**args)
  @enable_answer_feedback = args[:enable_answer_feedback] if args.key?(:enable_answer_feedback)
end