Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3AgentClientCertificateSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

Settings for custom client certificates.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowCxV3AgentClientCertificateSettings

Returns a new instance of GoogleCloudDialogflowCxV3AgentClientCertificateSettings.



498
499
500
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 498

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#passphraseString

Optional. The name of the SecretManager secret version resource storing the passphrase. 'passphrase' should be left unset if the private key is not encrypted. Format: projects/project/secrets/secret/versions/version` Corresponds to the JSON propertypassphrase`

Returns:

  • (String)


483
484
485
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 483

def passphrase
  @passphrase
end

#private_keyString

Required. The name of the SecretManager secret version resource storing the private key encoded in PEM format. Format: projects/project/secrets/secret /versions/version` Corresponds to the JSON propertyprivateKey`

Returns:

  • (String)


490
491
492
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 490

def private_key
  @private_key
end

#ssl_certificateString

Required. The ssl certificate encoded in PEM format. This string must include the begin header and end footer lines. Corresponds to the JSON property sslCertificate

Returns:

  • (String)


496
497
498
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 496

def ssl_certificate
  @ssl_certificate
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



503
504
505
506
507
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 503

def update!(**args)
  @passphrase = args[:passphrase] if args.key?(:passphrase)
  @private_key = args[:private_key] if args.key?(:private_key)
  @ssl_certificate = args[:ssl_certificate] if args.key?(:ssl_certificate)
end