Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3CompareVersionsRequest
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3CompareVersionsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
The request message for Versions.CompareVersions.
Instance Attribute Summary collapse
-
#language_code ⇒ String
The language to compare the flow versions for.
-
#target_version ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3CompareVersionsRequest
constructor
A new instance of GoogleCloudDialogflowCxV3CompareVersionsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3CompareVersionsRequest
Returns a new instance of GoogleCloudDialogflowCxV3CompareVersionsRequest.
1195 1196 1197 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 1195 def initialize(**args) update!(**args) end |
Instance Attribute Details
#language_code ⇒ String
The language to compare the flow versions for. If not specified, the agent's
default language is used. Many languages are supported. Note: languages must be enabled in the
agent before they can be used.
Corresponds to the JSON property languageCode
1186 1187 1188 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 1186 def language_code @language_code end |
#target_version ⇒ String
Required. Name of the target flow version to compare with the base version.
Use version ID 0 to indicate the draft version of the specified flow. Format:
projects//locations//agents//flows//versions/.
Corresponds to the JSON property targetVersion
1193 1194 1195 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 1193 def target_version @target_version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1200 1201 1202 1203 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 1200 def update!(**args) @language_code = args[:language_code] if args.key?(:language_code) @target_version = args[:target_version] if args.key?(:target_version) end |