Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3ConversationSignals

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

This message is used to hold all the Conversation Signals data, which will be converted to JSON and exported to BigQuery.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowCxV3ConversationSignals

Returns a new instance of GoogleCloudDialogflowCxV3ConversationSignals.



1287
1288
1289
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 1287

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#turn_signalsGoogle::Apis::DialogflowV3::GoogleCloudDialogflowCxV3TurnSignals

Collection of all signals that were extracted for a single turn of the conversation. Corresponds to the JSON property turnSignals



1285
1286
1287
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 1285

def turn_signals
  @turn_signals
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1292
1293
1294
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 1292

def update!(**args)
  @turn_signals = args[:turn_signals] if args.key?(:turn_signals)
end