Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3ConversationTurnUserInput
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3ConversationTurnUserInput
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
The input from the human user.
Instance Attribute Summary collapse
-
#enable_sentiment_analysis ⇒ Boolean
(also: #enable_sentiment_analysis?)
Whether sentiment analysis is enabled.
-
#injected_parameters ⇒ Hash<String,Object>
Parameters that need to be injected into the conversation during intent detection.
-
#input ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3QueryInput
Represents the query input.
-
#is_webhook_enabled ⇒ Boolean
(also: #is_webhook_enabled?)
If webhooks should be allowed to trigger in response to the user utterance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3ConversationTurnUserInput
constructor
A new instance of GoogleCloudDialogflowCxV3ConversationTurnUserInput.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3ConversationTurnUserInput
Returns a new instance of GoogleCloudDialogflowCxV3ConversationTurnUserInput.
1355 1356 1357 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 1355 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enable_sentiment_analysis ⇒ Boolean Also known as: enable_sentiment_analysis?
Whether sentiment analysis is enabled.
Corresponds to the JSON property enableSentimentAnalysis
1330 1331 1332 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 1330 def enable_sentiment_analysis @enable_sentiment_analysis end |
#injected_parameters ⇒ Hash<String,Object>
Parameters that need to be injected into the conversation during intent
detection.
Corresponds to the JSON property injectedParameters
1337 1338 1339 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 1337 def injected_parameters @injected_parameters end |
#input ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3QueryInput
Represents the query input. It can contain one of: 1. A conversational query in the form of text. 2. An intent query that specifies which intent to trigger.
- Natural language speech audio to be processed. 4. An event to be triggered.
- DTMF digits to invoke an intent and fill in parameter value. 6. The
results of a tool executed by the client.
Corresponds to the JSON property
input
1346 1347 1348 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 1346 def input @input end |
#is_webhook_enabled ⇒ Boolean Also known as: is_webhook_enabled?
If webhooks should be allowed to trigger in response to the user utterance.
Often if parameters are injected, webhooks should not be enabled.
Corresponds to the JSON property isWebhookEnabled
1352 1353 1354 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 1352 def is_webhook_enabled @is_webhook_enabled end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1360 1361 1362 1363 1364 1365 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 1360 def update!(**args) @enable_sentiment_analysis = args[:enable_sentiment_analysis] if args.key?(:enable_sentiment_analysis) @injected_parameters = args[:injected_parameters] if args.key?(:injected_parameters) @input = args[:input] if args.key?(:input) @is_webhook_enabled = args[:is_webhook_enabled] if args.key?(:is_webhook_enabled) end |