Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3DataStoreConnectionSignals
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3DataStoreConnectionSignals
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
Data store connection feature output signals. Might be only partially field if processing stop before the final answer. Reasons for this can be, but are not limited to: empty UCS search results, positive RAI check outcome, grounding failure, ...
Instance Attribute Summary collapse
-
#answer ⇒ String
Optional.
-
#answer_generation_model_call_signals ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3DataStoreConnectionSignalsAnswerGenerationModelCallSignals
Diagnostic info related to the answer generation model call.
-
#answer_parts ⇒ Array<Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3DataStoreConnectionSignalsAnswerPart>
Optional.
-
#cited_snippets ⇒ Array<Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3DataStoreConnectionSignalsCitedSnippet>
Optional.
-
#grounding_signals ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3DataStoreConnectionSignalsGroundingSignals
Grounding signals.
-
#rewriter_model_call_signals ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3DataStoreConnectionSignalsRewriterModelCallSignals
Diagnostic info related to the rewriter model call.
-
#rewritten_query ⇒ String
Optional.
-
#safety_signals ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3DataStoreConnectionSignalsSafetySignals
Safety check results.
-
#search_snippets ⇒ Array<Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3DataStoreConnectionSignalsSearchSnippet>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3DataStoreConnectionSignals
constructor
A new instance of GoogleCloudDialogflowCxV3DataStoreConnectionSignals.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3DataStoreConnectionSignals
Returns a new instance of GoogleCloudDialogflowCxV3DataStoreConnectionSignals.
1554 1555 1556 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 1554 def initialize(**args) update!(**args) end |
Instance Attribute Details
#answer ⇒ String
Optional. The final compiled answer.
Corresponds to the JSON property answer
1510 1511 1512 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 1510 def answer @answer end |
#answer_generation_model_call_signals ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3DataStoreConnectionSignalsAnswerGenerationModelCallSignals
Diagnostic info related to the answer generation model call.
Corresponds to the JSON property answerGenerationModelCallSignals
1515 1516 1517 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 1515 def answer_generation_model_call_signals @answer_generation_model_call_signals end |
#answer_parts ⇒ Array<Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3DataStoreConnectionSignalsAnswerPart>
Optional. Answer parts with relevant citations. Concatenation of texts should
add up the answer (not counting whitespaces).
Corresponds to the JSON property answerParts
1521 1522 1523 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 1521 def answer_parts @answer_parts end |
#cited_snippets ⇒ Array<Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3DataStoreConnectionSignalsCitedSnippet>
Optional. Snippets cited by the answer generation model from the most to least
relevant.
Corresponds to the JSON property citedSnippets
1527 1528 1529 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 1527 def cited_snippets @cited_snippets end |
#grounding_signals ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3DataStoreConnectionSignalsGroundingSignals
Grounding signals.
Corresponds to the JSON property groundingSignals
1532 1533 1534 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 1532 def grounding_signals @grounding_signals end |
#rewriter_model_call_signals ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3DataStoreConnectionSignalsRewriterModelCallSignals
Diagnostic info related to the rewriter model call.
Corresponds to the JSON property rewriterModelCallSignals
1537 1538 1539 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 1537 def rewriter_model_call_signals @rewriter_model_call_signals end |
#rewritten_query ⇒ String
Optional. Rewritten string query used for search.
Corresponds to the JSON property rewrittenQuery
1542 1543 1544 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 1542 def rewritten_query @rewritten_query end |
#safety_signals ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3DataStoreConnectionSignalsSafetySignals
Safety check results.
Corresponds to the JSON property safetySignals
1547 1548 1549 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 1547 def safety_signals @safety_signals end |
#search_snippets ⇒ Array<Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3DataStoreConnectionSignalsSearchSnippet>
Optional. Search snippets included in the answer generation prompt.
Corresponds to the JSON property searchSnippets
1552 1553 1554 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 1552 def search_snippets @search_snippets end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1559 1560 1561 1562 1563 1564 1565 1566 1567 1568 1569 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 1559 def update!(**args) @answer = args[:answer] if args.key?(:answer) @answer_generation_model_call_signals = args[:answer_generation_model_call_signals] if args.key?(:answer_generation_model_call_signals) @answer_parts = args[:answer_parts] if args.key?(:answer_parts) @cited_snippets = args[:cited_snippets] if args.key?(:cited_snippets) @grounding_signals = args[:grounding_signals] if args.key?(:grounding_signals) @rewriter_model_call_signals = args[:rewriter_model_call_signals] if args.key?(:rewriter_model_call_signals) @rewritten_query = args[:rewritten_query] if args.key?(:rewritten_query) @safety_signals = args[:safety_signals] if args.key?(:safety_signals) @search_snippets = args[:search_snippets] if args.key?(:search_snippets) end |