Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3Deployment
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3Deployment
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
Represents a deployment in an environment. A deployment happens when a flow version configured to be active in the environment. You can configure running pre-deployment steps, e.g. running validation test cases, experiment auto- rollout, etc.
Instance Attribute Summary collapse
-
#end_time ⇒ String
End time of this deployment.
-
#flow_version ⇒ String
The name of the flow version for this deployment.
-
#name ⇒ String
The name of the deployment.
-
#result ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3DeploymentResult
Result of the deployment.
-
#start_time ⇒ String
Start time of this deployment.
-
#state ⇒ String
The current state of the deployment.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3Deployment
constructor
A new instance of GoogleCloudDialogflowCxV3Deployment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3Deployment
Returns a new instance of GoogleCloudDialogflowCxV3Deployment.
1889 1890 1891 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 1889 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_time ⇒ String
End time of this deployment.
Corresponds to the JSON property endTime
1860 1861 1862 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 1860 def end_time @end_time end |
#flow_version ⇒ String
The name of the flow version for this deployment. Format: projects//locations//
agents//flows//versions/.
Corresponds to the JSON property flowVersion
1866 1867 1868 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 1866 def flow_version @flow_version end |
#name ⇒ String
The name of the deployment. Format: projects//locations//agents//environments//
deployments/.
Corresponds to the JSON property name
1872 1873 1874 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 1872 def name @name end |
#result ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3DeploymentResult
Result of the deployment.
Corresponds to the JSON property result
1877 1878 1879 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 1877 def result @result end |
#start_time ⇒ String
Start time of this deployment.
Corresponds to the JSON property startTime
1882 1883 1884 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 1882 def start_time @start_time end |
#state ⇒ String
The current state of the deployment.
Corresponds to the JSON property state
1887 1888 1889 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 1887 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1894 1895 1896 1897 1898 1899 1900 1901 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 1894 def update!(**args) @end_time = args[:end_time] if args.key?(:end_time) @flow_version = args[:flow_version] if args.key?(:flow_version) @name = args[:name] if args.key?(:name) @result = args[:result] if args.key?(:result) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) end |