Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3DetectIntentRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

The request to detect user's intent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowCxV3DetectIntentRequest

Returns a new instance of GoogleCloudDialogflowCxV3DetectIntentRequest.



1960
1961
1962
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 1960

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#output_audio_configGoogle::Apis::DialogflowV3::GoogleCloudDialogflowCxV3OutputAudioConfig

Instructs the speech synthesizer how to generate the output audio content. Corresponds to the JSON property outputAudioConfig



1938
1939
1940
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 1938

def output_audio_config
  @output_audio_config
end

#query_inputGoogle::Apis::DialogflowV3::GoogleCloudDialogflowCxV3QueryInput

Represents the query input. It can contain one of: 1. A conversational query in the form of text. 2. An intent query that specifies which intent to trigger.

  1. Natural language speech audio to be processed. 4. An event to be triggered.
  2. DTMF digits to invoke an intent and fill in parameter value. 6. The results of a tool executed by the client. Corresponds to the JSON property queryInput


1947
1948
1949
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 1947

def query_input
  @query_input
end

#query_paramsGoogle::Apis::DialogflowV3::GoogleCloudDialogflowCxV3QueryParameters

Represents the parameters of a conversational query. Corresponds to the JSON property queryParams



1952
1953
1954
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 1952

def query_params
  @query_params
end

#response_viewString

Optional. Specifies which fields in the QueryResult to return. If not set, the default is DETECT_INTENT_RESPONSE_VIEW_FULL. Corresponds to the JSON property responseView

Returns:

  • (String)


1958
1959
1960
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 1958

def response_view
  @response_view
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1965
1966
1967
1968
1969
1970
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 1965

def update!(**args)
  @output_audio_config = args[:output_audio_config] if args.key?(:output_audio_config)
  @query_input = args[:query_input] if args.key?(:query_input)
  @query_params = args[:query_params] if args.key?(:query_params)
  @response_view = args[:response_view] if args.key?(:response_view)
end