Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3DetectIntentResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

The message returned from the DetectIntent method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowCxV3DetectIntentResponse

Returns a new instance of GoogleCloudDialogflowCxV3DetectIntentResponse.



2019
2020
2021
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 2019

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allow_cancellationBoolean Also known as: allow_cancellation?

Indicates whether the partial response can be cancelled when a later response arrives. e.g. if the agent specified some music as partial response, it can be cancelled. Corresponds to the JSON property allowCancellation

Returns:

  • (Boolean)


1982
1983
1984
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 1982

def allow_cancellation
  @allow_cancellation
end

#output_audioString

The audio data bytes encoded as specified in the request. Note: The output audio is generated based on the values of default platform text responses found in the query_result.response_messages field. If multiple default text responses exist, they will be concatenated when generating audio. If no default platform text responses exist, the generated audio content will be empty. In some scenarios, multiple output audio fields may be present in the response structure. In these cases, only the top-most-level audio output has content. Corresponds to the JSON property outputAudio NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


1996
1997
1998
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 1996

def output_audio
  @output_audio
end

#output_audio_configGoogle::Apis::DialogflowV3::GoogleCloudDialogflowCxV3OutputAudioConfig

Instructs the speech synthesizer how to generate the output audio content. Corresponds to the JSON property outputAudioConfig



2001
2002
2003
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 2001

def output_audio_config
  @output_audio_config
end

#query_resultGoogle::Apis::DialogflowV3::GoogleCloudDialogflowCxV3QueryResult

Represents the result of a conversational query. Corresponds to the JSON property queryResult



2006
2007
2008
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 2006

def query_result
  @query_result
end

#response_idString

Output only. The unique identifier of the response. It can be used to locate a response in the training example set or for reporting issues. Corresponds to the JSON property responseId

Returns:

  • (String)


2012
2013
2014
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 2012

def response_id
  @response_id
end

#response_typeString

Response type. Corresponds to the JSON property responseType

Returns:

  • (String)


2017
2018
2019
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 2017

def response_type
  @response_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2024
2025
2026
2027
2028
2029
2030
2031
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 2024

def update!(**args)
  @allow_cancellation = args[:allow_cancellation] if args.key?(:allow_cancellation)
  @output_audio = args[:output_audio] if args.key?(:output_audio)
  @output_audio_config = args[:output_audio_config] if args.key?(:output_audio_config)
  @query_result = args[:query_result] if args.key?(:query_result)
  @response_id = args[:response_id] if args.key?(:response_id)
  @response_type = args[:response_type] if args.key?(:response_type)
end