Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3EntityType

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

Entities are extracted from user input and represent parameters that are meaningful to your application. For example, a date range, a proper name such as a geographic location or landmark, and so on. Entities represent actionable data for your application. When you define an entity, you can also include synonyms that all map to that entity. For example, "soft drink", "soda", "pop", and so on. There are three types of entities: * System - entities that are defined by the Dialogflow API for common data types such as date, time, currency, and so on. A system entity is represented by the EntityType type. * Custom - entities that are defined by you that represent actionable data that is meaningful to your application. For example, you could define a pizza. sauce entity for red or white pizza sauce, a pizza.cheese entity for the different types of cheese on a pizza, a pizza.topping entity for different toppings, and so on. A custom entity is represented by the EntityType type. * User - entities that are built for an individual user such as favorites, preferences, playlists, and so on. A user entity is represented by the SessionEntityType type. For more information about entity types, see the Dialogflow documentation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowCxV3EntityType

Returns a new instance of GoogleCloudDialogflowCxV3EntityType.



2129
2130
2131
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 2129

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_expansion_modeString

Indicates whether the entity type can be automatically expanded. Corresponds to the JSON property autoExpansionMode

Returns:

  • (String)


2083
2084
2085
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 2083

def auto_expansion_mode
  @auto_expansion_mode
end

#display_nameString

Required. The human-readable name of the entity type, unique within the agent. Corresponds to the JSON property displayName

Returns:

  • (String)


2088
2089
2090
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 2088

def display_name
  @display_name
end

#enable_fuzzy_extractionBoolean Also known as: enable_fuzzy_extraction?

Enables fuzzy entity extraction during classification. Corresponds to the JSON property enableFuzzyExtraction

Returns:

  • (Boolean)


2093
2094
2095
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 2093

def enable_fuzzy_extraction
  @enable_fuzzy_extraction
end

#entitiesArray<Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3EntityTypeEntity>

The collection of entity entries associated with the entity type. Corresponds to the JSON property entities



2099
2100
2101
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 2099

def entities
  @entities
end

#excluded_phrasesArray<Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3EntityTypeExcludedPhrase>

Collection of exceptional words and phrases that shouldn't be matched. For example, if you have a size entity type with entry giant(an adjective), you might consider adding giants(a noun) as an exclusion. If the kind of entity type is KIND_MAP, then the phrases specified by entities and excluded phrases should be mutually exclusive. Corresponds to the JSON property excludedPhrases



2108
2109
2110
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 2108

def excluded_phrases
  @excluded_phrases
end

#kindString

Required. Indicates the kind of entity type. Corresponds to the JSON property kind

Returns:

  • (String)


2113
2114
2115
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 2113

def kind
  @kind
end

#nameString

The unique identifier of the entity type. Required for EntityTypes. UpdateEntityType. Format: projects//locations//agents//entityTypes/. Corresponds to the JSON property name

Returns:

  • (String)


2119
2120
2121
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 2119

def name
  @name
end

#redactBoolean Also known as: redact?

Indicates whether parameters of the entity type should be redacted in log. If redaction is enabled, page parameters and intent parameters referring to the entity type will be replaced by parameter name when logging. Corresponds to the JSON property redact

Returns:

  • (Boolean)


2126
2127
2128
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 2126

def redact
  @redact
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2134
2135
2136
2137
2138
2139
2140
2141
2142
2143
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 2134

def update!(**args)
  @auto_expansion_mode = args[:auto_expansion_mode] if args.key?(:auto_expansion_mode)
  @display_name = args[:display_name] if args.key?(:display_name)
  @enable_fuzzy_extraction = args[:enable_fuzzy_extraction] if args.key?(:enable_fuzzy_extraction)
  @entities = args[:entities] if args.key?(:entities)
  @excluded_phrases = args[:excluded_phrases] if args.key?(:excluded_phrases)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @redact = args[:redact] if args.key?(:redact)
end