Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3Environment
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3Environment
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
Represents an environment for an agent. You can create multiple versions of your agent and publish them to separate environments. When you edit an agent, you are editing the draft agent. At any point, you can save the draft agent as an agent version, which is an immutable snapshot of your agent. When you save the draft agent, it is published to the default environment. When you create agent versions, you can publish them to custom environments. You can create a variety of custom environments for testing, development, production, etc.
Instance Attribute Summary collapse
-
#description ⇒ String
The human-readable description of the environment.
-
#display_name ⇒ String
Required.
-
#name ⇒ String
The name of the environment.
-
#test_cases_config ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3EnvironmentTestCasesConfig
The configuration for continuous tests.
-
#update_time ⇒ String
Output only.
-
#version_configs ⇒ Array<Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3EnvironmentVersionConfig>
A list of configurations for flow versions.
-
#webhook_config ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3EnvironmentWebhookConfig
Configuration for webhooks.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3Environment
constructor
A new instance of GoogleCloudDialogflowCxV3Environment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3Environment
Returns a new instance of GoogleCloudDialogflowCxV3Environment.
2247 2248 2249 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 2247 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
The human-readable description of the environment. The maximum length is 500
characters. If exceeded, the request is rejected.
Corresponds to the JSON property description
2211 2212 2213 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 2211 def description @description end |
#display_name ⇒ String
Required. The human-readable name of the environment (unique in an agent).
Limit of 64 characters.
Corresponds to the JSON property displayName
2217 2218 2219 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 2217 def display_name @display_name end |
#name ⇒ String
The name of the environment. Format: projects//locations//agents//
environments/.
Corresponds to the JSON property name
2223 2224 2225 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 2223 def name @name end |
#test_cases_config ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3EnvironmentTestCasesConfig
The configuration for continuous tests.
Corresponds to the JSON property testCasesConfig
2228 2229 2230 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 2228 def test_cases_config @test_cases_config end |
#update_time ⇒ String
Output only. Update time of this environment.
Corresponds to the JSON property updateTime
2233 2234 2235 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 2233 def update_time @update_time end |
#version_configs ⇒ Array<Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3EnvironmentVersionConfig>
A list of configurations for flow versions. You should include version configs
for all flows that are reachable from Start Flow in the agent. Otherwise, an
error will be returned.
Corresponds to the JSON property versionConfigs
2240 2241 2242 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 2240 def version_configs @version_configs end |
#webhook_config ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3EnvironmentWebhookConfig
Configuration for webhooks.
Corresponds to the JSON property webhookConfig
2245 2246 2247 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 2245 def webhook_config @webhook_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2252 2253 2254 2255 2256 2257 2258 2259 2260 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 2252 def update!(**args) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @name = args[:name] if args.key?(:name) @test_cases_config = args[:test_cases_config] if args.key?(:test_cases_config) @update_time = args[:update_time] if args.key?(:update_time) @version_configs = args[:version_configs] if args.key?(:version_configs) @webhook_config = args[:webhook_config] if args.key?(:webhook_config) end |