Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3Experiment
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3Experiment
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
Represents an experiment in an environment.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Creation time of this experiment.
-
#definition ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3ExperimentDefinition
Definition of the experiment.
-
#description ⇒ String
The human-readable description of the experiment.
-
#display_name ⇒ String
Required.
-
#end_time ⇒ String
End time of this experiment.
-
#experiment_length ⇒ String
Maximum number of days to run the experiment/rollout.
-
#last_update_time ⇒ String
Last update time of this experiment.
-
#name ⇒ String
The name of the experiment.
-
#result ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3ExperimentResult
The inference result which includes an objective metric to optimize and the confidence interval.
-
#rollout_config ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3RolloutConfig
The configuration for auto rollout.
-
#rollout_failure_reason ⇒ String
The reason why rollout has failed.
-
#rollout_state ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3RolloutState
State of the auto-rollout process.
-
#start_time ⇒ String
Start time of this experiment.
-
#state ⇒ String
The current state of the experiment.
-
#variants_history ⇒ Array<Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3VariantsHistory>
The history of updates to the experiment variants.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3Experiment
constructor
A new instance of GoogleCloudDialogflowCxV3Experiment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3Experiment
Returns a new instance of GoogleCloudDialogflowCxV3Experiment.
2599 2600 2601 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 2599 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Creation time of this experiment.
Corresponds to the JSON property createTime
2519 2520 2521 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 2519 def create_time @create_time end |
#definition ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3ExperimentDefinition
Definition of the experiment.
Corresponds to the JSON property definition
2524 2525 2526 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 2524 def definition @definition end |
#description ⇒ String
The human-readable description of the experiment.
Corresponds to the JSON property description
2529 2530 2531 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 2529 def description @description end |
#display_name ⇒ String
Required. The human-readable name of the experiment (unique in an environment).
Limit of 64 characters.
Corresponds to the JSON property displayName
2535 2536 2537 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 2535 def display_name @display_name end |
#end_time ⇒ String
End time of this experiment.
Corresponds to the JSON property endTime
2540 2541 2542 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 2540 def end_time @end_time end |
#experiment_length ⇒ String
Maximum number of days to run the experiment/rollout. If auto-rollout is not
enabled, default value and maximum will be 30 days. If auto-rollout is enabled,
default value and maximum will be 6 days.
Corresponds to the JSON property experimentLength
2547 2548 2549 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 2547 def experiment_length @experiment_length end |
#last_update_time ⇒ String
Last update time of this experiment.
Corresponds to the JSON property lastUpdateTime
2552 2553 2554 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 2552 def last_update_time @last_update_time end |
#name ⇒ String
The name of the experiment. Format: projects//locations//agents//environments//
experiments/.
Corresponds to the JSON property name
2558 2559 2560 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 2558 def name @name end |
#result ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3ExperimentResult
The inference result which includes an objective metric to optimize and the
confidence interval.
Corresponds to the JSON property result
2564 2565 2566 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 2564 def result @result end |
#rollout_config ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3RolloutConfig
The configuration for auto rollout.
Corresponds to the JSON property rolloutConfig
2569 2570 2571 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 2569 def rollout_config @rollout_config end |
#rollout_failure_reason ⇒ String
The reason why rollout has failed. Should only be set when state is
ROLLOUT_FAILED.
Corresponds to the JSON property rolloutFailureReason
2575 2576 2577 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 2575 def rollout_failure_reason @rollout_failure_reason end |
#rollout_state ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3RolloutState
State of the auto-rollout process.
Corresponds to the JSON property rolloutState
2580 2581 2582 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 2580 def rollout_state @rollout_state end |
#start_time ⇒ String
Start time of this experiment.
Corresponds to the JSON property startTime
2585 2586 2587 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 2585 def start_time @start_time end |
#state ⇒ String
The current state of the experiment. Transition triggered by Experiments.
StartExperiment: DRAFT->RUNNING. Transition triggered by Experiments.
CancelExperiment: DRAFT->DONE or RUNNING->DONE.
Corresponds to the JSON property state
2592 2593 2594 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 2592 def state @state end |
#variants_history ⇒ Array<Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3VariantsHistory>
The history of updates to the experiment variants.
Corresponds to the JSON property variantsHistory
2597 2598 2599 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 2597 def variants_history @variants_history end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2604 2605 2606 2607 2608 2609 2610 2611 2612 2613 2614 2615 2616 2617 2618 2619 2620 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 2604 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @definition = args[:definition] if args.key?(:definition) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @end_time = args[:end_time] if args.key?(:end_time) @experiment_length = args[:experiment_length] if args.key?(:experiment_length) @last_update_time = args[:last_update_time] if args.key?(:last_update_time) @name = args[:name] if args.key?(:name) @result = args[:result] if args.key?(:result) @rollout_config = args[:rollout_config] if args.key?(:rollout_config) @rollout_failure_reason = args[:rollout_failure_reason] if args.key?(:rollout_failure_reason) @rollout_state = args[:rollout_state] if args.key?(:rollout_state) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) @variants_history = args[:variants_history] if args.key?(:variants_history) end |