Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3ExperimentResult
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3ExperimentResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
The inference result which includes an objective metric to optimize and the confidence interval.
Instance Attribute Summary collapse
-
#last_update_time ⇒ String
The last time the experiment's stats data was updated.
-
#version_metrics ⇒ Array<Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3ExperimentResultVersionMetrics>
Version variants and metrics.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3ExperimentResult
constructor
A new instance of GoogleCloudDialogflowCxV3ExperimentResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3ExperimentResult
Returns a new instance of GoogleCloudDialogflowCxV3ExperimentResult.
2667 2668 2669 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 2667 def initialize(**args) update!(**args) end |
Instance Attribute Details
#last_update_time ⇒ String
The last time the experiment's stats data was updated. Will have default value
if stats have never been computed for this experiment.
Corresponds to the JSON property lastUpdateTime
2660 2661 2662 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 2660 def last_update_time @last_update_time end |
#version_metrics ⇒ Array<Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3ExperimentResultVersionMetrics>
Version variants and metrics.
Corresponds to the JSON property versionMetrics
2665 2666 2667 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 2665 def version_metrics @version_metrics end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2672 2673 2674 2675 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 2672 def update!(**args) @last_update_time = args[:last_update_time] if args.key?(:last_update_time) @version_metrics = args[:version_metrics] if args.key?(:version_metrics) end |