Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3ExportFlowRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

The request message for Flows.ExportFlow.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowCxV3ExportFlowRequest

Returns a new instance of GoogleCloudDialogflowCxV3ExportFlowRequest.



3025
3026
3027
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 3025

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#flow_uriString

Optional. The Google Cloud Storage URI to export the flow to. The format of this URI must be gs:///. If left unspecified, the serialized flow is returned inline. Dialogflow performs a write operation for the Cloud Storage object on the caller's behalf, so your request authentication must have write permissions for the object. For more information, see Dialogflow access control. Corresponds to the JSON property flowUri

Returns:

  • (String)


3017
3018
3019
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 3017

def flow_uri
  @flow_uri
end

#include_referenced_flowsBoolean Also known as: include_referenced_flows?

Optional. Whether to export flows referenced by the specified flow. Corresponds to the JSON property includeReferencedFlows

Returns:

  • (Boolean)


3022
3023
3024
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 3022

def include_referenced_flows
  @include_referenced_flows
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3030
3031
3032
3033
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 3030

def update!(**args)
  @flow_uri = args[:flow_uri] if args.key?(:flow_uri)
  @include_referenced_flows = args[:include_referenced_flows] if args.key?(:include_referenced_flows)
end