Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3ExportIntentsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

The request message for Intents.ExportIntents.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowCxV3ExportIntentsRequest

Returns a new instance of GoogleCloudDialogflowCxV3ExportIntentsRequest.



3108
3109
3110
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 3108

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_formatString

Optional. The data format of the exported intents. If not specified, BLOB is assumed. Corresponds to the JSON property dataFormat

Returns:

  • (String)


3084
3085
3086
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 3084

def data_format
  @data_format
end

#intentsArray<String>

Required. The name of the intents to export. Format: projects//locations// agents//intents/. Corresponds to the JSON property intents

Returns:

  • (Array<String>)


3090
3091
3092
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 3090

def intents
  @intents
end

#intents_content_inlineBoolean Also known as: intents_content_inline?

Optional. The option to return the serialized intents inline. Corresponds to the JSON property intentsContentInline

Returns:

  • (Boolean)


3095
3096
3097
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 3095

def intents_content_inline
  @intents_content_inline
end

#intents_uriString

Optional. The Google Cloud Storage URI to export the intents to. The format of this URI must be gs:///. Dialogflow performs a write operation for the Cloud Storage object on the caller's behalf, so your request authentication must have write permissions for the object. For more information, see Dialogflow access control. Corresponds to the JSON property intentsUri

Returns:

  • (String)


3106
3107
3108
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 3106

def intents_uri
  @intents_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3113
3114
3115
3116
3117
3118
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 3113

def update!(**args)
  @data_format = args[:data_format] if args.key?(:data_format)
  @intents = args[:intents] if args.key?(:intents)
  @intents_content_inline = args[:intents_content_inline] if args.key?(:intents_content_inline)
  @intents_uri = args[:intents_uri] if args.key?(:intents_uri)
end