Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3ExportTestCasesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

The request message for TestCases.ExportTestCases.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowCxV3ExportTestCasesRequest

Returns a new instance of GoogleCloudDialogflowCxV3ExportTestCasesRequest.



3223
3224
3225
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 3223

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_formatString

The data format of the exported test cases. If not specified, BLOB is assumed. Corresponds to the JSON property dataFormat

Returns:

  • (String)


3202
3203
3204
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 3202

def data_format
  @data_format
end

#filterString

The filter expression used to filter exported test cases, see API Filtering. The expression is case insensitive and supports the following syntax: name = [OR name = ] ... For example: * "name = t1 OR name = t2" matches the test case with the exact resource name "t1" or "t2". Corresponds to the JSON property filter

Returns:

  • (String)


3210
3211
3212
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 3210

def filter
  @filter
end

#gcs_uriString

The Google Cloud Storage URI to export the test cases to. The format of this URI must be gs:///. If unspecified, the serialized test cases is returned inline. Dialogflow performs a write operation for the Cloud Storage object on the caller's behalf, so your request authentication must have write permissions for the object. For more information, see Dialogflow access control. Corresponds to the JSON property gcsUri

Returns:

  • (String)


3221
3222
3223
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 3221

def gcs_uri
  @gcs_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3228
3229
3230
3231
3232
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 3228

def update!(**args)
  @data_format = args[:data_format] if args.key?(:data_format)
  @filter = args[:filter] if args.key?(:filter)
  @gcs_uri = args[:gcs_uri] if args.key?(:gcs_uri)
end