Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3FlowTransition
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3FlowTransition
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
Stores metadata of the transition to a target CX flow. Flow transition actions exit the caller playbook and enter the child flow.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Output only.
-
#flow ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3FlowTransition
constructor
A new instance of GoogleCloudDialogflowCxV3FlowTransition.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3FlowTransition
Returns a new instance of GoogleCloudDialogflowCxV3FlowTransition.
3526 3527 3528 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 3526 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Output only. The display name of the flow.
Corresponds to the JSON property displayName
3518 3519 3520 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 3518 def display_name @display_name end |
#flow ⇒ String
Required. The unique identifier of the flow. Format: projects//locations//
agents/.
Corresponds to the JSON property flow
3524 3525 3526 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 3524 def flow @flow end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3531 3532 3533 3534 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 3531 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @flow = args[:flow] if args.key?(:flow) end |