Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3Form

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

A form is a data model that groups related parameters that can be collected from the user. The process in which the agent prompts the user and collects parameter values from the user is called form filling. A form can be added to a page. When form filling is done, the filled parameters will be written to the session.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowCxV3Form

Returns a new instance of GoogleCloudDialogflowCxV3Form.



3582
3583
3584
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 3582

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#parametersArray<Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3FormParameter>

Parameters to collect from the user. Corresponds to the JSON property parameters



3580
3581
3582
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 3580

def parameters
  @parameters
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3587
3588
3589
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 3587

def update!(**args)
  @parameters = args[:parameters] if args.key?(:parameters)
end