Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3FulfillIntentResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

Response of FulfillIntent

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowCxV3FulfillIntentResponse

Returns a new instance of GoogleCloudDialogflowCxV3FulfillIntentResponse.



3786
3787
3788
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 3786

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#output_audioString

The audio data bytes encoded as specified in the request. Note: The output audio is generated based on the values of default platform text responses found in the query_result.response_messages field. If multiple default text responses exist, they will be concatenated when generating audio. If no default platform text responses exist, the generated audio content will be empty. In some scenarios, multiple output audio fields may be present in the response structure. In these cases, only the top-most-level audio output has content. Corresponds to the JSON property outputAudio NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


3768
3769
3770
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 3768

def output_audio
  @output_audio
end

#output_audio_configGoogle::Apis::DialogflowV3::GoogleCloudDialogflowCxV3OutputAudioConfig

Instructs the speech synthesizer how to generate the output audio content. Corresponds to the JSON property outputAudioConfig



3773
3774
3775
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 3773

def output_audio_config
  @output_audio_config
end

#query_resultGoogle::Apis::DialogflowV3::GoogleCloudDialogflowCxV3QueryResult

Represents the result of a conversational query. Corresponds to the JSON property queryResult



3778
3779
3780
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 3778

def query_result
  @query_result
end

#response_idString

Output only. The unique identifier of the response. It can be used to locate a response in the training example set or for reporting issues. Corresponds to the JSON property responseId

Returns:

  • (String)


3784
3785
3786
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 3784

def response_id
  @response_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3791
3792
3793
3794
3795
3796
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 3791

def update!(**args)
  @output_audio = args[:output_audio] if args.key?(:output_audio)
  @output_audio_config = args[:output_audio_config] if args.key?(:output_audio_config)
  @query_result = args[:query_result] if args.key?(:query_result)
  @response_id = args[:response_id] if args.key?(:response_id)
end