Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3FulfillmentConditionalCasesCase
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3FulfillmentConditionalCasesCase
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
Each case has a Boolean condition. When it is evaluated to be True, the corresponding messages will be selected and evaluated recursively.
Instance Attribute Summary collapse
-
#case_content ⇒ Array<Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3FulfillmentConditionalCasesCaseCaseContent>
A list of case content.
-
#condition ⇒ String
The condition to activate and select this case.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3FulfillmentConditionalCasesCase
constructor
A new instance of GoogleCloudDialogflowCxV3FulfillmentConditionalCasesCase.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3FulfillmentConditionalCasesCase
Returns a new instance of GoogleCloudDialogflowCxV3FulfillmentConditionalCasesCase.
3932 3933 3934 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 3932 def initialize(**args) update!(**args) end |
Instance Attribute Details
#case_content ⇒ Array<Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3FulfillmentConditionalCasesCaseCaseContent>
A list of case content.
Corresponds to the JSON property caseContent
3922 3923 3924 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 3922 def case_content @case_content end |
#condition ⇒ String
The condition to activate and select this case. Empty means the condition is
always true. The condition is evaluated against form parameters or session
parameters. See the conditions reference.
Corresponds to the JSON property condition
3930 3931 3932 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 3930 def condition @condition end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3937 3938 3939 3940 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 3937 def update!(**args) @case_content = args[:case_content] if args.key?(:case_content) @condition = args[:condition] if args.key?(:condition) end |