Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3FulfillmentConditionalCasesCaseCaseContent
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3FulfillmentConditionalCasesCaseCaseContent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
The list of messages or conditional cases to activate for this case.
Instance Attribute Summary collapse
-
#additional_cases ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3FulfillmentConditionalCases
A list of cascading if-else conditions.
-
#message ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3ResponseMessage
Represents a response message that can be returned by a conversational agent.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3FulfillmentConditionalCasesCaseCaseContent
constructor
A new instance of GoogleCloudDialogflowCxV3FulfillmentConditionalCasesCaseCaseContent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3FulfillmentConditionalCasesCaseCaseContent
Returns a new instance of GoogleCloudDialogflowCxV3FulfillmentConditionalCasesCaseCaseContent.
3969 3970 3971 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 3969 def initialize(**args) update!(**args) end |
Instance Attribute Details
#additional_cases ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3FulfillmentConditionalCases
A list of cascading if-else conditions. Cases are mutually exclusive. The
first one with a matching condition is selected, all the rest ignored.
Corresponds to the JSON property additionalCases
3951 3952 3953 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 3951 def additional_cases @additional_cases end |
#message ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3ResponseMessage
Represents a response message that can be returned by a conversational agent.
Response messages are also used for output audio synthesis. The approach is as
follows: * If at least one OutputAudioText response is present, then all
OutputAudioText responses are linearly concatenated, and the result is used
for output audio synthesis. * If the OutputAudioText responses are a mixture
of text and SSML, then the concatenated result is treated as SSML; otherwise,
the result is treated as either text or SSML as appropriate. The agent
designer should ideally use either text or SSML consistently throughout the
bot design. * Otherwise, all Text responses are linearly concatenated, and the
result is used for output audio synthesis. This approach allows for more
sophisticated user experience scenarios, where the text displayed to the user
may differ from what is heard.
Corresponds to the JSON property message
3967 3968 3969 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 3967 def @message end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3974 3975 3976 3977 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 3974 def update!(**args) @additional_cases = args[:additional_cases] if args.key?(:additional_cases) @message = args[:message] if args.key?(:message) end |