Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3FulfillmentGeneratorSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

Generator settings used by the LLM to generate a text response.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowCxV3FulfillmentGeneratorSettings

Returns a new instance of GoogleCloudDialogflowCxV3FulfillmentGeneratorSettings.



4006
4007
4008
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 4006

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#generatorString

Required. The generator to call. Format: projects//locations//agents// generators/. Corresponds to the JSON property generator

Returns:

  • (String)


3988
3989
3990
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 3988

def generator
  @generator
end

#input_parametersHash<String,String>

Map from placeholder parameter in the Generator to corresponding session parameters. By default, Dialogflow uses the session parameter with the same name to fill in the generator template. e.g. If there is a placeholder parameter city in the Generator, Dialogflow default to fill in the $city with $session.params.city. However, you may choose to fill $city with $ session.params.desination-city. - Map key: parameter ID - Map value: session parameter name Corresponds to the JSON property inputParameters

Returns:

  • (Hash<String,String>)


3999
4000
4001
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 3999

def input_parameters
  @input_parameters
end

#output_parameterString

Required. Output parameter which should contain the generator response. Corresponds to the JSON property outputParameter

Returns:

  • (String)


4004
4005
4006
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 4004

def output_parameter
  @output_parameter
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4011
4012
4013
4014
4015
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 4011

def update!(**args)
  @generator = args[:generator] if args.key?(:generator)
  @input_parameters = args[:input_parameters] if args.key?(:input_parameters)
  @output_parameter = args[:output_parameter] if args.key?(:output_parameter)
end