Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3GenerativeSettingsKnowledgeConnectorSettings
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3GenerativeSettingsKnowledgeConnectorSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
Settings for knowledge connector. These parameters are used for LLM prompt like "You are . You are a helpful and verbose at , . Your task is to help humans on ".
Instance Attribute Summary collapse
-
#agent ⇒ String
Name of the virtual agent.
-
#agent_identity ⇒ String
Identity of the agent, e.g.
-
#agent_scope ⇒ String
Agent scope, e.g.
-
#business ⇒ String
Name of the company, organization or other entity that the agent represents.
-
#business_description ⇒ String
Company description, used for LLM prompt, e.g.
-
#disable_data_store_fallback ⇒ Boolean
(also: #disable_data_store_fallback?)
Whether to disable fallback to Data Store search results (in case the LLM couldn't pick a proper answer).
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3GenerativeSettingsKnowledgeConnectorSettings
constructor
A new instance of GoogleCloudDialogflowCxV3GenerativeSettingsKnowledgeConnectorSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3GenerativeSettingsKnowledgeConnectorSettings
Returns a new instance of GoogleCloudDialogflowCxV3GenerativeSettingsKnowledgeConnectorSettings.
4217 4218 4219 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 4217 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent ⇒ String
Name of the virtual agent. Used for LLM prompt. Can be left empty.
Corresponds to the JSON property agent
4185 4186 4187 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 4185 def agent @agent end |
#agent_identity ⇒ String
Identity of the agent, e.g. "virtual agent", "AI assistant".
Corresponds to the JSON property agentIdentity
4190 4191 4192 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 4190 def agent_identity @agent_identity end |
#agent_scope ⇒ String
Agent scope, e.g. "Example company website", "internal Example company website
for employees", "manual of car owner".
Corresponds to the JSON property agentScope
4196 4197 4198 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 4196 def agent_scope @agent_scope end |
#business ⇒ String
Name of the company, organization or other entity that the agent represents.
Used for knowledge connector LLM prompt and for knowledge search.
Corresponds to the JSON property business
4202 4203 4204 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 4202 def business @business end |
#business_description ⇒ String
Company description, used for LLM prompt, e.g. "a family company selling
freshly roasted coffee beans".
Corresponds to the JSON property businessDescription
4208 4209 4210 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 4208 def business_description @business_description end |
#disable_data_store_fallback ⇒ Boolean Also known as: disable_data_store_fallback?
Whether to disable fallback to Data Store search results (in case the LLM
couldn't pick a proper answer). Per default the feature is enabled.
Corresponds to the JSON property disableDataStoreFallback
4214 4215 4216 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 4214 def disable_data_store_fallback @disable_data_store_fallback end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4222 4223 4224 4225 4226 4227 4228 4229 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 4222 def update!(**args) @agent = args[:agent] if args.key?(:agent) @agent_identity = args[:agent_identity] if args.key?(:agent_identity) @agent_scope = args[:agent_scope] if args.key?(:agent_scope) @business = args[:business] if args.key?(:business) @business_description = args[:business_description] if args.key?(:business_description) @disable_data_store_fallback = args[:disable_data_store_fallback] if args.key?(:disable_data_store_fallback) end |