Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3Handler

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

Handler can be used to define custom logic to be executed based on the user- specified triggers.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowCxV3Handler

Returns a new instance of GoogleCloudDialogflowCxV3Handler.



4374
4375
4376
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 4374

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#event_handlerGoogle::Apis::DialogflowV3::GoogleCloudDialogflowCxV3HandlerEventHandler

A handler that is triggered by the specified event. Corresponds to the JSON property eventHandler



4366
4367
4368
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 4366

def event_handler
  @event_handler
end

#lifecycle_handlerGoogle::Apis::DialogflowV3::GoogleCloudDialogflowCxV3HandlerLifecycleHandler

A handler that is triggered on the specific lifecycle_stage of the playbook execution. Corresponds to the JSON property lifecycleHandler



4372
4373
4374
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 4372

def lifecycle_handler
  @lifecycle_handler
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4379
4380
4381
4382
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 4379

def update!(**args)
  @event_handler = args[:event_handler] if args.key?(:event_handler)
  @lifecycle_handler = args[:lifecycle_handler] if args.key?(:lifecycle_handler)
end