Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3HandlerLifecycleHandler

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

A handler that is triggered on the specific lifecycle_stage of the playbook execution.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowCxV3HandlerLifecycleHandler

Returns a new instance of GoogleCloudDialogflowCxV3HandlerLifecycleHandler.



4450
4451
4452
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 4450

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conditionString

Optional. The condition that must be satisfied to trigger this handler. Corresponds to the JSON property condition

Returns:

  • (String)


4430
4431
4432
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 4430

def condition
  @condition
end

#fulfillmentGoogle::Apis::DialogflowV3::GoogleCloudDialogflowCxV3Fulfillment

A fulfillment can do one or more of the following actions at the same time: * Generate rich message responses. * Set parameter values. * Call the webhook. Fulfillments can be called at various stages in the Page or Form lifecycle. For example, when a DetectIntentRequest drives a session to enter a new page, the page's entry fulfillment can add a static response to the QueryResult in the returning DetectIntentResponse, call the webhook (for example, to load user data from a database), or both. Corresponds to the JSON property fulfillment



4441
4442
4443
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 4441

def fulfillment
  @fulfillment
end

#lifecycle_stageString

Required. The name of the lifecycle stage that triggers this handler. Supported values: * playbook-start * pre-action-selection * pre-action- execution Corresponds to the JSON property lifecycleStage

Returns:

  • (String)


4448
4449
4450
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 4448

def lifecycle_stage
  @lifecycle_stage
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4455
4456
4457
4458
4459
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 4455

def update!(**args)
  @condition = args[:condition] if args.key?(:condition)
  @fulfillment = args[:fulfillment] if args.key?(:fulfillment)
  @lifecycle_stage = args[:lifecycle_stage] if args.key?(:lifecycle_stage)
end