Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3ImportFlowRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

The request message for Flows.ImportFlow.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowCxV3ImportFlowRequest

Returns a new instance of GoogleCloudDialogflowCxV3ImportFlowRequest.



4608
4609
4610
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 4608

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#flow_contentString

Uncompressed raw byte content for flow. Corresponds to the JSON property flowContent NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


4585
4586
4587
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 4585

def flow_content
  @flow_content
end

#flow_import_strategyGoogle::Apis::DialogflowV3::GoogleCloudDialogflowCxV3FlowImportStrategy

The flow import strategy used for resource conflict resolution associated with an ImportFlowRequest. Corresponds to the JSON property flowImportStrategy



4591
4592
4593
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 4591

def flow_import_strategy
  @flow_import_strategy
end

#flow_uriString

The Google Cloud Storage URI to import flow from. The format of this URI must be gs:///. Dialogflow performs a read operation for the Cloud Storage object on the caller's behalf, so your request authentication must have read permissions for the object. For more information, see Dialogflow access control. Corresponds to the JSON property flowUri

Returns:

  • (String)


4601
4602
4603
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 4601

def flow_uri
  @flow_uri
end

#import_optionString

Flow import mode. If not specified, KEEP is assumed. Corresponds to the JSON property importOption

Returns:

  • (String)


4606
4607
4608
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 4606

def import_option
  @import_option
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4613
4614
4615
4616
4617
4618
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 4613

def update!(**args)
  @flow_content = args[:flow_content] if args.key?(:flow_content)
  @flow_import_strategy = args[:flow_import_strategy] if args.key?(:flow_import_strategy)
  @flow_uri = args[:flow_uri] if args.key?(:flow_uri)
  @import_option = args[:import_option] if args.key?(:import_option)
end