Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3ImportPlaybookRequest
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3ImportPlaybookRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
The request message for Playbooks.ImportPlaybook.
Instance Attribute Summary collapse
-
#import_strategy ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3PlaybookImportStrategy
The playbook import strategy used for resource conflict resolution associated with an ImportPlaybookRequest.
-
#playbook_content ⇒ String
Uncompressed raw byte content for playbook.
- #playbook_uri ⇒ String
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3ImportPlaybookRequest
constructor
A new instance of GoogleCloudDialogflowCxV3ImportPlaybookRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3ImportPlaybookRequest
Returns a new instance of GoogleCloudDialogflowCxV3ImportPlaybookRequest.
4768 4769 4770 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 4768 def initialize(**args) update!(**args) end |
Instance Attribute Details
#import_strategy ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3PlaybookImportStrategy
The playbook import strategy used for resource conflict resolution associated
with an ImportPlaybookRequest.
Corresponds to the JSON property importStrategy
4754 4755 4756 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 4754 def import_strategy @import_strategy end |
#playbook_content ⇒ String
Uncompressed raw byte content for playbook.
Corresponds to the JSON property playbookContent
NOTE: Values are automatically base64 encoded/decoded in the client library.
4760 4761 4762 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 4760 def playbook_content @playbook_content end |
#playbook_uri ⇒ String
Dialogflow access control.
Corresponds to the JSON property playbookUri
4766 4767 4768 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 4766 def playbook_uri @playbook_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4773 4774 4775 4776 4777 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 4773 def update!(**args) @import_strategy = args[:import_strategy] if args.key?(:import_strategy) @playbook_content = args[:playbook_content] if args.key?(:playbook_content) @playbook_uri = args[:playbook_uri] if args.key?(:playbook_uri) end |