Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3ImportTestCasesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

The request message for TestCases.ImportTestCases.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowCxV3ImportTestCasesRequest

Returns a new instance of GoogleCloudDialogflowCxV3ImportTestCasesRequest.



4819
4820
4821
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 4819

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contentString

Uncompressed raw byte content for test cases. Corresponds to the JSON property content NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


4807
4808
4809
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 4807

def content
  @content
end

#gcs_uriString

The Google Cloud Storage URI to import test cases from. The format of this URI must be gs:///. Dialogflow performs a read operation for the Cloud Storage object on the caller's behalf, so your request authentication must have read permissions for the object. For more information, see Dialogflow access control. Corresponds to the JSON property gcsUri

Returns:

  • (String)


4817
4818
4819
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 4817

def gcs_uri
  @gcs_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4824
4825
4826
4827
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 4824

def update!(**args)
  @content = args[:content] if args.key?(:content)
  @gcs_uri = args[:gcs_uri] if args.key?(:gcs_uri)
end