Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3InlineSchema
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3InlineSchema
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
A type schema object that's specified inline.
Instance Attribute Summary collapse
-
#items ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3TypeSchema
Encapsulates different type schema variations: either a reference to an a schema that's already defined by a tool, or an inline definition.
-
#type ⇒ String
Data type of the schema.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3InlineSchema
constructor
A new instance of GoogleCloudDialogflowCxV3InlineSchema.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3InlineSchema
Returns a new instance of GoogleCloudDialogflowCxV3InlineSchema.
4887 4888 4889 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 4887 def initialize(**args) update!(**args) end |
Instance Attribute Details
#items ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3TypeSchema
Encapsulates different type schema variations: either a reference to an a
schema that's already defined by a tool, or an inline definition.
Corresponds to the JSON property items
4880 4881 4882 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 4880 def items @items end |
#type ⇒ String
Data type of the schema.
Corresponds to the JSON property type
4885 4886 4887 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 4885 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4892 4893 4894 4895 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 4892 def update!(**args) @items = args[:items] if args.key?(:items) @type = args[:type] if args.key?(:type) end |