Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3InputAudioConfig
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3InputAudioConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
Instructs the speech recognizer on how to process the audio content.
Instance Attribute Summary collapse
-
#audio_encoding ⇒ String
Required.
-
#barge_in_config ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3BargeInConfig
Configuration of the barge-in behavior.
-
#enable_word_info ⇒ Boolean
(also: #enable_word_info?)
Optional.
-
#model ⇒ String
Optional.
-
#model_variant ⇒ String
Optional.
-
#opt_out_conformer_model_migration ⇒ Boolean
(also: #opt_out_conformer_model_migration?)
If
true, the request will opt out for STT conformer model migration. -
#phrase_hints ⇒ Array<String>
Optional.
-
#sample_rate_hertz ⇒ Fixnum
Sample rate (in Hertz) of the audio content sent in the query.
-
#single_utterance ⇒ Boolean
(also: #single_utterance?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3InputAudioConfig
constructor
A new instance of GoogleCloudDialogflowCxV3InputAudioConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3InputAudioConfig
Returns a new instance of GoogleCloudDialogflowCxV3InputAudioConfig.
5003 5004 5005 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 5003 def initialize(**args) update!(**args) end |
Instance Attribute Details
#audio_encoding ⇒ String
Required. Audio encoding of the audio content to process.
Corresponds to the JSON property audioEncoding
4926 4927 4928 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 4926 def audio_encoding @audio_encoding end |
#barge_in_config ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3BargeInConfig
Configuration of the barge-in behavior. Barge-in instructs the API to return a
detected utterance at a proper time while the client is playing back the
response audio from a previous request. When the client sees the utterance, it
should stop the playback and immediately get ready for receiving the responses
for the current request. The barge-in handling requires the client to start
streaming audio input as soon as it starts playing back the audio from the
previous response. The playback is modeled into two phases: * No barge-in
phase: which goes first and during which speech detection should not be
carried out. * Barge-in phase: which follows the no barge-in phase and during
which the API starts speech detection and may inform the client that an
utterance has been detected. Note that no-speech event is not expected in this
phase. The client provides this configuration in terms of the durations of
those two phases. The durations are measured in terms of the audio length from
the start of the input audio. No-speech event is a response with
END_OF_UTTERANCE without any transcript following up.
Corresponds to the JSON property bargeInConfig
4945 4946 4947 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 4945 def @barge_in_config end |
#enable_word_info ⇒ Boolean Also known as: enable_word_info?
Optional. If true, Dialogflow returns SpeechWordInfo in
StreamingRecognitionResult with information about the recognized speech words,
e.g. start and end time offsets. If false or unspecified, Speech doesn't
return any word-level information.
Corresponds to the JSON property enableWordInfo
4953 4954 4955 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 4953 def enable_word_info @enable_word_info end |
#model ⇒ String
Optional. Which Speech model to select for the given request. For more
information, see Speech models.
Corresponds to the JSON property model
4961 4962 4963 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 4961 def model @model end |
#model_variant ⇒ String
Optional. Which variant of the Speech model to use.
Corresponds to the JSON property modelVariant
4966 4967 4968 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 4966 def model_variant @model_variant end |
#opt_out_conformer_model_migration ⇒ Boolean Also known as: opt_out_conformer_model_migration?
If true, the request will opt out for STT conformer model migration. This
field will be deprecated once force migration takes place in June 2024. Please
refer to Dialogflow CX Speech model migration.
Corresponds to the JSON property optOutConformerModelMigration
4974 4975 4976 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 4974 def opt_out_conformer_model_migration @opt_out_conformer_model_migration end |
#phrase_hints ⇒ Array<String>
Optional. A list of strings containing words and phrases that the speech
recognizer should recognize with higher likelihood. See the Cloud Speech
documentation for more details.
Corresponds to the JSON property phraseHints
4983 4984 4985 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 4983 def phrase_hints @phrase_hints end |
#sample_rate_hertz ⇒ Fixnum
Sample rate (in Hertz) of the audio content sent in the query. Refer to Cloud
Speech API documentation
for more details.
Corresponds to the JSON property sampleRateHertz
4990 4991 4992 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 4990 def sample_rate_hertz @sample_rate_hertz end |
#single_utterance ⇒ Boolean Also known as: single_utterance?
Optional. If false (default), recognition does not cease until the client
closes the stream. If true, the recognizer will detect a single spoken
utterance in input audio. Recognition ceases when it detects the audio's voice
has stopped or paused. In this case, once a detected intent is received, the
client should close the stream and start a new request with a new stream as
needed. Note: This setting is relevant only for streaming methods.
Corresponds to the JSON property singleUtterance
5000 5001 5002 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 5000 def single_utterance @single_utterance end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5008 5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 5008 def update!(**args) @audio_encoding = args[:audio_encoding] if args.key?(:audio_encoding) @barge_in_config = args[:barge_in_config] if args.key?(:barge_in_config) @enable_word_info = args[:enable_word_info] if args.key?(:enable_word_info) @model = args[:model] if args.key?(:model) @model_variant = args[:model_variant] if args.key?(:model_variant) @opt_out_conformer_model_migration = args[:opt_out_conformer_model_migration] if args.key?(:opt_out_conformer_model_migration) @phrase_hints = args[:phrase_hints] if args.key?(:phrase_hints) @sample_rate_hertz = args[:sample_rate_hertz] if args.key?(:sample_rate_hertz) @single_utterance = args[:single_utterance] if args.key?(:single_utterance) end |