Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3IntentTrainingPhrasePart
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3IntentTrainingPhrasePart
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
Represents a part of a training phrase.
Instance Attribute Summary collapse
-
#parameter_id ⇒ String
The parameter used to annotate this part of the training phrase.
-
#text ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3IntentTrainingPhrasePart
constructor
A new instance of GoogleCloudDialogflowCxV3IntentTrainingPhrasePart.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3IntentTrainingPhrasePart
Returns a new instance of GoogleCloudDialogflowCxV3IntentTrainingPhrasePart.
5280 5281 5282 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 5280 def initialize(**args) update!(**args) end |
Instance Attribute Details
#parameter_id ⇒ String
The parameter used to annotate this part of the training phrase. This field is
required for annotated parts of the training phrase.
Corresponds to the JSON property parameterId
5273 5274 5275 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 5273 def parameter_id @parameter_id end |
#text ⇒ String
Required. The text for this part.
Corresponds to the JSON property text
5278 5279 5280 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 5278 def text @text end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5285 5286 5287 5288 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 5285 def update!(**args) @parameter_id = args[:parameter_id] if args.key?(:parameter_id) @text = args[:text] if args.key?(:text) end |