Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3ListPlaybooksResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

The response message for Playbooks.ListPlaybooks.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowCxV3ListPlaybooksResponse

Returns a new instance of GoogleCloudDialogflowCxV3ListPlaybooksResponse.



5746
5747
5748
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 5746

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

Token to retrieve the next page of results, or empty if there are no more results in the list. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


5738
5739
5740
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 5738

def next_page_token
  @next_page_token
end

#playbooksArray<Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3Playbook>

The list of playbooks. There will be a maximum number of items returned based on the page_size field in the request. Corresponds to the JSON property playbooks



5744
5745
5746
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 5744

def playbooks
  @playbooks
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5751
5752
5753
5754
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 5751

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @playbooks = args[:playbooks] if args.key?(:playbooks)
end