Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3ListToolVersionsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

The response message for Tools.ListToolVersions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowCxV3ListToolVersionsResponse

Returns a new instance of GoogleCloudDialogflowCxV3ListToolVersionsResponse.



5879
5880
5881
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 5879

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

Token to retrieve the next page of results, or empty if there are no more results in the list. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


5871
5872
5873
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 5871

def next_page_token
  @next_page_token
end

#tool_versionsArray<Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3ToolVersion>

The list of tool versions. There will be a maximum number of items returned based on the page_size field in the request. Corresponds to the JSON property toolVersions



5877
5878
5879
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 5877

def tool_versions
  @tool_versions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5884
5885
5886
5887
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 5884

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @tool_versions = args[:tool_versions] if args.key?(:tool_versions)
end