Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3ListToolsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

The response message for Tools.ListTools.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowCxV3ListToolsResponse

Returns a new instance of GoogleCloudDialogflowCxV3ListToolsResponse.



5906
5907
5908
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 5906

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

Token to retrieve the next page of results, or empty if there are no more results in the list. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


5898
5899
5900
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 5898

def next_page_token
  @next_page_token
end

#toolsArray<Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3Tool>

The list of Tools. There will be a maximum number of items returned based on the page_size field in the request. Corresponds to the JSON property tools



5904
5905
5906
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 5904

def tools
  @tools
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5911
5912
5913
5914
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 5911

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @tools = args[:tools] if args.key?(:tools)
end