Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3MatchIntentRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

Request of MatchIntent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowCxV3MatchIntentRequest

Returns a new instance of GoogleCloudDialogflowCxV3MatchIntentRequest.



6167
6168
6169
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 6167

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#persist_parameter_changesBoolean Also known as: persist_parameter_changes?

Persist session parameter changes from query_params. Corresponds to the JSON property persistParameterChanges

Returns:

  • (Boolean)


6150
6151
6152
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 6150

def persist_parameter_changes
  @persist_parameter_changes
end

#query_inputGoogle::Apis::DialogflowV3::GoogleCloudDialogflowCxV3QueryInput

Represents the query input. It can contain one of: 1. A conversational query in the form of text. 2. An intent query that specifies which intent to trigger.

  1. Natural language speech audio to be processed. 4. An event to be triggered.
  2. DTMF digits to invoke an intent and fill in parameter value. 6. The results of a tool executed by the client. Corresponds to the JSON property queryInput


6160
6161
6162
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 6160

def query_input
  @query_input
end

#query_paramsGoogle::Apis::DialogflowV3::GoogleCloudDialogflowCxV3QueryParameters

Represents the parameters of a conversational query. Corresponds to the JSON property queryParams



6165
6166
6167
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 6165

def query_params
  @query_params
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6172
6173
6174
6175
6176
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 6172

def update!(**args)
  @persist_parameter_changes = args[:persist_parameter_changes] if args.key?(:persist_parameter_changes)
  @query_input = args[:query_input] if args.key?(:query_input)
  @query_params = args[:query_params] if args.key?(:query_params)
end