Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3MatchIntentResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

Response of MatchIntent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowCxV3MatchIntentResponse

Returns a new instance of GoogleCloudDialogflowCxV3MatchIntentResponse.



6229
6230
6231
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 6229

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#current_pageGoogle::Apis::DialogflowV3::GoogleCloudDialogflowCxV3Page

A Dialogflow CX conversation (session) can be described and visualized as a state machine. The states of a CX session are represented by pages. For each flow, you define many pages, where your combined pages can handle a complete conversation on the topics the flow is designed for. At any given moment, exactly one page is the current page, the current page is considered active, and the flow associated with that page is considered active. Every flow has a special start page. When a flow initially becomes active, the start page page becomes the current page. For each conversational turn, the current page will either stay the same or transition to another page. You configure each page to collect information from the end-user that is relevant for the conversational state represented by the page. For more information, see the Page guide. Corresponds to the JSON property currentPage



6197
6198
6199
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 6197

def current_page
  @current_page
end

#matchesArray<Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3Match>

Match results, if more than one, ordered descendingly by the confidence we have that the particular intent matches the query. Corresponds to the JSON property matches



6203
6204
6205
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 6203

def matches
  @matches
end

#textString

If natural language text was provided as input, this field will contain a copy of the text. Corresponds to the JSON property text

Returns:

  • (String)


6209
6210
6211
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 6209

def text
  @text
end

#transcriptString

If natural language speech audio was provided as input, this field will contain the transcript for the audio. Corresponds to the JSON property transcript

Returns:

  • (String)


6215
6216
6217
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 6215

def transcript
  @transcript
end

#trigger_eventString

If an event was provided as input, this field will contain a copy of the event name. Corresponds to the JSON property triggerEvent

Returns:

  • (String)


6221
6222
6223
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 6221

def trigger_event
  @trigger_event
end

#trigger_intentString

If an intent was provided as input, this field will contain a copy of the intent identifier. Format: projects//locations//agents//intents/. Corresponds to the JSON property triggerIntent

Returns:

  • (String)


6227
6228
6229
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 6227

def trigger_intent
  @trigger_intent
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6234
6235
6236
6237
6238
6239
6240
6241
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 6234

def update!(**args)
  @current_page = args[:current_page] if args.key?(:current_page)
  @matches = args[:matches] if args.key?(:matches)
  @text = args[:text] if args.key?(:text)
  @transcript = args[:transcript] if args.key?(:transcript)
  @trigger_event = args[:trigger_event] if args.key?(:trigger_event)
  @trigger_intent = args[:trigger_intent] if args.key?(:trigger_intent)
end