Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3NluSettings
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3NluSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
Settings related to NLU.
Instance Attribute Summary collapse
-
#classification_threshold ⇒ Float
To filter out false positive results and still get variety in matched natural language inputs for your agent, you can tune the machine learning classification threshold.
-
#model_training_mode ⇒ String
Indicates NLU model training mode.
-
#model_type ⇒ String
Indicates the type of NLU model.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3NluSettings
constructor
A new instance of GoogleCloudDialogflowCxV3NluSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3NluSettings
Returns a new instance of GoogleCloudDialogflowCxV3NluSettings.
6269 6270 6271 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 6269 def initialize(**args) update!(**args) end |
Instance Attribute Details
#classification_threshold ⇒ Float
To filter out false positive results and still get variety in matched natural
language inputs for your agent, you can tune the machine learning
classification threshold. If the returned score value is less than the
threshold value, then a no-match event will be triggered. The score values
range from 0.0 (completely uncertain) to 1.0 (completely certain). If set to 0.
0, the default of 0.3 is used. You can set a separate classification threshold
for the flow in each language enabled for the agent.
Corresponds to the JSON property classificationThreshold
6257 6258 6259 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 6257 def classification_threshold @classification_threshold end |
#model_training_mode ⇒ String
Indicates NLU model training mode.
Corresponds to the JSON property modelTrainingMode
6262 6263 6264 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 6262 def model_training_mode @model_training_mode end |
#model_type ⇒ String
Indicates the type of NLU model.
Corresponds to the JSON property modelType
6267 6268 6269 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 6267 def model_type @model_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6274 6275 6276 6277 6278 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 6274 def update!(**args) @classification_threshold = args[:classification_threshold] if args.key?(:classification_threshold) @model_training_mode = args[:model_training_mode] if args.key?(:model_training_mode) @model_type = args[:model_type] if args.key?(:model_type) end |