Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3OutputAudioConfig
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3OutputAudioConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
Instructs the speech synthesizer how to generate the output audio content.
Instance Attribute Summary collapse
-
#audio_encoding ⇒ String
Required.
-
#sample_rate_hertz ⇒ Fixnum
Optional.
-
#synthesize_speech_config ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3SynthesizeSpeechConfig
Configuration of how speech should be synthesized.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3OutputAudioConfig
constructor
A new instance of GoogleCloudDialogflowCxV3OutputAudioConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3OutputAudioConfig
Returns a new instance of GoogleCloudDialogflowCxV3OutputAudioConfig.
6304 6305 6306 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 6304 def initialize(**args) update!(**args) end |
Instance Attribute Details
#audio_encoding ⇒ String
Required. Audio encoding of the synthesized audio content.
Corresponds to the JSON property audioEncoding
6288 6289 6290 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 6288 def audio_encoding @audio_encoding end |
#sample_rate_hertz ⇒ Fixnum
Optional. The synthesis sample rate (in hertz) for this audio. If not provided,
then the synthesizer will use the default sample rate based on the audio
encoding. If this is different from the voice's natural sample rate, then the
synthesizer will honor this request by converting to the desired sample rate (
which might result in worse audio quality).
Corresponds to the JSON property sampleRateHertz
6297 6298 6299 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 6297 def sample_rate_hertz @sample_rate_hertz end |
#synthesize_speech_config ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3SynthesizeSpeechConfig
Configuration of how speech should be synthesized.
Corresponds to the JSON property synthesizeSpeechConfig
6302 6303 6304 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 6302 def synthesize_speech_config @synthesize_speech_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6309 6310 6311 6312 6313 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 6309 def update!(**args) @audio_encoding = args[:audio_encoding] if args.key?(:audio_encoding) @sample_rate_hertz = args[:sample_rate_hertz] if args.key?(:sample_rate_hertz) @synthesize_speech_config = args[:synthesize_speech_config] if args.key?(:synthesize_speech_config) end |