Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3Page

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

A Dialogflow CX conversation (session) can be described and visualized as a state machine. The states of a CX session are represented by pages. For each flow, you define many pages, where your combined pages can handle a complete conversation on the topics the flow is designed for. At any given moment, exactly one page is the current page, the current page is considered active, and the flow associated with that page is considered active. Every flow has a special start page. When a flow initially becomes active, the start page page becomes the current page. For each conversational turn, the current page will either stay the same or transition to another page. You configure each page to collect information from the end-user that is relevant for the conversational state represented by the page. For more information, see the Page guide.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowCxV3Page

Returns a new instance of GoogleCloudDialogflowCxV3Page.



6422
6423
6424
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 6422

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advanced_settingsGoogle::Apis::DialogflowV3::GoogleCloudDialogflowCxV3AdvancedSettings

Hierarchical advanced settings for agent/flow/page/fulfillment/parameter. Settings exposed at lower level overrides the settings exposed at higher level. Overriding occurs at the sub-setting level. For example, the playback_interruption_settings at fulfillment level only overrides the playback_interruption_settings at the agent level, leaving other settings at the agent level unchanged. DTMF settings does not override each other. DTMF settings set at different levels define DTMF detections running in parallel. Hierarchy: Agent->Flow->Page->Fulfillment/Parameter. Corresponds to the JSON property advancedSettings



6341
6342
6343
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 6341

def advanced_settings
  @advanced_settings
end

#descriptionString

The description of the page. The maximum length is 500 characters. Corresponds to the JSON property description

Returns:

  • (String)


6346
6347
6348
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 6346

def description
  @description
end

#display_nameString

Required. The human-readable name of the page, unique within the flow. Corresponds to the JSON property displayName

Returns:

  • (String)


6351
6352
6353
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 6351

def display_name
  @display_name
end

#entry_fulfillmentGoogle::Apis::DialogflowV3::GoogleCloudDialogflowCxV3Fulfillment

A fulfillment can do one or more of the following actions at the same time: * Generate rich message responses. * Set parameter values. * Call the webhook. Fulfillments can be called at various stages in the Page or Form lifecycle. For example, when a DetectIntentRequest drives a session to enter a new page, the page's entry fulfillment can add a static response to the QueryResult in the returning DetectIntentResponse, call the webhook (for example, to load user data from a database), or both. Corresponds to the JSON property entryFulfillment



6362
6363
6364
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 6362

def entry_fulfillment
  @entry_fulfillment
end

#event_handlersArray<Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3EventHandler>

Handlers associated with the page to handle events such as webhook errors, no match or no input. Corresponds to the JSON property eventHandlers



6368
6369
6370
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 6368

def event_handlers
  @event_handlers
end

#formGoogle::Apis::DialogflowV3::GoogleCloudDialogflowCxV3Form

A form is a data model that groups related parameters that can be collected from the user. The process in which the agent prompts the user and collects parameter values from the user is called form filling. A form can be added to a page. When form filling is done, the filled parameters will be written to the session. Corresponds to the JSON property form



6377
6378
6379
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 6377

def form
  @form
end

#knowledge_connector_settingsGoogle::Apis::DialogflowV3::GoogleCloudDialogflowCxV3KnowledgeConnectorSettings

The Knowledge Connector settings for this page or flow. This includes information such as the attached Knowledge Bases, and the way to execute fulfillment. Corresponds to the JSON property knowledgeConnectorSettings



6384
6385
6386
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 6384

def knowledge_connector_settings
  @knowledge_connector_settings
end

#nameString

The unique identifier of the page. Required for the Pages.UpdatePage method. Pages.CreatePage populates the name automatically. Format: projects// locations//agents//flows//pages/. Corresponds to the JSON property name

Returns:

  • (String)


6391
6392
6393
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 6391

def name
  @name
end

#transition_route_groupsArray<String>

Ordered list of TransitionRouteGroups added to the page. Transition route groups must be unique within a page. If the page links both flow-level transition route groups and agent-level transition route groups, the flow- level ones will have higher priority and will be put before the agent-level ones. * If multiple transition routes within a page scope refer to the same intent, then the precedence order is: page's transition route -> page's transition route group -> flow's transition routes. * If multiple transition route groups within a page contain the same intent, then the first group in the ordered list takes precedence. Format:projects//locations//agents//flows// transitionRouteGroups/ or projects//locations//agents//transitionRouteGroups/ for agent-level groups. Corresponds to the JSON property transitionRouteGroups

Returns:

  • (Array<String>)


6406
6407
6408
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 6406

def transition_route_groups
  @transition_route_groups
end

#transition_routesArray<Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3TransitionRoute>

A list of transitions for the transition rules of this page. They route the conversation to another page in the same flow, or another flow. When we are in a certain page, the TransitionRoutes are evaluated in the following order: * TransitionRoutes defined in the page with intent specified. * TransitionRoutes defined in the transition route groups with intent specified. * TransitionRoutes defined in flow with intent specified. * TransitionRoutes defined in the transition route groups with intent specified. * TransitionRoutes defined in the page with only condition specified. * TransitionRoutes defined in the transition route groups with only condition specified. Corresponds to the JSON property transitionRoutes



6420
6421
6422
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 6420

def transition_routes
  @transition_routes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6427
6428
6429
6430
6431
6432
6433
6434
6435
6436
6437
6438
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 6427

def update!(**args)
  @advanced_settings = args[:advanced_settings] if args.key?(:advanced_settings)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @entry_fulfillment = args[:entry_fulfillment] if args.key?(:entry_fulfillment)
  @event_handlers = args[:event_handlers] if args.key?(:event_handlers)
  @form = args[:form] if args.key?(:form)
  @knowledge_connector_settings = args[:knowledge_connector_settings] if args.key?(:knowledge_connector_settings)
  @name = args[:name] if args.key?(:name)
  @transition_route_groups = args[:transition_route_groups] if args.key?(:transition_route_groups)
  @transition_routes = args[:transition_routes] if args.key?(:transition_routes)
end