Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3PageInfoFormInfoParameterInfo
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3PageInfoFormInfoParameterInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
Represents parameter information.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Always present for WebhookRequest.
-
#just_collected ⇒ Boolean
(also: #just_collected?)
Optional for WebhookRequest.
-
#required ⇒ Boolean
(also: #required?)
Optional for both WebhookRequest and WebhookResponse.
-
#state ⇒ String
Always present for WebhookRequest.
-
#value ⇒ Object
Optional for both WebhookRequest and WebhookResponse.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3PageInfoFormInfoParameterInfo
constructor
A new instance of GoogleCloudDialogflowCxV3PageInfoFormInfoParameterInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3PageInfoFormInfoParameterInfo
Returns a new instance of GoogleCloudDialogflowCxV3PageInfoFormInfoParameterInfo.
6535 6536 6537 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 6535 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Always present for WebhookRequest. Required for WebhookResponse. The human-
readable name of the parameter, unique within the form. This field cannot be
modified by the webhook.
Corresponds to the JSON property displayName
6504 6505 6506 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 6504 def display_name @display_name end |
#just_collected ⇒ Boolean Also known as: just_collected?
Optional for WebhookRequest. Ignored for WebhookResponse. Indicates if the
parameter value was just collected on the last conversation turn.
Corresponds to the JSON property justCollected
6510 6511 6512 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 6510 def just_collected @just_collected end |
#required ⇒ Boolean Also known as: required?
Optional for both WebhookRequest and WebhookResponse. Indicates whether the
parameter is required. Optional parameters will not trigger prompts; however,
they are filled if the user specifies them. Required parameters must be filled
before form filling concludes.
Corresponds to the JSON property required
6519 6520 6521 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 6519 def required @required end |
#state ⇒ String
Always present for WebhookRequest. Required for WebhookResponse. The state of
the parameter. This field can be set to INVALID by the webhook to invalidate
the parameter; other values set by the webhook will be ignored.
Corresponds to the JSON property state
6527 6528 6529 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 6527 def state @state end |
#value ⇒ Object
Optional for both WebhookRequest and WebhookResponse. The value of the
parameter. This field can be set by the webhook to change the parameter value.
Corresponds to the JSON property value
6533 6534 6535 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 6533 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6540 6541 6542 6543 6544 6545 6546 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 6540 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @just_collected = args[:just_collected] if args.key?(:just_collected) @required = args[:required] if args.key?(:required) @state = args[:state] if args.key?(:state) @value = args[:value] if args.key?(:value) end |