Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3PlaybookImportStrategy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

The playbook import strategy used for resource conflict resolution associated with an ImportPlaybookRequest.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowCxV3PlaybookImportStrategy

Returns a new instance of GoogleCloudDialogflowCxV3PlaybookImportStrategy.



6764
6765
6766
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 6764

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#main_playbook_import_strategyString

Optional. Specifies the import strategy used when resolving conflicts with the main playbook. If not specified, 'CREATE_NEW' is assumed. Corresponds to the JSON property mainPlaybookImportStrategy

Returns:

  • (String)


6748
6749
6750
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 6748

def main_playbook_import_strategy
  @main_playbook_import_strategy
end

#nested_resource_import_strategyString

Optional. Specifies the import strategy used when resolving referenced playbook/flow conflicts. If not specified, 'CREATE_NEW' is assumed. Corresponds to the JSON property nestedResourceImportStrategy

Returns:

  • (String)


6754
6755
6756
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 6754

def nested_resource_import_strategy
  @nested_resource_import_strategy
end

#tool_import_strategyString

Optional. Specifies the import strategy used when resolving tool conflicts. If not specified, 'CREATE_NEW' is assumed. This will be applied after the main playbook and nested resource import strategies, meaning if the playbook that references the tool is skipped, the tool will also be skipped. Corresponds to the JSON property toolImportStrategy

Returns:

  • (String)


6762
6763
6764
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 6762

def tool_import_strategy
  @tool_import_strategy
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6769
6770
6771
6772
6773
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 6769

def update!(**args)
  @main_playbook_import_strategy = args[:main_playbook_import_strategy] if args.key?(:main_playbook_import_strategy)
  @nested_resource_import_strategy = args[:nested_resource_import_strategy] if args.key?(:nested_resource_import_strategy)
  @tool_import_strategy = args[:tool_import_strategy] if args.key?(:tool_import_strategy)
end