Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3PlaybookInstruction

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

Message of the Instruction of the playbook.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowCxV3PlaybookInstruction

Returns a new instance of GoogleCloudDialogflowCxV3PlaybookInstruction.



6812
6813
6814
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 6812

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#guidelinesString

General guidelines for the playbook. These are unstructured instructions that are not directly part of the goal, e.g. "Always be polite". It's valid for this text to be long and used instead of steps altogether. Corresponds to the JSON property guidelines

Returns:

  • (String)


6805
6806
6807
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 6805

def guidelines
  @guidelines
end

#stepsArray<Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3PlaybookStep>

Ordered list of step by step execution instructions to accomplish target goal. Corresponds to the JSON property steps



6810
6811
6812
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 6810

def steps
  @steps
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6817
6818
6819
6820
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 6817

def update!(**args)
  @guidelines = args[:guidelines] if args.key?(:guidelines)
  @steps = args[:steps] if args.key?(:steps)
end