Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3PlaybookTransition

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

Stores metadata of the transition to another target playbook. Playbook transition actions exit the caller playbook and enter the target playbook.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowCxV3PlaybookTransition

Returns a new instance of GoogleCloudDialogflowCxV3PlaybookTransition.



6927
6928
6929
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 6927

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Output only. The display name of the playbook. Corresponds to the JSON property displayName

Returns:

  • (String)


6919
6920
6921
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 6919

def display_name
  @display_name
end

#playbookString

Required. The unique identifier of the playbook. Format: projects//locations// agents//playbooks/. Corresponds to the JSON property playbook

Returns:

  • (String)


6925
6926
6927
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 6925

def playbook
  @playbook
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6932
6933
6934
6935
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 6932

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @playbook = args[:playbook] if args.key?(:playbook)
end