Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3QueryInput

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

Represents the query input. It can contain one of: 1. A conversational query in the form of text. 2. An intent query that specifies which intent to trigger.

  1. Natural language speech audio to be processed. 4. An event to be triggered.
  2. DTMF digits to invoke an intent and fill in parameter value. 6. The results of a tool executed by the client.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowCxV3QueryInput

Returns a new instance of GoogleCloudDialogflowCxV3QueryInput.



7035
7036
7037
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7035

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#audioGoogle::Apis::DialogflowV3::GoogleCloudDialogflowCxV3AudioInput

Represents the natural speech audio to be processed. Corresponds to the JSON property audio



6999
7000
7001
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 6999

def audio
  @audio
end

#dtmfGoogle::Apis::DialogflowV3::GoogleCloudDialogflowCxV3DtmfInput

Represents the input for dtmf event. Corresponds to the JSON property dtmf



7004
7005
7006
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7004

def dtmf
  @dtmf
end

#eventGoogle::Apis::DialogflowV3::GoogleCloudDialogflowCxV3EventInput

Represents the event to trigger. Corresponds to the JSON property event



7009
7010
7011
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7009

def event
  @event
end

#intentGoogle::Apis::DialogflowV3::GoogleCloudDialogflowCxV3IntentInput

Represents the intent to trigger programmatically rather than as a result of natural language processing. Corresponds to the JSON property intent



7015
7016
7017
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7015

def intent
  @intent
end

#language_codeString

Required. The language of the input. See Language Support for a list of the currently supported language codes. Note that queries in the same session do not necessarily need to specify the same language. Corresponds to the JSON property languageCode

Returns:

  • (String)


7023
7024
7025
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7023

def language_code
  @language_code
end

#textGoogle::Apis::DialogflowV3::GoogleCloudDialogflowCxV3TextInput

Represents the natural language text to be processed. Corresponds to the JSON property text



7028
7029
7030
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7028

def text
  @text
end

#tool_call_resultGoogle::Apis::DialogflowV3::GoogleCloudDialogflowCxV3ToolCallResult

The result of calling a tool's action that has been executed by the client. Corresponds to the JSON property toolCallResult



7033
7034
7035
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7033

def tool_call_result
  @tool_call_result
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7040
7041
7042
7043
7044
7045
7046
7047
7048
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7040

def update!(**args)
  @audio = args[:audio] if args.key?(:audio)
  @dtmf = args[:dtmf] if args.key?(:dtmf)
  @event = args[:event] if args.key?(:event)
  @intent = args[:intent] if args.key?(:intent)
  @language_code = args[:language_code] if args.key?(:language_code)
  @text = args[:text] if args.key?(:text)
  @tool_call_result = args[:tool_call_result] if args.key?(:tool_call_result)
end