Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3QueryResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

Represents the result of a conversational query.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowCxV3QueryResult

Returns a new instance of GoogleCloudDialogflowCxV3QueryResult.



7395
7396
7397
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7395

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advanced_settingsGoogle::Apis::DialogflowV3::GoogleCloudDialogflowCxV3AdvancedSettings

Hierarchical advanced settings for agent/flow/page/fulfillment/parameter. Settings exposed at lower level overrides the settings exposed at higher level. Overriding occurs at the sub-setting level. For example, the playback_interruption_settings at fulfillment level only overrides the playback_interruption_settings at the agent level, leaving other settings at the agent level unchanged. DTMF settings does not override each other. DTMF settings set at different levels define DTMF detections running in parallel. Hierarchy: Agent->Flow->Page->Fulfillment/Parameter. Corresponds to the JSON property advancedSettings



7248
7249
7250
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7248

def advanced_settings
  @advanced_settings
end

#allow_answer_feedbackBoolean Also known as: allow_answer_feedback?

Indicates whether the Thumbs up/Thumbs down rating controls are need to be shown for the response in the Dialogflow Messenger widget. Corresponds to the JSON property allowAnswerFeedback

Returns:

  • (Boolean)


7254
7255
7256
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7254

def allow_answer_feedback
  @allow_answer_feedback
end

#current_pageGoogle::Apis::DialogflowV3::GoogleCloudDialogflowCxV3Page

A Dialogflow CX conversation (session) can be described and visualized as a state machine. The states of a CX session are represented by pages. For each flow, you define many pages, where your combined pages can handle a complete conversation on the topics the flow is designed for. At any given moment, exactly one page is the current page, the current page is considered active, and the flow associated with that page is considered active. Every flow has a special start page. When a flow initially becomes active, the start page page becomes the current page. For each conversational turn, the current page will either stay the same or transition to another page. You configure each page to collect information from the end-user that is relevant for the conversational state represented by the page. For more information, see the Page guide. Corresponds to the JSON property currentPage



7271
7272
7273
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7271

def current_page
  @current_page
end

#data_store_connection_signalsGoogle::Apis::DialogflowV3::GoogleCloudDialogflowCxV3DataStoreConnectionSignals

Data store connection feature output signals. Might be only partially field if processing stop before the final answer. Reasons for this can be, but are not limited to: empty UCS search results, positive RAI check outcome, grounding failure, ... Corresponds to the JSON property dataStoreConnectionSignals



7279
7280
7281
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7279

def data_store_connection_signals
  @data_store_connection_signals
end

#diagnostic_infoHash<String,Object>

The free-form diagnostic info. For example, this field could contain webhook call latency. The fields of this data can change without notice, so you should not write code that depends on its structure. One of the fields is called " Alternative Matched Intents", which may aid with debugging. The following describes these intent results: - The list is empty if no intent was matched to end-user input. - Only intents that are referenced in the currently active flow are included. - The matched intent is included. - Other intents that could have matched end-user input, but did not match because they are referenced by intent routes that are out of scope, are included. - Other intents referenced by intent routes in scope that matched end-user input, but had a lower confidence score. Corresponds to the JSON property diagnosticInfo

Returns:

  • (Hash<String,Object>)


7295
7296
7297
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7295

def diagnostic_info
  @diagnostic_info
end

#dtmfGoogle::Apis::DialogflowV3::GoogleCloudDialogflowCxV3DtmfInput

Represents the input for dtmf event. Corresponds to the JSON property dtmf



7300
7301
7302
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7300

def dtmf
  @dtmf
end

#intentGoogle::Apis::DialogflowV3::GoogleCloudDialogflowCxV3Intent

An intent represents a user's intent to interact with a conversational agent. You can provide information for the Dialogflow API to use to match user input to an intent by adding training phrases (i.e., examples of user input) to your intent. Corresponds to the JSON property intent



7308
7309
7310
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7308

def intent
  @intent
end

#intent_detection_confidenceFloat

The intent detection confidence. Values range from 0.0 (completely uncertain) to 1.0 (completely certain). This value is for informational purpose only and is only used to help match the best intent within the classification threshold. This value may change for the same end-user expression at any time due to a model retraining or change in implementation. This field is deprecated, please use QueryResult.match instead. Corresponds to the JSON property intentDetectionConfidence

Returns:

  • (Float)


7318
7319
7320
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7318

def intent_detection_confidence
  @intent_detection_confidence
end

#language_codeString

The language that was triggered during intent detection. See Language Support for a list of the currently supported language codes. Corresponds to the JSON property languageCode

Returns:

  • (String)


7325
7326
7327
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7325

def language_code
  @language_code
end

#matchGoogle::Apis::DialogflowV3::GoogleCloudDialogflowCxV3Match

Represents one match result of MatchIntent. Corresponds to the JSON property match



7330
7331
7332
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7330

def match
  @match
end

#parametersHash<String,Object>

The collected session parameters. Depending on your protocol or client library language, this is a map, associative array, symbol table, dictionary, or JSON object composed of a collection of (MapKey, MapValue) pairs: * MapKey type: string * MapKey value: parameter name * MapValue type: If parameter's entity type is a composite entity then use map, otherwise, depending on the parameter value type, it could be one of string, number, boolean, null, list or map. * MapValue value: If parameter's entity type is a composite entity then use map from composite entity property names to property values, otherwise, use parameter value. Corresponds to the JSON property parameters

Returns:

  • (Hash<String,Object>)


7343
7344
7345
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7343

def parameters
  @parameters
end

#response_messagesArray<Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3ResponseMessage>

The list of rich messages returned to the client. Responses vary from simple text messages to more sophisticated, structured payloads used to drive complex logic. Corresponds to the JSON property responseMessages



7350
7351
7352
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7350

def response_messages
  @response_messages
end

#sentiment_analysis_resultGoogle::Apis::DialogflowV3::GoogleCloudDialogflowCxV3SentimentAnalysisResult

The result of sentiment analysis. Sentiment analysis inspects user input and identifies the prevailing subjective opinion, especially to determine a user's attitude as positive, negative, or neutral. Corresponds to the JSON property sentimentAnalysisResult



7357
7358
7359
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7357

def sentiment_analysis_result
  @sentiment_analysis_result
end

#textString

If natural language text was provided as input, this field will contain a copy of the text. Corresponds to the JSON property text

Returns:

  • (String)


7363
7364
7365
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7363

def text
  @text
end

#transcriptString

If natural language speech audio was provided as input, this field will contain the transcript for the audio. Corresponds to the JSON property transcript

Returns:

  • (String)


7369
7370
7371
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7369

def transcript
  @transcript
end

#trigger_eventString

If an event was provided as input, this field will contain the name of the event. Corresponds to the JSON property triggerEvent

Returns:

  • (String)


7375
7376
7377
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7375

def trigger_event
  @trigger_event
end

#trigger_intentString

If an intent was provided as input, this field will contain a copy of the intent identifier. Format: projects//locations//agents//intents/. Corresponds to the JSON property triggerIntent

Returns:

  • (String)


7381
7382
7383
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7381

def trigger_intent
  @trigger_intent
end

#webhook_payloadsArray<Hash<String,Object>>

The list of webhook payload in WebhookResponse.payload, in the order of call sequence. If some webhook call fails or doesn't return any payload, an empty Struct would be used instead. Corresponds to the JSON property webhookPayloads

Returns:

  • (Array<Hash<String,Object>>)


7388
7389
7390
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7388

def webhook_payloads
  @webhook_payloads
end

#webhook_statusesArray<Google::Apis::DialogflowV3::GoogleRpcStatus>

The list of webhook call status in the order of call sequence. Corresponds to the JSON property webhookStatuses



7393
7394
7395
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7393

def webhook_statuses
  @webhook_statuses
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7400
7401
7402
7403
7404
7405
7406
7407
7408
7409
7410
7411
7412
7413
7414
7415
7416
7417
7418
7419
7420
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7400

def update!(**args)
  @advanced_settings = args[:advanced_settings] if args.key?(:advanced_settings)
  @allow_answer_feedback = args[:allow_answer_feedback] if args.key?(:allow_answer_feedback)
  @current_page = args[:current_page] if args.key?(:current_page)
  @data_store_connection_signals = args[:data_store_connection_signals] if args.key?(:data_store_connection_signals)
  @diagnostic_info = args[:diagnostic_info] if args.key?(:diagnostic_info)
  @dtmf = args[:dtmf] if args.key?(:dtmf)
  @intent = args[:intent] if args.key?(:intent)
  @intent_detection_confidence = args[:intent_detection_confidence] if args.key?(:intent_detection_confidence)
  @language_code = args[:language_code] if args.key?(:language_code)
  @match = args[:match] if args.key?(:match)
  @parameters = args[:parameters] if args.key?(:parameters)
  @response_messages = args[:response_messages] if args.key?(:response_messages)
  @sentiment_analysis_result = args[:sentiment_analysis_result] if args.key?(:sentiment_analysis_result)
  @text = args[:text] if args.key?(:text)
  @transcript = args[:transcript] if args.key?(:transcript)
  @trigger_event = args[:trigger_event] if args.key?(:trigger_event)
  @trigger_intent = args[:trigger_intent] if args.key?(:trigger_intent)
  @webhook_payloads = args[:webhook_payloads] if args.key?(:webhook_payloads)
  @webhook_statuses = args[:webhook_statuses] if args.key?(:webhook_statuses)
end