Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3ResponseMessageConversationSuccess
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3ResponseMessageConversationSuccess
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
Indicates that the conversation succeeded, i.e., the bot handled the issue that the customer talked to it about. Dialogflow only uses this to determine which conversations should be counted as successful and doesn't process the metadata in this message in any way. Note that Dialogflow also considers conversations that get to the conversation end page as successful even if they don't return ConversationSuccess. You may set this, for example: * In the entry_fulfillment of a Page if entering the page indicates that the conversation succeeded. * In a webhook response when you determine that you handled the customer issue.
Instance Attribute Summary collapse
-
#metadata ⇒ Hash<String,Object>
Custom metadata.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3ResponseMessageConversationSuccess
constructor
A new instance of GoogleCloudDialogflowCxV3ResponseMessageConversationSuccess.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3ResponseMessageConversationSuccess
Returns a new instance of GoogleCloudDialogflowCxV3ResponseMessageConversationSuccess.
7591 7592 7593 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7591 def initialize(**args) update!(**args) end |
Instance Attribute Details
#metadata ⇒ Hash<String,Object>
Custom metadata. Dialogflow doesn't impose any structure on this.
Corresponds to the JSON property metadata
7589 7590 7591 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7589 def @metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7596 7597 7598 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7596 def update!(**args) @metadata = args[:metadata] if args.key?(:metadata) end |