Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3ResponseMessageMixedAudioSegment
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3ResponseMessageMixedAudioSegment
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
Represents one segment of audio.
Instance Attribute Summary collapse
-
#allow_playback_interruption ⇒ Boolean
(also: #allow_playback_interruption?)
Output only.
-
#audio ⇒ String
Raw audio synthesized from the Dialogflow agent's response using the output config specified in the request.
-
#uri ⇒ String
Client-specific URI that points to an audio clip accessible to the client.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3ResponseMessageMixedAudioSegment
constructor
A new instance of GoogleCloudDialogflowCxV3ResponseMessageMixedAudioSegment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3ResponseMessageMixedAudioSegment
Returns a new instance of GoogleCloudDialogflowCxV3ResponseMessageMixedAudioSegment.
7702 7703 7704 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7702 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allow_playback_interruption ⇒ Boolean Also known as: allow_playback_interruption?
Output only. Whether the playback of this segment can be interrupted by the
end user's speech and the client should then start the next Dialogflow request.
Corresponds to the JSON property allowPlaybackInterruption
7686 7687 7688 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7686 def allow_playback_interruption @allow_playback_interruption end |
#audio ⇒ String
Raw audio synthesized from the Dialogflow agent's response using the output
config specified in the request.
Corresponds to the JSON property audio
NOTE: Values are automatically base64 encoded/decoded in the client library.
7694 7695 7696 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7694 def audio @audio end |
#uri ⇒ String
Client-specific URI that points to an audio clip accessible to the client.
Dialogflow does not impose any validation on it.
Corresponds to the JSON property uri
7700 7701 7702 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7700 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7707 7708 7709 7710 7711 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7707 def update!(**args) @allow_playback_interruption = args[:allow_playback_interruption] if args.key?(:allow_playback_interruption) @audio = args[:audio] if args.key?(:audio) @uri = args[:uri] if args.key?(:uri) end |