Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3ResponseMessageOutputAudioText
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3ResponseMessageOutputAudioText
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
A text or ssml response that is preferentially used for TTS output audio synthesis, as described in the comment on the ResponseMessage message.
Instance Attribute Summary collapse
-
#allow_playback_interruption ⇒ Boolean
(also: #allow_playback_interruption?)
Output only.
-
#ssml ⇒ String
The SSML text to be synthesized.
-
#text ⇒ String
The raw text to be synthesized.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3ResponseMessageOutputAudioText
constructor
A new instance of GoogleCloudDialogflowCxV3ResponseMessageOutputAudioText.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3ResponseMessageOutputAudioText
Returns a new instance of GoogleCloudDialogflowCxV3ResponseMessageOutputAudioText.
7737 7738 7739 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7737 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allow_playback_interruption ⇒ Boolean Also known as: allow_playback_interruption?
Output only. Whether the playback of this message can be interrupted by the
end user's speech and the client can then starts the next Dialogflow request.
Corresponds to the JSON property allowPlaybackInterruption
7723 7724 7725 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7723 def allow_playback_interruption @allow_playback_interruption end |
#ssml ⇒ String
The SSML text to be synthesized. For more information, see SSML.
Corresponds to the JSON property ssml
7730 7731 7732 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7730 def ssml @ssml end |
#text ⇒ String
The raw text to be synthesized.
Corresponds to the JSON property text
7735 7736 7737 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7735 def text @text end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7742 7743 7744 7745 7746 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7742 def update!(**args) @allow_playback_interruption = args[:allow_playback_interruption] if args.key?(:allow_playback_interruption) @ssml = args[:ssml] if args.key?(:ssml) @text = args[:text] if args.key?(:text) end |