Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3ResponseMessageText

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

The text response message.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowCxV3ResponseMessageText

Returns a new instance of GoogleCloudDialogflowCxV3ResponseMessageText.



7815
7816
7817
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7815

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allow_playback_interruptionBoolean Also known as: allow_playback_interruption?

Output only. Whether the playback of this message can be interrupted by the end user's speech and the client can then starts the next Dialogflow request. Corresponds to the JSON property allowPlaybackInterruption

Returns:

  • (Boolean)


7806
7807
7808
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7806

def allow_playback_interruption
  @allow_playback_interruption
end

#textArray<String>

Required. A collection of text response variants. If multiple variants are defined, only one text response variant is returned at runtime. Corresponds to the JSON property text

Returns:

  • (Array<String>)


7813
7814
7815
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7813

def text
  @text
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7820
7821
7822
7823
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7820

def update!(**args)
  @allow_playback_interruption = args[:allow_playback_interruption] if args.key?(:allow_playback_interruption)
  @text = args[:text] if args.key?(:text)
end