Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3RestorePlaybookVersionResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

The response message for Playbooks.RestorePlaybookVersion.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowCxV3RestorePlaybookVersionResponse

Returns a new instance of GoogleCloudDialogflowCxV3RestorePlaybookVersionResponse.



7915
7916
7917
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7915

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#playbookGoogle::Apis::DialogflowV3::GoogleCloudDialogflowCxV3Playbook

Playbook is the basic building block to instruct the LLM how to execute a certain task. A playbook consists of a goal to accomplish, an optional list of step by step instructions (the step instruction may refers to name of the custom or default plugin tools to use) to perform the task, a list of contextual input data to be passed in at the beginning of the invoked, and a list of output parameters to store the playbook result. Corresponds to the JSON property playbook



7913
7914
7915
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7913

def playbook
  @playbook
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7920
7921
7922
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7920

def update!(**args)
  @playbook = args[:playbook] if args.key?(:playbook)
end