Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3SearchConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

Search configuration for UCS search queries.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowCxV3SearchConfig

Returns a new instance of GoogleCloudDialogflowCxV3SearchConfig.



8320
8321
8322
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 8320

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#boost_specsArray<Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3BoostSpecs>

Optional. Boosting configuration for the datastores. Maps from datastore name to their boost configuration. Do not specify more than one BoostSpecs for each datastore name. If multiple BoostSpecs are provided for the same datastore name, the behavior is undefined. Corresponds to the JSON property boostSpecs



8310
8311
8312
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 8310

def boost_specs
  @boost_specs
end

#filter_specsArray<Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3FilterSpecs>

Optional. Filter configuration for the datastores. Maps from datastore name to the filter expression for that datastore. Do not specify more than one FilterSpecs for each datastore name. If multiple FilterSpecs are provided for the same datastore name, the behavior is undefined. Corresponds to the JSON property filterSpecs



8318
8319
8320
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 8318

def filter_specs
  @filter_specs
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8325
8326
8327
8328
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 8325

def update!(**args)
  @boost_specs = args[:boost_specs] if args.key?(:boost_specs)
  @filter_specs = args[:filter_specs] if args.key?(:filter_specs)
end