Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3SecuritySettingsAudioExportSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

Settings for exporting audio.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowCxV3SecuritySettingsAudioExportSettings

Returns a new instance of GoogleCloudDialogflowCxV3SecuritySettingsAudioExportSettings.



8478
8479
8480
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 8478

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#audio_export_patternString

Filename pattern for exported audio. conversation and timestamp are placeholders that will be replaced with the conversation ID and epoch micros of the conversation. For example, "conversation/recording_timestamp.mulaw". Corresponds to the JSON property audioExportPattern

Returns:

  • (String)


8449
8450
8451
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 8449

def audio_export_pattern
  @audio_export_pattern
end

#audio_formatString

File format for exported audio file. Currently only in telephony recordings. Corresponds to the JSON property audioFormat

Returns:

  • (String)


8454
8455
8456
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 8454

def audio_format
  @audio_format
end

#enable_audio_redactionBoolean Also known as: enable_audio_redaction?

Enable audio redaction if it is true. Note that this only redacts end-user audio data; Synthesised audio from the virtual agent is not redacted. Corresponds to the JSON property enableAudioRedaction

Returns:

  • (Boolean)


8460
8461
8462
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 8460

def enable_audio_redaction
  @enable_audio_redaction
end

#gcs_bucketString

Cloud Storage bucket to export audio record to. Setting this field would grant the Storage Object Creator role to the Dialogflow Service Agent. API caller that tries to modify this field should have the permission of storage.buckets. setIamPolicy. Corresponds to the JSON property gcsBucket

Returns:

  • (String)


8469
8470
8471
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 8469

def gcs_bucket
  @gcs_bucket
end

#store_tts_audioBoolean Also known as: store_tts_audio?

Whether to store TTS audio. By default, TTS audio from the virtual agent is not exported. Corresponds to the JSON property storeTtsAudio

Returns:

  • (Boolean)


8475
8476
8477
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 8475

def store_tts_audio
  @store_tts_audio
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8483
8484
8485
8486
8487
8488
8489
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 8483

def update!(**args)
  @audio_export_pattern = args[:audio_export_pattern] if args.key?(:audio_export_pattern)
  @audio_format = args[:audio_format] if args.key?(:audio_format)
  @enable_audio_redaction = args[:enable_audio_redaction] if args.key?(:enable_audio_redaction)
  @gcs_bucket = args[:gcs_bucket] if args.key?(:gcs_bucket)
  @store_tts_audio = args[:store_tts_audio] if args.key?(:store_tts_audio)
end