Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3SessionEntityType

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

Session entity types are referred to as User entity types and are entities that are built for an individual user such as favorites, preferences, playlists, and so on. You can redefine a session entity type at the session level to extend or replace a custom entity type at the user session level (we refer to the entity types defined at the agent level as "custom entity types"). Note: session entity types apply to all queries, regardless of the language. For more information about entity types, see the Dialogflow documentation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowCxV3SessionEntityType

Returns a new instance of GoogleCloudDialogflowCxV3SessionEntityType.



8573
8574
8575
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 8573

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#entitiesArray<Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3EntityTypeEntity>

Required. The collection of entities to override or supplement the custom entity type. Corresponds to the JSON property entities



8557
8558
8559
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 8557

def entities
  @entities
end

#entity_override_modeString

Required. Indicates whether the additional data should override or supplement the custom entity type definition. Corresponds to the JSON property entityOverrideMode

Returns:

  • (String)


8563
8564
8565
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 8563

def entity_override_mode
  @entity_override_mode
end

#nameString

Required. The unique identifier of the session entity type. Format: projects// locations//agents//sessions//entityTypes/ or projects//locations//agents// environments//sessions//entityTypes/. If Environment ID is not specified, we assume default 'draft' environment. Corresponds to the JSON property name

Returns:

  • (String)


8571
8572
8573
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 8571

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8578
8579
8580
8581
8582
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 8578

def update!(**args)
  @entities = args[:entities] if args.key?(:entities)
  @entity_override_mode = args[:entity_override_mode] if args.key?(:entity_override_mode)
  @name = args[:name] if args.key?(:name)
end