Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3SessionInfo
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3SessionInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
Represents session information communicated to and from the webhook.
Instance Attribute Summary collapse
-
#parameters ⇒ Hash<String,Object>
Optional for WebhookRequest.
-
#session ⇒ String
Always present for WebhookRequest.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3SessionInfo
constructor
A new instance of GoogleCloudDialogflowCxV3SessionInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3SessionInfo
Returns a new instance of GoogleCloudDialogflowCxV3SessionInfo.
8606 8607 8608 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 8606 def initialize(**args) update!(**args) end |
Instance Attribute Details
#parameters ⇒ Hash<String,Object>
Optional for WebhookRequest. Optional for WebhookResponse. All parameters
collected from forms and intents during the session. Parameters can be created,
updated, or removed by the webhook. To remove a parameter from the session,
the webhook should explicitly set the parameter value to null in
WebhookResponse. The map is keyed by parameters' display names.
Corresponds to the JSON property parameters
8596 8597 8598 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 8596 def parameters @parameters end |
#session ⇒ String
Always present for WebhookRequest. Ignored for WebhookResponse. The unique
identifier of the session. This field can be used by the webhook to identify a
session. Format: projects//locations//agents//sessions/ or projects//
locations//agents//environments//sessions/ if environment is specified.
Corresponds to the JSON property session
8604 8605 8606 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 8604 def session @session end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8611 8612 8613 8614 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 8611 def update!(**args) @parameters = args[:parameters] if args.key?(:parameters) @session = args[:session] if args.key?(:session) end |