Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3SynthesizeSpeechConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

Configuration of how speech should be synthesized.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowCxV3SynthesizeSpeechConfig

Returns a new instance of GoogleCloudDialogflowCxV3SynthesizeSpeechConfig.



8739
8740
8741
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 8739

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#effects_profile_idArray<String>

Optional. An identifier which selects 'audio effects' profiles that are applied on (post synthesized) text to speech. Effects are applied on top of each other in the order they are given. Corresponds to the JSON property effectsProfileId

Returns:

  • (Array<String>)


8705
8706
8707
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 8705

def effects_profile_id
  @effects_profile_id
end

#pitchFloat

Optional. Speaking pitch, in the range [-20.0, 20.0]. 20 means increase 20 semitones from the original pitch. -20 means decrease 20 semitones from the original pitch. Corresponds to the JSON property pitch

Returns:

  • (Float)


8712
8713
8714
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 8712

def pitch
  @pitch
end

#speaking_rateFloat

Optional. Speaking rate/speed, in the range [0.25, 4.0]. 1.0 is the normal native speed supported by the specific voice. 2.0 is twice as fast, and 0.5 is half as fast. If unset(0.0), defaults to the native 1.0 speed. Any other values < 0.25 or > 4.0 will return an error. Corresponds to the JSON property speakingRate

Returns:

  • (Float)


8720
8721
8722
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 8720

def speaking_rate
  @speaking_rate
end

#voiceGoogle::Apis::DialogflowV3::GoogleCloudDialogflowCxV3VoiceSelectionParams

Description of which voice to use for speech synthesis. Corresponds to the JSON property voice



8725
8726
8727
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 8725

def voice
  @voice
end

#volume_gain_dbFloat

Optional. Volume gain (in dB) of the normal native volume supported by the specific voice, in the range [-96.0, 16.0]. If unset, or set to a value of 0.0 (dB), will play at normal native signal amplitude. A value of -6.0 (dB) will play at approximately half the amplitude of the normal native signal amplitude. A value of +6.0 (dB) will play at approximately twice the amplitude of the normal native signal amplitude. We strongly recommend not to exceed +10 (dB) as there's usually no effective increase in loudness for any value greater than that. Corresponds to the JSON property volumeGainDb

Returns:

  • (Float)


8737
8738
8739
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 8737

def volume_gain_db
  @volume_gain_db
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8744
8745
8746
8747
8748
8749
8750
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 8744

def update!(**args)
  @effects_profile_id = args[:effects_profile_id] if args.key?(:effects_profile_id)
  @pitch = args[:pitch] if args.key?(:pitch)
  @speaking_rate = args[:speaking_rate] if args.key?(:speaking_rate)
  @voice = args[:voice] if args.key?(:voice)
  @volume_gain_db = args[:volume_gain_db] if args.key?(:volume_gain_db)
end