Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3TestConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

Represents configurations for a test case.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowCxV3TestConfig

Returns a new instance of GoogleCloudDialogflowCxV3TestConfig.



8922
8923
8924
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 8922

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#flowString

Flow name to start the test case with. Format: projects//locations//agents// flows/. Only one of flow and page should be set to indicate the starting point of the test case. If neither is set, the test case will start with start page on the default start flow. Corresponds to the JSON property flow

Returns:

  • (String)


8907
8908
8909
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 8907

def flow
  @flow
end

#pageString

The page to start the test case with. Format: projects//locations//agents// flows//pages/. Only one of flow and page should be set to indicate the starting point of the test case. If neither is set, the test case will start with start page on the default start flow. Corresponds to the JSON property page

Returns:

  • (String)


8915
8916
8917
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 8915

def page
  @page
end

#tracking_parametersArray<String>

Session parameters to be compared when calculating differences. Corresponds to the JSON property trackingParameters

Returns:

  • (Array<String>)


8920
8921
8922
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 8920

def tracking_parameters
  @tracking_parameters
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8927
8928
8929
8930
8931
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 8927

def update!(**args)
  @flow = args[:flow] if args.key?(:flow)
  @page = args[:page] if args.key?(:page)
  @tracking_parameters = args[:tracking_parameters] if args.key?(:tracking_parameters)
end