Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3TestError

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

Error info for running a test.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowCxV3TestError

Returns a new instance of GoogleCloudDialogflowCxV3TestError.



8958
8959
8960
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 8958

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#statusGoogle::Apis::DialogflowV3::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property status



8946
8947
8948
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 8946

def status
  @status
end

#test_caseString

The test case resource name. Corresponds to the JSON property testCase

Returns:

  • (String)


8951
8952
8953
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 8951

def test_case
  @test_case
end

#test_timeString

The timestamp when the test was completed. Corresponds to the JSON property testTime

Returns:

  • (String)


8956
8957
8958
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 8956

def test_time
  @test_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8963
8964
8965
8966
8967
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 8963

def update!(**args)
  @status = args[:status] if args.key?(:status)
  @test_case = args[:test_case] if args.key?(:test_case)
  @test_time = args[:test_time] if args.key?(:test_time)
end