Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3Tool
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3Tool
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
A tool provides a list of actions which are available to the Playbook to attain its goal. A Tool consists of a description of the tool's usage and a specification of the tool which contains the schema and authentication information.
Instance Attribute Summary collapse
-
#data_store_spec ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3ToolDataStoreTool
A DataStoreTool is a way to provide specifications needed to search a list of data stores.
-
#description ⇒ String
Required.
-
#display_name ⇒ String
Required.
-
#function_spec ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3ToolFunctionTool
A Function tool describes the functions to be invoked on the client side.
-
#name ⇒ String
The unique identifier of the Tool.
-
#open_api_spec ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3ToolOpenApiTool
An OpenAPI tool is a way to provide the Tool specifications in the Open API schema format.
-
#tool_type ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3Tool
constructor
A new instance of GoogleCloudDialogflowCxV3Tool.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3Tool
Returns a new instance of GoogleCloudDialogflowCxV3Tool.
9085 9086 9087 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 9085 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_store_spec ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3ToolDataStoreTool
A DataStoreTool is a way to provide specifications needed to search a list of
data stores.
Corresponds to the JSON property dataStoreSpec
9051 9052 9053 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 9051 def data_store_spec @data_store_spec end |
#description ⇒ String
Required. High level description of the Tool and its usage.
Corresponds to the JSON property description
9056 9057 9058 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 9056 def description @description end |
#display_name ⇒ String
Required. The human-readable name of the Tool, unique within an agent.
Corresponds to the JSON property displayName
9061 9062 9063 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 9061 def display_name @display_name end |
#function_spec ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3ToolFunctionTool
A Function tool describes the functions to be invoked on the client side.
Corresponds to the JSON property functionSpec
9066 9067 9068 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 9066 def function_spec @function_spec end |
#name ⇒ String
The unique identifier of the Tool. Format: projects//locations//agents//tools/
.
Corresponds to the JSON property name
9072 9073 9074 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 9072 def name @name end |
#open_api_spec ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3ToolOpenApiTool
An OpenAPI tool is a way to provide the Tool specifications in the Open API
schema format.
Corresponds to the JSON property openApiSpec
9078 9079 9080 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 9078 def open_api_spec @open_api_spec end |
#tool_type ⇒ String
Output only. The tool type.
Corresponds to the JSON property toolType
9083 9084 9085 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 9083 def tool_type @tool_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9090 9091 9092 9093 9094 9095 9096 9097 9098 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 9090 def update!(**args) @data_store_spec = args[:data_store_spec] if args.key?(:data_store_spec) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @function_spec = args[:function_spec] if args.key?(:function_spec) @name = args[:name] if args.key?(:name) @open_api_spec = args[:open_api_spec] if args.key?(:open_api_spec) @tool_type = args[:tool_type] if args.key?(:tool_type) end |