Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3ToolAuthenticationBearerTokenConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

Config for authentication using bearer token.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowCxV3ToolAuthenticationBearerTokenConfig

Returns a new instance of GoogleCloudDialogflowCxV3ToolAuthenticationBearerTokenConfig.



9206
9207
9208
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 9206

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#secret_version_for_tokenString

Optional. The name of the SecretManager secret version resource storing the Bearer token. If this field is set, the token field will be ignored. Format: projects/project/secrets/secret/versions/version` Corresponds to the JSON propertysecretVersionForToken`

Returns:

  • (String)


9196
9197
9198
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 9196

def secret_version_for_token
  @secret_version_for_token
end

#tokenString

Optional. The text token appended to the text Bearer to the request Authorization header. Session parameters reference can be used to pass the token dynamically, e.g. $session.params.parameter-id. Corresponds to the JSON property token

Returns:

  • (String)


9204
9205
9206
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 9204

def token
  @token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9211
9212
9213
9214
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 9211

def update!(**args)
  @secret_version_for_token = args[:secret_version_for_token] if args.key?(:secret_version_for_token)
  @token = args[:token] if args.key?(:token)
end