Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3ToolTlsConfigCaCert

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

The CA certificate.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowCxV3ToolTlsConfigCaCert

Returns a new instance of GoogleCloudDialogflowCxV3ToolTlsConfigCaCert.



9578
9579
9580
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 9578

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#certString

Required. The allowed custom CA certificates (in DER format) for HTTPS verification. This overrides the default SSL trust store. If this is empty or unspecified, Dialogflow will use Google's default trust store to verify certificates. N.B. Make sure the HTTPS server certificates are signed with " subject alt name". For instance a certificate can be self-signed using the following command: openssl x509 -req -days 200 -in example.com.csr \ - signkey example.com.key \ -out example.com.crt \ -extfile <(printf "\ nsubjectAltName='DNS:www.example.com'") Corresponds to the JSON property cert NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


9570
9571
9572
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 9570

def cert
  @cert
end

#display_nameString

Required. The name of the allowed custom CA certificates. This can be used to disambiguate the custom CA certificates. Corresponds to the JSON property displayName

Returns:

  • (String)


9576
9577
9578
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 9576

def display_name
  @display_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9583
9584
9585
9586
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 9583

def update!(**args)
  @cert = args[:cert] if args.key?(:cert)
  @display_name = args[:display_name] if args.key?(:display_name)
end