Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3TransitionRouteGroup
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3TransitionRouteGroup
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
A TransitionRouteGroup represents a group of TransitionRoutes to be used by
a Page.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Required.
-
#name ⇒ String
The unique identifier of the transition route group.
-
#transition_routes ⇒ Array<Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3TransitionRoute>
Transition routes associated with the TransitionRouteGroup.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3TransitionRouteGroup
constructor
A new instance of GoogleCloudDialogflowCxV3TransitionRouteGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3TransitionRouteGroup
Returns a new instance of GoogleCloudDialogflowCxV3TransitionRouteGroup.
9928 9929 9930 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 9928 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Required. The human-readable name of the transition route group, unique within
the flow. The display name can be no longer than 30 characters.
Corresponds to the JSON property displayName
9914 9915 9916 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 9914 def display_name @display_name end |
#name ⇒ String
The unique identifier of the transition route group. TransitionRouteGroups.
CreateTransitionRouteGroup populates the name automatically. Format: projects/
/locations//agents//flows//transitionRouteGroups/ .
Corresponds to the JSON property name
9921 9922 9923 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 9921 def name @name end |
#transition_routes ⇒ Array<Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3TransitionRoute>
Transition routes associated with the TransitionRouteGroup.
Corresponds to the JSON property transitionRoutes
9926 9927 9928 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 9926 def transition_routes @transition_routes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9933 9934 9935 9936 9937 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 9933 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @name = args[:name] if args.key?(:name) @transition_routes = args[:transition_routes] if args.key?(:transition_routes) end |