Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3TurnSignals

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

Collection of all signals that were extracted for a single turn of the conversation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowCxV3TurnSignals

Returns a new instance of GoogleCloudDialogflowCxV3TurnSignals.



10097
10098
10099
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10097

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_escalatedBoolean Also known as: agent_escalated?

Whether agent responded with LiveAgentHandoff fulfillment. Corresponds to the JSON property agentEscalated

Returns:

  • (Boolean)


10042
10043
10044
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10042

def agent_escalated
  @agent_escalated
end

#dtmf_usedBoolean Also known as: dtmf_used?

Whether user was using DTMF input. Corresponds to the JSON property dtmfUsed

Returns:

  • (Boolean)


10048
10049
10050
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10048

def dtmf_used
  @dtmf_used
end

#failure_reasonsArray<String>

Failure reasons of the turn. Corresponds to the JSON property failureReasons

Returns:

  • (Array<String>)


10054
10055
10056
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10054

def failure_reasons
  @failure_reasons
end

#no_matchBoolean Also known as: no_match?

Whether NLU predicted NO_MATCH. Corresponds to the JSON property noMatch

Returns:

  • (Boolean)


10059
10060
10061
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10059

def no_match
  @no_match
end

#no_user_inputBoolean Also known as: no_user_input?

Whether user provided no input. Corresponds to the JSON property noUserInput

Returns:

  • (Boolean)


10065
10066
10067
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10065

def no_user_input
  @no_user_input
end

#reached_end_pageBoolean Also known as: reached_end_page?

Whether turn resulted in End Session page. Corresponds to the JSON property reachedEndPage

Returns:

  • (Boolean)


10071
10072
10073
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10071

def reached_end_page
  @reached_end_page
end

#sentiment_magnitudeFloat

Sentiment magnitude of the user utterance if sentiment was enabled. Corresponds to the JSON property sentimentMagnitude

Returns:

  • (Float)


10078
10079
10080
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10078

def sentiment_magnitude
  @sentiment_magnitude
end

#sentiment_scoreFloat

Sentiment score of the user utterance if sentiment was enabled. Corresponds to the JSON property sentimentScore

Returns:

  • (Float)


10084
10085
10086
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10084

def sentiment_score
  @sentiment_score
end

#user_escalatedBoolean Also known as: user_escalated?

Whether user was specifically asking for a live agent. Corresponds to the JSON property userEscalated

Returns:

  • (Boolean)


10089
10090
10091
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10089

def user_escalated
  @user_escalated
end

#webhook_statusesArray<String>

Human-readable statuses of the webhooks triggered during this turn. Corresponds to the JSON property webhookStatuses

Returns:

  • (Array<String>)


10095
10096
10097
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10095

def webhook_statuses
  @webhook_statuses
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10102
10103
10104
10105
10106
10107
10108
10109
10110
10111
10112
10113
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10102

def update!(**args)
  @agent_escalated = args[:agent_escalated] if args.key?(:agent_escalated)
  @dtmf_used = args[:dtmf_used] if args.key?(:dtmf_used)
  @failure_reasons = args[:failure_reasons] if args.key?(:failure_reasons)
  @no_match = args[:no_match] if args.key?(:no_match)
  @no_user_input = args[:no_user_input] if args.key?(:no_user_input)
  @reached_end_page = args[:reached_end_page] if args.key?(:reached_end_page)
  @sentiment_magnitude = args[:sentiment_magnitude] if args.key?(:sentiment_magnitude)
  @sentiment_score = args[:sentiment_score] if args.key?(:sentiment_score)
  @user_escalated = args[:user_escalated] if args.key?(:user_escalated)
  @webhook_statuses = args[:webhook_statuses] if args.key?(:webhook_statuses)
end