Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3TypeSchema

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

Encapsulates different type schema variations: either a reference to an a schema that's already defined by a tool, or an inline definition.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowCxV3TypeSchema

Returns a new instance of GoogleCloudDialogflowCxV3TypeSchema.



10131
10132
10133
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10131

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#inline_schemaGoogle::Apis::DialogflowV3::GoogleCloudDialogflowCxV3InlineSchema

A type schema object that's specified inline. Corresponds to the JSON property inlineSchema



10124
10125
10126
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10124

def inline_schema
  @inline_schema
end

#schema_referenceGoogle::Apis::DialogflowV3::GoogleCloudDialogflowCxV3TypeSchemaSchemaReference

A reference to the schema of an existing tool. Corresponds to the JSON property schemaReference



10129
10130
10131
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10129

def schema_reference
  @schema_reference
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10136
10137
10138
10139
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10136

def update!(**args)
  @inline_schema = args[:inline_schema] if args.key?(:inline_schema)
  @schema_reference = args[:schema_reference] if args.key?(:schema_reference)
end