Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3ValidationMessage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

Agent/flow validation message.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowCxV3ValidationMessage

Returns a new instance of GoogleCloudDialogflowCxV3ValidationMessage.



10254
10255
10256
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10254

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#detailString

The message detail. Corresponds to the JSON property detail

Returns:

  • (String)


10232
10233
10234
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10232

def detail
  @detail
end

#resource_namesArray<Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3ResourceName>

The resource names of the resources where the message is found. Corresponds to the JSON property resourceNames



10237
10238
10239
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10237

def resource_names
  @resource_names
end

#resource_typeString

The type of the resources where the message is found. Corresponds to the JSON property resourceType

Returns:

  • (String)


10242
10243
10244
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10242

def resource_type
  @resource_type
end

#resourcesArray<String>

The names of the resources where the message is found. Corresponds to the JSON property resources

Returns:

  • (Array<String>)


10247
10248
10249
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10247

def resources
  @resources
end

#severityString

Indicates the severity of the message. Corresponds to the JSON property severity

Returns:

  • (String)


10252
10253
10254
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10252

def severity
  @severity
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10259
10260
10261
10262
10263
10264
10265
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10259

def update!(**args)
  @detail = args[:detail] if args.key?(:detail)
  @resource_names = args[:resource_names] if args.key?(:resource_names)
  @resource_type = args[:resource_type] if args.key?(:resource_type)
  @resources = args[:resources] if args.key?(:resources)
  @severity = args[:severity] if args.key?(:severity)
end