Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3WebhookGenericWebServiceServiceAccountAuthConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

Configuration for authentication using a service account.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowCxV3WebhookGenericWebServiceServiceAccountAuthConfig

Returns a new instance of GoogleCloudDialogflowCxV3WebhookGenericWebServiceServiceAccountAuthConfig.



10688
10689
10690
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10688

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#service_accountString

Required. The email address of the service account used to authenticate the webhook call. Dialogflow uses this service account to exchange an access token and the access token is then sent in the Authorization header of the webhook request. The service account must have the roles/iam. serviceAccountTokenCreator role granted to the Dialogflow service agent. Corresponds to the JSON property serviceAccount

Returns:

  • (String)


10686
10687
10688
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10686

def 
  @service_account
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10693
10694
10695
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10693

def update!(**args)
  @service_account = args[:service_account] if args.key?(:service_account)
end