Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3WebhookRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

The request message for a webhook call. The request is sent as a JSON object and the field names will be presented in camel cases. You may see undocumented fields in an actual request. These fields are used internally by Dialogflow and should be ignored.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowCxV3WebhookRequest

Returns a new instance of GoogleCloudDialogflowCxV3WebhookRequest.



10786
10787
10788
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10786

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#detect_intent_response_idString

Always present. The unique identifier of the DetectIntentResponse that will be returned to the API caller. Corresponds to the JSON property detectIntentResponseId

Returns:

  • (String)


10709
10710
10711
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10709

def detect_intent_response_id
  @detect_intent_response_id
end

#dtmf_digitsString

If DTMF was provided as input, this field will contain the DTMF digits. Corresponds to the JSON property dtmfDigits

Returns:

  • (String)


10714
10715
10716
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10714

def dtmf_digits
  @dtmf_digits
end

#fulfillment_infoGoogle::Apis::DialogflowV3::GoogleCloudDialogflowCxV3WebhookRequestFulfillmentInfo

Represents fulfillment information communicated to the webhook. Corresponds to the JSON property fulfillmentInfo



10719
10720
10721
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10719

def fulfillment_info
  @fulfillment_info
end

#intent_infoGoogle::Apis::DialogflowV3::GoogleCloudDialogflowCxV3WebhookRequestIntentInfo

Represents intent information communicated to the webhook. Corresponds to the JSON property intentInfo



10724
10725
10726
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10724

def intent_info
  @intent_info
end

#language_codeString

The language code specified in the original request. Corresponds to the JSON property languageCode

Returns:

  • (String)


10729
10730
10731
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10729

def language_code
  @language_code
end

#language_infoGoogle::Apis::DialogflowV3::GoogleCloudDialogflowCxV3LanguageInfo

Represents the language information of the request. Corresponds to the JSON property languageInfo



10734
10735
10736
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10734

def language_info
  @language_info
end

#messagesArray<Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3ResponseMessage>

The list of rich message responses to present to the user. Webhook can choose to append or replace this list in WebhookResponse.fulfillment_response; Corresponds to the JSON property messages



10740
10741
10742
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10740

def messages
  @messages
end

#page_infoGoogle::Apis::DialogflowV3::GoogleCloudDialogflowCxV3PageInfo

Represents page information communicated to and from the webhook. Corresponds to the JSON property pageInfo



10745
10746
10747
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10745

def page_info
  @page_info
end

#payloadHash<String,Object>

Custom data set in QueryParameters.payload. Corresponds to the JSON property payload

Returns:

  • (Hash<String,Object>)


10750
10751
10752
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10750

def payload
  @payload
end

#sentiment_analysis_resultGoogle::Apis::DialogflowV3::GoogleCloudDialogflowCxV3WebhookRequestSentimentAnalysisResult

Represents the result of sentiment analysis. Corresponds to the JSON property sentimentAnalysisResult



10755
10756
10757
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10755

def sentiment_analysis_result
  @sentiment_analysis_result
end

#session_infoGoogle::Apis::DialogflowV3::GoogleCloudDialogflowCxV3SessionInfo

Represents session information communicated to and from the webhook. Corresponds to the JSON property sessionInfo



10760
10761
10762
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10760

def session_info
  @session_info
end

#textString

If natural language text was provided as input, this field will contain a copy of the text. Corresponds to the JSON property text

Returns:

  • (String)


10766
10767
10768
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10766

def text
  @text
end

#transcriptString

If natural language speech audio was provided as input, this field will contain the transcript for the audio. Corresponds to the JSON property transcript

Returns:

  • (String)


10772
10773
10774
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10772

def transcript
  @transcript
end

#trigger_eventString

If an event was provided as input, this field will contain the name of the event. Corresponds to the JSON property triggerEvent

Returns:

  • (String)


10778
10779
10780
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10778

def trigger_event
  @trigger_event
end

#trigger_intentString

If an intent was provided as input, this field will contain a copy of the intent identifier. Format: projects//locations//agents//intents/. Corresponds to the JSON property triggerIntent

Returns:

  • (String)


10784
10785
10786
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10784

def trigger_intent
  @trigger_intent
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10791
10792
10793
10794
10795
10796
10797
10798
10799
10800
10801
10802
10803
10804
10805
10806
10807
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10791

def update!(**args)
  @detect_intent_response_id = args[:detect_intent_response_id] if args.key?(:detect_intent_response_id)
  @dtmf_digits = args[:dtmf_digits] if args.key?(:dtmf_digits)
  @fulfillment_info = args[:fulfillment_info] if args.key?(:fulfillment_info)
  @intent_info = args[:intent_info] if args.key?(:intent_info)
  @language_code = args[:language_code] if args.key?(:language_code)
  @language_info = args[:language_info] if args.key?(:language_info)
  @messages = args[:messages] if args.key?(:messages)
  @page_info = args[:page_info] if args.key?(:page_info)
  @payload = args[:payload] if args.key?(:payload)
  @sentiment_analysis_result = args[:sentiment_analysis_result] if args.key?(:sentiment_analysis_result)
  @session_info = args[:session_info] if args.key?(:session_info)
  @text = args[:text] if args.key?(:text)
  @transcript = args[:transcript] if args.key?(:transcript)
  @trigger_event = args[:trigger_event] if args.key?(:trigger_event)
  @trigger_intent = args[:trigger_intent] if args.key?(:trigger_intent)
end