Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3WebhookRequestFulfillmentInfo
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3WebhookRequestFulfillmentInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
Represents fulfillment information communicated to the webhook.
Instance Attribute Summary collapse
-
#tag ⇒ String
Always present.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3WebhookRequestFulfillmentInfo
constructor
A new instance of GoogleCloudDialogflowCxV3WebhookRequestFulfillmentInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3WebhookRequestFulfillmentInfo
Returns a new instance of GoogleCloudDialogflowCxV3WebhookRequestFulfillmentInfo.
10822 10823 10824 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10822 def initialize(**args) update!(**args) end |
Instance Attribute Details
#tag ⇒ String
Always present. The value of the Fulfillment.tag field will be populated in
this field by Dialogflow when the associated webhook is called. The tag is
typically used by the webhook service to identify which fulfillment is being
called, but it could be used for other purposes.
Corresponds to the JSON property tag
10820 10821 10822 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10820 def tag @tag end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10827 10828 10829 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10827 def update!(**args) @tag = args[:tag] if args.key?(:tag) end |