Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3WebhookRequestIntentInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

Represents intent information communicated to the webhook.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowCxV3WebhookRequestIntentInfo

Returns a new instance of GoogleCloudDialogflowCxV3WebhookRequestIntentInfo.



10861
10862
10863
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10861

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#confidenceFloat

The confidence of the matched intent. Values range from 0.0 (completely uncertain) to 1.0 (completely certain). Corresponds to the JSON property confidence

Returns:

  • (Float)


10840
10841
10842
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10840

def confidence
  @confidence
end

#display_nameString

Always present. The display name of the last matched intent. Corresponds to the JSON property displayName

Returns:

  • (String)


10845
10846
10847
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10845

def display_name
  @display_name
end

#last_matched_intentString

Always present. The unique identifier of the last matched intent. Format: projects//locations//agents//intents/. Corresponds to the JSON property lastMatchedIntent

Returns:

  • (String)


10851
10852
10853
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10851

def last_matched_intent
  @last_matched_intent
end

#parametersHash<String,Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3WebhookRequestIntentInfoIntentParameterValue>

Parameters identified as a result of intent matching. This is a map of the name of the identified parameter to the value of the parameter identified from the user's utterance. All parameters defined in the matched intent that are identified will be surfaced here. Corresponds to the JSON property parameters



10859
10860
10861
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10859

def parameters
  @parameters
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10866
10867
10868
10869
10870
10871
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10866

def update!(**args)
  @confidence = args[:confidence] if args.key?(:confidence)
  @display_name = args[:display_name] if args.key?(:display_name)
  @last_matched_intent = args[:last_matched_intent] if args.key?(:last_matched_intent)
  @parameters = args[:parameters] if args.key?(:parameters)
end