Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3WebhookResponse
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3WebhookResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
The response message for a webhook call.
Instance Attribute Summary collapse
-
#fulfillment_response ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3WebhookResponseFulfillmentResponse
Represents a fulfillment response to the user.
-
#page_info ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3PageInfo
Represents page information communicated to and from the webhook.
-
#payload ⇒ Hash<String,Object>
Value to append directly to QueryResult.webhook_payloads.
-
#session_info ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3SessionInfo
Represents session information communicated to and from the webhook.
-
#target_flow ⇒ String
The target flow to transition to.
-
#target_page ⇒ String
The target page to transition to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3WebhookResponse
constructor
A new instance of GoogleCloudDialogflowCxV3WebhookResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3WebhookResponse
Returns a new instance of GoogleCloudDialogflowCxV3WebhookResponse.
10962 10963 10964 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10962 def initialize(**args) update!(**args) end |
Instance Attribute Details
#fulfillment_response ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3WebhookResponseFulfillmentResponse
Represents a fulfillment response to the user.
Corresponds to the JSON property fulfillmentResponse
10933 10934 10935 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10933 def fulfillment_response @fulfillment_response end |
#page_info ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3PageInfo
Represents page information communicated to and from the webhook.
Corresponds to the JSON property pageInfo
10938 10939 10940 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10938 def page_info @page_info end |
#payload ⇒ Hash<String,Object>
Value to append directly to QueryResult.webhook_payloads.
Corresponds to the JSON property payload
10943 10944 10945 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10943 def payload @payload end |
#session_info ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3SessionInfo
Represents session information communicated to and from the webhook.
Corresponds to the JSON property sessionInfo
10948 10949 10950 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10948 def session_info @session_info end |
#target_flow ⇒ String
The target flow to transition to. Format: projects//locations//agents//flows/
.
Corresponds to the JSON property targetFlow
10954 10955 10956 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10954 def target_flow @target_flow end |
#target_page ⇒ String
The target page to transition to. Format: projects//locations//agents//flows//
pages/.
Corresponds to the JSON property targetPage
10960 10961 10962 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10960 def target_page @target_page end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10967 10968 10969 10970 10971 10972 10973 10974 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10967 def update!(**args) @fulfillment_response = args[:fulfillment_response] if args.key?(:fulfillment_response) @page_info = args[:page_info] if args.key?(:page_info) @payload = args[:payload] if args.key?(:payload) @session_info = args[:session_info] if args.key?(:session_info) @target_flow = args[:target_flow] if args.key?(:target_flow) @target_page = args[:target_page] if args.key?(:target_page) end |