Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1AdvancedSettingsDtmfSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

Define behaviors for DTMF (dual tone multi frequency).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowCxV3beta1AdvancedSettingsDtmfSettings

Returns a new instance of GoogleCloudDialogflowCxV3beta1AdvancedSettingsDtmfSettings.



11110
11111
11112
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 11110

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enabledBoolean Also known as: enabled?

If true, incoming audio is processed for DTMF (dual tone multi frequency) events. For example, if the caller presses a button on their telephone keypad and DTMF processing is enabled, Dialogflow will detect the event (e.g. a "3" was pressed) in the incoming audio and pass the event to the bot to drive business logic (e.g. when 3 is pressed, return the account balance). Corresponds to the JSON property enabled

Returns:

  • (Boolean)


11087
11088
11089
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 11087

def enabled
  @enabled
end

#endpointing_timeout_durationString

Endpoint timeout setting for matching dtmf input to regex. Corresponds to the JSON property endpointingTimeoutDuration

Returns:

  • (String)


11093
11094
11095
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 11093

def endpointing_timeout_duration
  @endpointing_timeout_duration
end

#finish_digitString

The digit that terminates a DTMF digit sequence. Corresponds to the JSON property finishDigit

Returns:

  • (String)


11098
11099
11100
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 11098

def finish_digit
  @finish_digit
end

#interdigit_timeout_durationString

Interdigit timeout setting for matching dtmf input to regex. Corresponds to the JSON property interdigitTimeoutDuration

Returns:

  • (String)


11103
11104
11105
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 11103

def interdigit_timeout_duration
  @interdigit_timeout_duration
end

#max_digitsFixnum

Max length of DTMF digits. Corresponds to the JSON property maxDigits

Returns:

  • (Fixnum)


11108
11109
11110
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 11108

def max_digits
  @max_digits
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11115
11116
11117
11118
11119
11120
11121
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 11115

def update!(**args)
  @enabled = args[:enabled] if args.key?(:enabled)
  @endpointing_timeout_duration = args[:endpointing_timeout_duration] if args.key?(:endpointing_timeout_duration)
  @finish_digit = args[:finish_digit] if args.key?(:finish_digit)
  @interdigit_timeout_duration = args[:interdigit_timeout_duration] if args.key?(:interdigit_timeout_duration)
  @max_digits = args[:max_digits] if args.key?(:max_digits)
end