Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1ConversationTurnUserInput
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1ConversationTurnUserInput
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
The input from the human user.
Instance Attribute Summary collapse
-
#enable_sentiment_analysis ⇒ Boolean
(also: #enable_sentiment_analysis?)
Whether sentiment analysis is enabled.
-
#injected_parameters ⇒ Hash<String,Object>
Parameters that need to be injected into the conversation during intent detection.
-
#input ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1QueryInput
Represents the query input.
-
#is_webhook_enabled ⇒ Boolean
(also: #is_webhook_enabled?)
If webhooks should be allowed to trigger in response to the user utterance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3beta1ConversationTurnUserInput
constructor
A new instance of GoogleCloudDialogflowCxV3beta1ConversationTurnUserInput.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3beta1ConversationTurnUserInput
Returns a new instance of GoogleCloudDialogflowCxV3beta1ConversationTurnUserInput.
11430 11431 11432 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 11430 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enable_sentiment_analysis ⇒ Boolean Also known as: enable_sentiment_analysis?
Whether sentiment analysis is enabled.
Corresponds to the JSON property enableSentimentAnalysis
11405 11406 11407 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 11405 def enable_sentiment_analysis @enable_sentiment_analysis end |
#injected_parameters ⇒ Hash<String,Object>
Parameters that need to be injected into the conversation during intent
detection.
Corresponds to the JSON property injectedParameters
11412 11413 11414 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 11412 def injected_parameters @injected_parameters end |
#input ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1QueryInput
Represents the query input. It can contain one of: 1. A conversational query in the form of text. 2. An intent query that specifies which intent to trigger.
- Natural language speech audio to be processed. 4. An event to be triggered.
- DTMF digits to invoke an intent and fill in parameter value. 6. The
results of a tool executed by the client.
Corresponds to the JSON property
input
11421 11422 11423 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 11421 def input @input end |
#is_webhook_enabled ⇒ Boolean Also known as: is_webhook_enabled?
If webhooks should be allowed to trigger in response to the user utterance.
Often if parameters are injected, webhooks should not be enabled.
Corresponds to the JSON property isWebhookEnabled
11427 11428 11429 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 11427 def is_webhook_enabled @is_webhook_enabled end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11435 11436 11437 11438 11439 11440 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 11435 def update!(**args) @enable_sentiment_analysis = args[:enable_sentiment_analysis] if args.key?(:enable_sentiment_analysis) @injected_parameters = args[:injected_parameters] if args.key?(:injected_parameters) @input = args[:input] if args.key?(:input) @is_webhook_enabled = args[:is_webhook_enabled] if args.key?(:is_webhook_enabled) end |