Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1ConversationTurnVirtualAgentOutput

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

The output from the virtual agent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowCxV3beta1ConversationTurnVirtualAgentOutput

Returns a new instance of GoogleCloudDialogflowCxV3beta1ConversationTurnVirtualAgentOutput.



11503
11504
11505
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 11503

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#current_pageGoogle::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1Page

A Dialogflow CX conversation (session) can be described and visualized as a state machine. The states of a CX session are represented by pages. For each flow, you define many pages, where your combined pages can handle a complete conversation on the topics the flow is designed for. At any given moment, exactly one page is the current page, the current page is considered active, and the flow associated with that page is considered active. Every flow has a special start page. When a flow initially becomes active, the start page page becomes the current page. For each conversational turn, the current page will either stay the same or transition to another page. You configure each page to collect information from the end-user that is relevant for the conversational state represented by the page. For more information, see the Page guide. Corresponds to the JSON property currentPage



11461
11462
11463
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 11461

def current_page
  @current_page
end

#diagnostic_infoHash<String,Object>

Required. Input only. The diagnostic info output for the turn. Required to calculate the testing coverage. Corresponds to the JSON property diagnosticInfo

Returns:

  • (Hash<String,Object>)


11467
11468
11469
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 11467

def diagnostic_info
  @diagnostic_info
end

#differencesArray<Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1TestRunDifference>

Output only. If this is part of a result conversation turn, the list of differences between the original run and the replay for this output, if any. Corresponds to the JSON property differences



11473
11474
11475
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 11473

def differences
  @differences
end

#session_parametersHash<String,Object>

The session parameters available to the bot at this point. Corresponds to the JSON property sessionParameters

Returns:

  • (Hash<String,Object>)


11478
11479
11480
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 11478

def session_parameters
  @session_parameters
end

#statusGoogle::Apis::DialogflowV3::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property status



11488
11489
11490
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 11488

def status
  @status
end

#text_responsesArray<Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1ResponseMessageText>

The text responses from the agent for the turn. Corresponds to the JSON property textResponses



11493
11494
11495
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 11493

def text_responses
  @text_responses
end

#triggered_intentGoogle::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1Intent

An intent represents a user's intent to interact with a conversational agent. You can provide information for the Dialogflow API to use to match user input to an intent by adding training phrases (i.e., examples of user input) to your intent. Corresponds to the JSON property triggeredIntent



11501
11502
11503
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 11501

def triggered_intent
  @triggered_intent
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11508
11509
11510
11511
11512
11513
11514
11515
11516
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 11508

def update!(**args)
  @current_page = args[:current_page] if args.key?(:current_page)
  @diagnostic_info = args[:diagnostic_info] if args.key?(:diagnostic_info)
  @differences = args[:differences] if args.key?(:differences)
  @session_parameters = args[:session_parameters] if args.key?(:session_parameters)
  @status = args[:status] if args.key?(:status)
  @text_responses = args[:text_responses] if args.key?(:text_responses)
  @triggered_intent = args[:triggered_intent] if args.key?(:triggered_intent)
end