Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1DataStoreConnection

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

A data store connection. It represents a data store in Discovery Engine and the type of the contents it contains.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowCxV3beta1DataStoreConnection

Returns a new instance of GoogleCloudDialogflowCxV3beta1DataStoreConnection.



11563
11564
11565
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 11563

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_storeString

The full name of the referenced data store. Formats: projects/project/ locations/location/collections/collection/dataStores/data_store` projects/`project`/locations/`location`/dataStores/`data_store Corresponds to the JSON property dataStore

Returns:

  • (String)


11549
11550
11551
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 11549

def data_store
  @data_store
end

#data_store_typeString

The type of the connected data store. Corresponds to the JSON property dataStoreType

Returns:

  • (String)


11554
11555
11556
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 11554

def data_store_type
  @data_store_type
end

#document_processing_modeString

The document processing mode for the data store connection. Should only be set for PUBLIC_WEB and UNSTRUCTURED data stores. If not set it is considered as DOCUMENTS, as this is the legacy mode. Corresponds to the JSON property documentProcessingMode

Returns:

  • (String)


11561
11562
11563
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 11561

def document_processing_mode
  @document_processing_mode
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11568
11569
11570
11571
11572
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 11568

def update!(**args)
  @data_store = args[:data_store] if args.key?(:data_store)
  @data_store_type = args[:data_store_type] if args.key?(:data_store_type)
  @document_processing_mode = args[:document_processing_mode] if args.key?(:document_processing_mode)
end