Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1Environment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

Represents an environment for an agent. You can create multiple versions of your agent and publish them to separate environments. When you edit an agent, you are editing the draft agent. At any point, you can save the draft agent as an agent version, which is an immutable snapshot of your agent. When you save the draft agent, it is published to the default environment. When you create agent versions, you can publish them to custom environments. You can create a variety of custom environments for testing, development, production, etc.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowCxV3beta1Environment

Returns a new instance of GoogleCloudDialogflowCxV3beta1Environment.



11701
11702
11703
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 11701

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

The human-readable description of the environment. The maximum length is 500 characters. If exceeded, the request is rejected. Corresponds to the JSON property description

Returns:

  • (String)


11665
11666
11667
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 11665

def description
  @description
end

#display_nameString

Required. The human-readable name of the environment (unique in an agent). Limit of 64 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


11671
11672
11673
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 11671

def display_name
  @display_name
end

#nameString

The name of the environment. Format: projects//locations//agents// environments/. Corresponds to the JSON property name

Returns:

  • (String)


11677
11678
11679
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 11677

def name
  @name
end

#test_cases_configGoogle::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1EnvironmentTestCasesConfig

The configuration for continuous tests. Corresponds to the JSON property testCasesConfig



11682
11683
11684
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 11682

def test_cases_config
  @test_cases_config
end

#update_timeString

Output only. Update time of this environment. Corresponds to the JSON property updateTime

Returns:

  • (String)


11687
11688
11689
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 11687

def update_time
  @update_time
end

#version_configsArray<Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1EnvironmentVersionConfig>

A list of configurations for flow versions. You should include version configs for all flows that are reachable from Start Flow in the agent. Otherwise, an error will be returned. Corresponds to the JSON property versionConfigs



11694
11695
11696
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 11694

def version_configs
  @version_configs
end

#webhook_configGoogle::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1EnvironmentWebhookConfig

Configuration for webhooks. Corresponds to the JSON property webhookConfig



11699
11700
11701
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 11699

def webhook_config
  @webhook_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11706
11707
11708
11709
11710
11711
11712
11713
11714
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 11706

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @test_cases_config = args[:test_cases_config] if args.key?(:test_cases_config)
  @update_time = args[:update_time] if args.key?(:update_time)
  @version_configs = args[:version_configs] if args.key?(:version_configs)
  @webhook_config = args[:webhook_config] if args.key?(:webhook_config)
end