Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1Form

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

A form is a data model that groups related parameters that can be collected from the user. The process in which the agent prompts the user and collects parameter values from the user is called form filling. A form can be added to a page. When form filling is done, the filled parameters will be written to the session.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowCxV3beta1Form

Returns a new instance of GoogleCloudDialogflowCxV3beta1Form.



12074
12075
12076
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 12074

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#parametersArray<Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1FormParameter>

Parameters to collect from the user. Corresponds to the JSON property parameters



12072
12073
12074
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 12072

def parameters
  @parameters
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12079
12080
12081
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 12079

def update!(**args)
  @parameters = args[:parameters] if args.key?(:parameters)
end