Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1Fulfillment
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1Fulfillment
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
A fulfillment can do one or more of the following actions at the same time: * Generate rich message responses. * Set parameter values. * Call the webhook. Fulfillments can be called at various stages in the Page or Form lifecycle. For example, when a DetectIntentRequest drives a session to enter a new page, the page's entry fulfillment can add a static response to the QueryResult in the returning DetectIntentResponse, call the webhook (for example, to load user data from a database), or both.
Instance Attribute Summary collapse
-
#advanced_settings ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1AdvancedSettings
Hierarchical advanced settings for agent/flow/page/fulfillment/parameter.
-
#conditional_cases ⇒ Array<Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1FulfillmentConditionalCases>
Conditional cases for this fulfillment.
-
#enable_generative_fallback ⇒ Boolean
(also: #enable_generative_fallback?)
If the flag is true, the agent will utilize LLM to generate a text response.
-
#generators ⇒ Array<Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1FulfillmentGeneratorSettings>
A list of Generators to be called during this fulfillment.
-
#messages ⇒ Array<Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1ResponseMessage>
The list of rich message responses to present to the user.
-
#return_partial_responses ⇒ Boolean
(also: #return_partial_responses?)
Whether Dialogflow should return currently queued fulfillment response messages in streaming APIs.
-
#set_parameter_actions ⇒ Array<Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1FulfillmentSetParameterAction>
Set parameter values before executing the webhook.
-
#tag ⇒ String
The value of this field will be populated in the WebhookRequest
fulfillmentInfo.tagfield by Dialogflow when the associated webhook is called. -
#webhook ⇒ String
The webhook to call.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3beta1Fulfillment
constructor
A new instance of GoogleCloudDialogflowCxV3beta1Fulfillment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3beta1Fulfillment
Returns a new instance of GoogleCloudDialogflowCxV3beta1Fulfillment.
12291 12292 12293 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 12291 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advanced_settings ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1AdvancedSettings
Hierarchical advanced settings for agent/flow/page/fulfillment/parameter.
Settings exposed at lower level overrides the settings exposed at higher level.
Overriding occurs at the sub-setting level. For example, the
playback_interruption_settings at fulfillment level only overrides the
playback_interruption_settings at the agent level, leaving other settings at
the agent level unchanged. DTMF settings does not override each other. DTMF
settings set at different levels define DTMF detections running in parallel.
Hierarchy: Agent->Flow->Page->Fulfillment/Parameter.
Corresponds to the JSON property advancedSettings
12234 12235 12236 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 12234 def advanced_settings @advanced_settings end |
#conditional_cases ⇒ Array<Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1FulfillmentConditionalCases>
Conditional cases for this fulfillment.
Corresponds to the JSON property conditionalCases
12239 12240 12241 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 12239 def conditional_cases @conditional_cases end |
#enable_generative_fallback ⇒ Boolean Also known as: enable_generative_fallback?
If the flag is true, the agent will utilize LLM to generate a text response.
If LLM generation fails, the defined responses in the fulfillment will be
respected. This flag is only useful for fulfillments associated with no-match
event handlers.
Corresponds to the JSON property enableGenerativeFallback
12247 12248 12249 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 12247 def enable_generative_fallback @enable_generative_fallback end |
#generators ⇒ Array<Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1FulfillmentGeneratorSettings>
A list of Generators to be called during this fulfillment.
Corresponds to the JSON property generators
12253 12254 12255 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 12253 def generators @generators end |
#messages ⇒ Array<Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1ResponseMessage>
The list of rich message responses to present to the user.
Corresponds to the JSON property messages
12258 12259 12260 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 12258 def @messages end |
#return_partial_responses ⇒ Boolean Also known as: return_partial_responses?
Whether Dialogflow should return currently queued fulfillment response
messages in streaming APIs. If a webhook is specified, it happens before
Dialogflow invokes webhook. Warning: 1) This flag only affects streaming API.
Responses are still queued and returned once in non-streaming API. 2) The flag
can be enabled in any fulfillment but only the first 3 partial responses will
be returned. You may only want to apply it to fulfillments that have slow
webhooks.
Corresponds to the JSON property returnPartialResponses
12269 12270 12271 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 12269 def return_partial_responses @return_partial_responses end |
#set_parameter_actions ⇒ Array<Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1FulfillmentSetParameterAction>
Set parameter values before executing the webhook.
Corresponds to the JSON property setParameterActions
12275 12276 12277 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 12275 def set_parameter_actions @set_parameter_actions end |
#tag ⇒ String
The value of this field will be populated in the WebhookRequest
fulfillmentInfo.tag field by Dialogflow when the associated webhook is called.
The tag is typically used by the webhook service to identify which
fulfillment is being called, but it could be used for other purposes. This
field is required if webhook is specified.
Corresponds to the JSON property tag
12284 12285 12286 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 12284 def tag @tag end |
#webhook ⇒ String
The webhook to call. Format: projects//locations//agents//webhooks/.
Corresponds to the JSON property webhook
12289 12290 12291 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 12289 def webhook @webhook end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12296 12297 12298 12299 12300 12301 12302 12303 12304 12305 12306 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 12296 def update!(**args) @advanced_settings = args[:advanced_settings] if args.key?(:advanced_settings) @conditional_cases = args[:conditional_cases] if args.key?(:conditional_cases) @enable_generative_fallback = args[:enable_generative_fallback] if args.key?(:enable_generative_fallback) @generators = args[:generators] if args.key?(:generators) @messages = args[:messages] if args.key?(:messages) @return_partial_responses = args[:return_partial_responses] if args.key?(:return_partial_responses) @set_parameter_actions = args[:set_parameter_actions] if args.key?(:set_parameter_actions) @tag = args[:tag] if args.key?(:tag) @webhook = args[:webhook] if args.key?(:webhook) end |