Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1FulfillmentConditionalCasesCase

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

Each case has a Boolean condition. When it is evaluated to be True, the corresponding messages will be selected and evaluated recursively.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowCxV3beta1FulfillmentConditionalCasesCase

Returns a new instance of GoogleCloudDialogflowCxV3beta1FulfillmentConditionalCasesCase.



12347
12348
12349
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 12347

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#case_contentArray<Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1FulfillmentConditionalCasesCaseCaseContent>

A list of case content. Corresponds to the JSON property caseContent



12337
12338
12339
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 12337

def case_content
  @case_content
end

#conditionString

The condition to activate and select this case. Empty means the condition is always true. The condition is evaluated against form parameters or session parameters. See the conditions reference. Corresponds to the JSON property condition

Returns:

  • (String)


12345
12346
12347
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 12345

def condition
  @condition
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12352
12353
12354
12355
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 12352

def update!(**args)
  @case_content = args[:case_content] if args.key?(:case_content)
  @condition = args[:condition] if args.key?(:condition)
end