Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1FulfillmentConditionalCasesCaseCaseContent
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1FulfillmentConditionalCasesCaseCaseContent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
The list of messages or conditional cases to activate for this case.
Instance Attribute Summary collapse
-
#additional_cases ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1FulfillmentConditionalCases
A list of cascading if-else conditions.
-
#message ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1ResponseMessage
Represents a response message that can be returned by a conversational agent.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3beta1FulfillmentConditionalCasesCaseCaseContent
constructor
A new instance of GoogleCloudDialogflowCxV3beta1FulfillmentConditionalCasesCaseCaseContent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3beta1FulfillmentConditionalCasesCaseCaseContent
Returns a new instance of GoogleCloudDialogflowCxV3beta1FulfillmentConditionalCasesCaseCaseContent.
12384 12385 12386 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 12384 def initialize(**args) update!(**args) end |
Instance Attribute Details
#additional_cases ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1FulfillmentConditionalCases
A list of cascading if-else conditions. Cases are mutually exclusive. The
first one with a matching condition is selected, all the rest ignored.
Corresponds to the JSON property additionalCases
12366 12367 12368 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 12366 def additional_cases @additional_cases end |
#message ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1ResponseMessage
Represents a response message that can be returned by a conversational agent.
Response messages are also used for output audio synthesis. The approach is as
follows: * If at least one OutputAudioText response is present, then all
OutputAudioText responses are linearly concatenated, and the result is used
for output audio synthesis. * If the OutputAudioText responses are a mixture
of text and SSML, then the concatenated result is treated as SSML; otherwise,
the result is treated as either text or SSML as appropriate. The agent
designer should ideally use either text or SSML consistently throughout the
bot design. * Otherwise, all Text responses are linearly concatenated, and the
result is used for output audio synthesis. This approach allows for more
sophisticated user experience scenarios, where the text displayed to the user
may differ from what is heard.
Corresponds to the JSON property message
12382 12383 12384 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 12382 def @message end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12389 12390 12391 12392 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 12389 def update!(**args) @additional_cases = args[:additional_cases] if args.key?(:additional_cases) @message = args[:message] if args.key?(:message) end |