Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1FulfillmentGeneratorSettings
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1FulfillmentGeneratorSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
Generator settings used by the LLM to generate a text response.
Instance Attribute Summary collapse
-
#generator ⇒ String
Required.
-
#input_parameters ⇒ Hash<String,String>
Map from placeholder parameter in the Generator to corresponding session parameters.
-
#output_parameter ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3beta1FulfillmentGeneratorSettings
constructor
A new instance of GoogleCloudDialogflowCxV3beta1FulfillmentGeneratorSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3beta1FulfillmentGeneratorSettings
Returns a new instance of GoogleCloudDialogflowCxV3beta1FulfillmentGeneratorSettings.
12421 12422 12423 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 12421 def initialize(**args) update!(**args) end |
Instance Attribute Details
#generator ⇒ String
Required. The generator to call. Format: projects//locations//agents//
generators/.
Corresponds to the JSON property generator
12403 12404 12405 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 12403 def generator @generator end |
#input_parameters ⇒ Hash<String,String>
Map from placeholder parameter in the Generator to corresponding session
parameters. By default, Dialogflow uses the session parameter with the same
name to fill in the generator template. e.g. If there is a placeholder
parameter city in the Generator, Dialogflow default to fill in the $city
with $session.params.city. However, you may choose to fill $city with $
session.params.desination-city. - Map key: parameter ID - Map value: session
parameter name
Corresponds to the JSON property inputParameters
12414 12415 12416 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 12414 def input_parameters @input_parameters end |
#output_parameter ⇒ String
Required. Output parameter which should contain the generator response.
Corresponds to the JSON property outputParameter
12419 12420 12421 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 12419 def output_parameter @output_parameter end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12426 12427 12428 12429 12430 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 12426 def update!(**args) @generator = args[:generator] if args.key?(:generator) @input_parameters = args[:input_parameters] if args.key?(:input_parameters) @output_parameter = args[:output_parameter] if args.key?(:output_parameter) end |