Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1IntentTrainingPhrase

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

Represents an example that the agent is trained on to identify the intent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowCxV3beta1IntentTrainingPhrase

Returns a new instance of GoogleCloudDialogflowCxV3beta1IntentTrainingPhrase.



12979
12980
12981
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 12979

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. The unique identifier of the training phrase. Corresponds to the JSON property id

Returns:

  • (String)


12957
12958
12959
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 12957

def id
  @id
end

#partsArray<Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1IntentTrainingPhrasePart>

Required. The ordered list of training phrase parts. The parts are concatenated in order to form the training phrase. Note: The API does not automatically annotate training phrases like the Dialogflow Console does. Note: Do not forget to include whitespace at part boundaries, so the training phrase is well formatted when the parts are concatenated. If the training phrase does not need to be annotated with parameters, you just need a single part with only the Part.text field set. If you want to annotate the training phrase, you must create multiple parts, where the fields of each part are populated in one of two ways: - Part.text is set to a part of the phrase that has no parameters. - Part.text is set to a part of the phrase that you want to annotate, and the parameter_id field is set. Corresponds to the JSON property parts



12972
12973
12974
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 12972

def parts
  @parts
end

#repeat_countFixnum

Indicates how many times this example was added to the intent. Corresponds to the JSON property repeatCount

Returns:

  • (Fixnum)


12977
12978
12979
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 12977

def repeat_count
  @repeat_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12984
12985
12986
12987
12988
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 12984

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @parts = args[:parts] if args.key?(:parts)
  @repeat_count = args[:repeat_count] if args.key?(:repeat_count)
end