Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1IntentTrainingPhrasePart
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1IntentTrainingPhrasePart
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
Represents a part of a training phrase.
Instance Attribute Summary collapse
-
#parameter_id ⇒ String
The parameter used to annotate this part of the training phrase.
-
#text ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3beta1IntentTrainingPhrasePart
constructor
A new instance of GoogleCloudDialogflowCxV3beta1IntentTrainingPhrasePart.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3beta1IntentTrainingPhrasePart
Returns a new instance of GoogleCloudDialogflowCxV3beta1IntentTrainingPhrasePart.
13006 13007 13008 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13006 def initialize(**args) update!(**args) end |
Instance Attribute Details
#parameter_id ⇒ String
The parameter used to annotate this part of the training phrase. This field is
required for annotated parts of the training phrase.
Corresponds to the JSON property parameterId
12999 13000 13001 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 12999 def parameter_id @parameter_id end |
#text ⇒ String
Required. The text for this part.
Corresponds to the JSON property text
13004 13005 13006 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13004 def text @text end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13011 13012 13013 13014 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13011 def update!(**args) @parameter_id = args[:parameter_id] if args.key?(:parameter_id) @text = args[:text] if args.key?(:text) end |