Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1KnowledgeConnectorSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

The Knowledge Connector settings for this page or flow. This includes information such as the attached Knowledge Bases, and the way to execute fulfillment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowCxV3beta1KnowledgeConnectorSettings

Returns a new instance of GoogleCloudDialogflowCxV3beta1KnowledgeConnectorSettings.



13057
13058
13059
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13057

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_store_connectionsArray<Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1DataStoreConnection>

Optional. List of related data store connections. Corresponds to the JSON property dataStoreConnections



13026
13027
13028
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13026

def data_store_connections
  @data_store_connections
end

#enabledBoolean Also known as: enabled?

Whether Knowledge Connector is enabled or not. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


13031
13032
13033
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13031

def enabled
  @enabled
end

#target_flowString

The target flow to transition to. Format: projects//locations//agents//flows/ . Corresponds to the JSON property targetFlow

Returns:

  • (String)


13038
13039
13040
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13038

def target_flow
  @target_flow
end

#target_pageString

The target page to transition to. Format: projects//locations//agents//flows// pages/. Corresponds to the JSON property targetPage

Returns:

  • (String)


13044
13045
13046
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13044

def target_page
  @target_page
end

#trigger_fulfillmentGoogle::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1Fulfillment

A fulfillment can do one or more of the following actions at the same time: * Generate rich message responses. * Set parameter values. * Call the webhook. Fulfillments can be called at various stages in the Page or Form lifecycle. For example, when a DetectIntentRequest drives a session to enter a new page, the page's entry fulfillment can add a static response to the QueryResult in the returning DetectIntentResponse, call the webhook (for example, to load user data from a database), or both. Corresponds to the JSON property triggerFulfillment



13055
13056
13057
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13055

def trigger_fulfillment
  @trigger_fulfillment
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13062
13063
13064
13065
13066
13067
13068
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13062

def update!(**args)
  @data_store_connections = args[:data_store_connections] if args.key?(:data_store_connections)
  @enabled = args[:enabled] if args.key?(:enabled)
  @target_flow = args[:target_flow] if args.key?(:target_flow)
  @target_page = args[:target_page] if args.key?(:target_page)
  @trigger_fulfillment = args[:trigger_fulfillment] if args.key?(:trigger_fulfillment)
end