Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1LanguageInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

Represents the language information of the request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowCxV3beta1LanguageInfo

Returns a new instance of GoogleCloudDialogflowCxV3beta1LanguageInfo.



13090
13091
13092
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13090

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#confidence_scoreFloat

The confidence score of the detected language between 0 and 1. Corresponds to the JSON property confidenceScore

Returns:

  • (Float)


13078
13079
13080
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13078

def confidence_score
  @confidence_score
end

#input_language_codeString

The language code specified in the original request. Corresponds to the JSON property inputLanguageCode

Returns:

  • (String)


13083
13084
13085
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13083

def input_language_code
  @input_language_code
end

#resolved_language_codeString

The language code detected for this request based on the user conversation. Corresponds to the JSON property resolvedLanguageCode

Returns:

  • (String)


13088
13089
13090
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13088

def resolved_language_code
  @resolved_language_code
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13095
13096
13097
13098
13099
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13095

def update!(**args)
  @confidence_score = args[:confidence_score] if args.key?(:confidence_score)
  @input_language_code = args[:input_language_code] if args.key?(:input_language_code)
  @resolved_language_code = args[:resolved_language_code] if args.key?(:resolved_language_code)
end