Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1PageInfoFormInfoParameterInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

Represents parameter information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowCxV3beta1PageInfoFormInfoParameterInfo

Returns a new instance of GoogleCloudDialogflowCxV3beta1PageInfoFormInfoParameterInfo.



13321
13322
13323
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13321

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Always present for WebhookRequest. Required for WebhookResponse. The human- readable name of the parameter, unique within the form. This field cannot be modified by the webhook. Corresponds to the JSON property displayName

Returns:

  • (String)


13290
13291
13292
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13290

def display_name
  @display_name
end

#just_collectedBoolean Also known as: just_collected?

Optional for WebhookRequest. Ignored for WebhookResponse. Indicates if the parameter value was just collected on the last conversation turn. Corresponds to the JSON property justCollected

Returns:

  • (Boolean)


13296
13297
13298
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13296

def just_collected
  @just_collected
end

#requiredBoolean Also known as: required?

Optional for both WebhookRequest and WebhookResponse. Indicates whether the parameter is required. Optional parameters will not trigger prompts; however, they are filled if the user specifies them. Required parameters must be filled before form filling concludes. Corresponds to the JSON property required

Returns:

  • (Boolean)


13305
13306
13307
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13305

def required
  @required
end

#stateString

Always present for WebhookRequest. Required for WebhookResponse. The state of the parameter. This field can be set to INVALID by the webhook to invalidate the parameter; other values set by the webhook will be ignored. Corresponds to the JSON property state

Returns:

  • (String)


13313
13314
13315
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13313

def state
  @state
end

#valueObject

Optional for both WebhookRequest and WebhookResponse. The value of the parameter. This field can be set by the webhook to change the parameter value. Corresponds to the JSON property value

Returns:

  • (Object)


13319
13320
13321
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13319

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13326
13327
13328
13329
13330
13331
13332
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13326

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @just_collected = args[:just_collected] if args.key?(:just_collected)
  @required = args[:required] if args.key?(:required)
  @state = args[:state] if args.key?(:state)
  @value = args[:value] if args.key?(:value)
end