Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1QueryInput

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

Represents the query input. It can contain one of: 1. A conversational query in the form of text. 2. An intent query that specifies which intent to trigger.

  1. Natural language speech audio to be processed. 4. An event to be triggered.
  2. DTMF digits to invoke an intent and fill in parameter value. 6. The results of a tool executed by the client.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowCxV3beta1QueryInput

Returns a new instance of GoogleCloudDialogflowCxV3beta1QueryInput.



13382
13383
13384
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13382

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#audioGoogle::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1AudioInput

Represents the natural speech audio to be processed. Corresponds to the JSON property audio



13346
13347
13348
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13346

def audio
  @audio
end

#dtmfGoogle::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1DtmfInput

Represents the input for dtmf event. Corresponds to the JSON property dtmf



13351
13352
13353
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13351

def dtmf
  @dtmf
end

#eventGoogle::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1EventInput

Represents the event to trigger. Corresponds to the JSON property event



13356
13357
13358
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13356

def event
  @event
end

#intentGoogle::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1IntentInput

Represents the intent to trigger programmatically rather than as a result of natural language processing. Corresponds to the JSON property intent



13362
13363
13364
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13362

def intent
  @intent
end

#language_codeString

Required. The language of the input. See Language Support for a list of the currently supported language codes. Note that queries in the same session do not necessarily need to specify the same language. Corresponds to the JSON property languageCode

Returns:

  • (String)


13370
13371
13372
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13370

def language_code
  @language_code
end

#textGoogle::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1TextInput

Represents the natural language text to be processed. Corresponds to the JSON property text



13375
13376
13377
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13375

def text
  @text
end

#tool_call_resultGoogle::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1ToolCallResult

The result of calling a tool's action that has been executed by the client. Corresponds to the JSON property toolCallResult



13380
13381
13382
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13380

def tool_call_result
  @tool_call_result
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13387
13388
13389
13390
13391
13392
13393
13394
13395
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13387

def update!(**args)
  @audio = args[:audio] if args.key?(:audio)
  @dtmf = args[:dtmf] if args.key?(:dtmf)
  @event = args[:event] if args.key?(:event)
  @intent = args[:intent] if args.key?(:intent)
  @language_code = args[:language_code] if args.key?(:language_code)
  @text = args[:text] if args.key?(:text)
  @tool_call_result = args[:tool_call_result] if args.key?(:tool_call_result)
end