Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1ResponseMessageEndInteraction

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

Indicates that interaction with the Dialogflow agent has ended. This message is generated by Dialogflow only and not supposed to be defined by the user.

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowCxV3beta1ResponseMessageEndInteraction

Returns a new instance of GoogleCloudDialogflowCxV3beta1ResponseMessageEndInteraction.



13550
13551
13552
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13550

def initialize(**args)
   update!(**args)
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13555
13556
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13555

def update!(**args)
end