Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1ResponseMessageMixedAudio

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

Represents an audio message that is composed of both segments synthesized from the Dialogflow agent prompts and ones hosted externally at the specified URIs. The external URIs are specified via play_audio. This message is generated by Dialogflow only and not supposed to be defined by the user.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowCxV3beta1ResponseMessageMixedAudio

Returns a new instance of GoogleCloudDialogflowCxV3beta1ResponseMessageMixedAudio.



13612
13613
13614
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13612

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#segmentsArray<Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1ResponseMessageMixedAudioSegment>

Segments this audio response is composed of. Corresponds to the JSON property segments



13610
13611
13612
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13610

def segments
  @segments
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13617
13618
13619
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13617

def update!(**args)
  @segments = args[:segments] if args.key?(:segments)
end