Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1ResponseMessageMixedAudioSegment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

Represents one segment of audio.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowCxV3beta1ResponseMessageMixedAudioSegment

Returns a new instance of GoogleCloudDialogflowCxV3beta1ResponseMessageMixedAudioSegment.



13646
13647
13648
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13646

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allow_playback_interruptionBoolean Also known as: allow_playback_interruption?

Output only. Whether the playback of this segment can be interrupted by the end user's speech and the client should then start the next Dialogflow request. Corresponds to the JSON property allowPlaybackInterruption

Returns:

  • (Boolean)


13630
13631
13632
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13630

def allow_playback_interruption
  @allow_playback_interruption
end

#audioString

Raw audio synthesized from the Dialogflow agent's response using the output config specified in the request. Corresponds to the JSON property audio NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


13638
13639
13640
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13638

def audio
  @audio
end

#uriString

Client-specific URI that points to an audio clip accessible to the client. Dialogflow does not impose any validation on it. Corresponds to the JSON property uri

Returns:

  • (String)


13644
13645
13646
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13644

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13651
13652
13653
13654
13655
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13651

def update!(**args)
  @allow_playback_interruption = args[:allow_playback_interruption] if args.key?(:allow_playback_interruption)
  @audio = args[:audio] if args.key?(:audio)
  @uri = args[:uri] if args.key?(:uri)
end