Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1ResponseMessageOutputAudioText

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

A text or ssml response that is preferentially used for TTS output audio synthesis, as described in the comment on the ResponseMessage message.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowCxV3beta1ResponseMessageOutputAudioText

Returns a new instance of GoogleCloudDialogflowCxV3beta1ResponseMessageOutputAudioText.



13681
13682
13683
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13681

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allow_playback_interruptionBoolean Also known as: allow_playback_interruption?

Output only. Whether the playback of this message can be interrupted by the end user's speech and the client can then starts the next Dialogflow request. Corresponds to the JSON property allowPlaybackInterruption

Returns:

  • (Boolean)


13667
13668
13669
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13667

def allow_playback_interruption
  @allow_playback_interruption
end

#ssmlString

The SSML text to be synthesized. For more information, see SSML. Corresponds to the JSON property ssml

Returns:

  • (String)


13674
13675
13676
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13674

def ssml
  @ssml
end

#textString

The raw text to be synthesized. Corresponds to the JSON property text

Returns:

  • (String)


13679
13680
13681
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13679

def text
  @text
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13686
13687
13688
13689
13690
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13686

def update!(**args)
  @allow_playback_interruption = args[:allow_playback_interruption] if args.key?(:allow_playback_interruption)
  @ssml = args[:ssml] if args.key?(:ssml)
  @text = args[:text] if args.key?(:text)
end