Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1ResponseMessageText

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

The text response message.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowCxV3beta1ResponseMessageText

Returns a new instance of GoogleCloudDialogflowCxV3beta1ResponseMessageText.



13759
13760
13761
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13759

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allow_playback_interruptionBoolean Also known as: allow_playback_interruption?

Output only. Whether the playback of this message can be interrupted by the end user's speech and the client can then starts the next Dialogflow request. Corresponds to the JSON property allowPlaybackInterruption

Returns:

  • (Boolean)


13750
13751
13752
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13750

def allow_playback_interruption
  @allow_playback_interruption
end

#textArray<String>

Required. A collection of text response variants. If multiple variants are defined, only one text response variant is returned at runtime. Corresponds to the JSON property text

Returns:

  • (Array<String>)


13757
13758
13759
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13757

def text
  @text
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13764
13765
13766
13767
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13764

def update!(**args)
  @allow_playback_interruption = args[:allow_playback_interruption] if args.key?(:allow_playback_interruption)
  @text = args[:text] if args.key?(:text)
end