Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1TestCase
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1TestCase
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
Represents a test case.
Instance Attribute Summary collapse
-
#creation_time ⇒ String
Output only.
-
#display_name ⇒ String
Required.
-
#last_test_result ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1TestCaseResult
Represents a result from running a test case in an agent environment.
-
#name ⇒ String
The unique identifier of the test case.
-
#notes ⇒ String
Additional freeform notes about the test case.
-
#tags ⇒ Array<String>
Tags are short descriptions that users may apply to test cases for organizational and filtering purposes.
-
#test_case_conversation_turns ⇒ Array<Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1ConversationTurn>
The conversation turns uttered when the test case was created, in chronological order.
-
#test_config ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1TestConfig
Represents configurations for a test case.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3beta1TestCase
constructor
A new instance of GoogleCloudDialogflowCxV3beta1TestCase.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3beta1TestCase
Returns a new instance of GoogleCloudDialogflowCxV3beta1TestCase.
13925 13926 13927 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13925 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_time ⇒ String
Output only. When the test was created.
Corresponds to the JSON property creationTime
13881 13882 13883 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13881 def creation_time @creation_time end |
#display_name ⇒ String
Required. The human-readable name of the test case, unique within the agent.
Limit of 200 characters.
Corresponds to the JSON property displayName
13887 13888 13889 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13887 def display_name @display_name end |
#last_test_result ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1TestCaseResult
Represents a result from running a test case in an agent environment.
Corresponds to the JSON property lastTestResult
13892 13893 13894 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13892 def last_test_result @last_test_result end |
#name ⇒ String
The unique identifier of the test case. TestCases.CreateTestCase will populate
the name automatically. Otherwise use format: projects//locations//agents//
testCases/.
Corresponds to the JSON property name
13899 13900 13901 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13899 def name @name end |
#notes ⇒ String
Additional freeform notes about the test case. Limit of 400 characters.
Corresponds to the JSON property notes
13904 13905 13906 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13904 def notes @notes end |
#tags ⇒ Array<String>
Tags are short descriptions that users may apply to test cases for
organizational and filtering purposes. Each tag should start with "#" and has
a limit of 30 characters.
Corresponds to the JSON property tags
13911 13912 13913 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13911 def @tags end |
#test_case_conversation_turns ⇒ Array<Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1ConversationTurn>
The conversation turns uttered when the test case was created, in
chronological order. These include the canonical set of agent utterances that
should occur when the agent is working properly.
Corresponds to the JSON property testCaseConversationTurns
13918 13919 13920 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13918 def test_case_conversation_turns @test_case_conversation_turns end |
#test_config ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1TestConfig
Represents configurations for a test case.
Corresponds to the JSON property testConfig
13923 13924 13925 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13923 def test_config @test_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13930 13931 13932 13933 13934 13935 13936 13937 13938 13939 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13930 def update!(**args) @creation_time = args[:creation_time] if args.key?(:creation_time) @display_name = args[:display_name] if args.key?(:display_name) @last_test_result = args[:last_test_result] if args.key?(:last_test_result) @name = args[:name] if args.key?(:name) @notes = args[:notes] if args.key?(:notes) @tags = args[:tags] if args.key?(:tags) @test_case_conversation_turns = args[:test_case_conversation_turns] if args.key?(:test_case_conversation_turns) @test_config = args[:test_config] if args.key?(:test_config) end |