Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1TestCaseError

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

Error info for importing a test.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowCxV3beta1TestCaseError

Returns a new instance of GoogleCloudDialogflowCxV3beta1TestCaseError.



13961
13962
13963
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13961

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#statusGoogle::Apis::DialogflowV3::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property status



13954
13955
13956
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13954

def status
  @status
end

#test_caseGoogle::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1TestCase

Represents a test case. Corresponds to the JSON property testCase



13959
13960
13961
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13959

def test_case
  @test_case
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13966
13967
13968
13969
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13966

def update!(**args)
  @status = args[:status] if args.key?(:status)
  @test_case = args[:test_case] if args.key?(:test_case)
end