Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1TestConfig
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1TestConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
Represents configurations for a test case.
Instance Attribute Summary collapse
-
#flow ⇒ String
Flow name to start the test case with.
-
#page ⇒ String
The page to start the test case with.
-
#tracking_parameters ⇒ Array<String>
Session parameters to be compared when calculating differences.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3beta1TestConfig
constructor
A new instance of GoogleCloudDialogflowCxV3beta1TestConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3beta1TestConfig
Returns a new instance of GoogleCloudDialogflowCxV3beta1TestConfig.
14043 14044 14045 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14043 def initialize(**args) update!(**args) end |
Instance Attribute Details
#flow ⇒ String
Flow name to start the test case with. Format: projects//locations//agents//
flows/. Only one of flow and page should be set to indicate the starting
point of the test case. If neither is set, the test case will start with start
page on the default start flow.
Corresponds to the JSON property flow
14028 14029 14030 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14028 def flow @flow end |
#page ⇒ String
The page to start the test case with. Format: projects//locations//agents//
flows//pages/. Only one of flow and page should be set to indicate the
starting point of the test case. If neither is set, the test case will start
with start page on the default start flow.
Corresponds to the JSON property page
14036 14037 14038 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14036 def page @page end |
#tracking_parameters ⇒ Array<String>
Session parameters to be compared when calculating differences.
Corresponds to the JSON property trackingParameters
14041 14042 14043 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14041 def tracking_parameters @tracking_parameters end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14048 14049 14050 14051 14052 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14048 def update!(**args) @flow = args[:flow] if args.key?(:flow) @page = args[:page] if args.key?(:page) @tracking_parameters = args[:tracking_parameters] if args.key?(:tracking_parameters) end |