Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1TurnSignals

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

Collection of all signals that were extracted for a single turn of the conversation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowCxV3beta1TurnSignals

Returns a new instance of GoogleCloudDialogflowCxV3beta1TurnSignals.



14366
14367
14368
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14366

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_escalatedBoolean Also known as: agent_escalated?

Whether agent responded with LiveAgentHandoff fulfillment. Corresponds to the JSON property agentEscalated

Returns:

  • (Boolean)


14311
14312
14313
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14311

def agent_escalated
  @agent_escalated
end

#dtmf_usedBoolean Also known as: dtmf_used?

Whether user was using DTMF input. Corresponds to the JSON property dtmfUsed

Returns:

  • (Boolean)


14317
14318
14319
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14317

def dtmf_used
  @dtmf_used
end

#failure_reasonsArray<String>

Failure reasons of the turn. Corresponds to the JSON property failureReasons

Returns:

  • (Array<String>)


14323
14324
14325
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14323

def failure_reasons
  @failure_reasons
end

#no_matchBoolean Also known as: no_match?

Whether NLU predicted NO_MATCH. Corresponds to the JSON property noMatch

Returns:

  • (Boolean)


14328
14329
14330
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14328

def no_match
  @no_match
end

#no_user_inputBoolean Also known as: no_user_input?

Whether user provided no input. Corresponds to the JSON property noUserInput

Returns:

  • (Boolean)


14334
14335
14336
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14334

def no_user_input
  @no_user_input
end

#reached_end_pageBoolean Also known as: reached_end_page?

Whether turn resulted in End Session page. Corresponds to the JSON property reachedEndPage

Returns:

  • (Boolean)


14340
14341
14342
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14340

def reached_end_page
  @reached_end_page
end

#sentiment_magnitudeFloat

Sentiment magnitude of the user utterance if sentiment was enabled. Corresponds to the JSON property sentimentMagnitude

Returns:

  • (Float)


14347
14348
14349
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14347

def sentiment_magnitude
  @sentiment_magnitude
end

#sentiment_scoreFloat

Sentiment score of the user utterance if sentiment was enabled. Corresponds to the JSON property sentimentScore

Returns:

  • (Float)


14353
14354
14355
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14353

def sentiment_score
  @sentiment_score
end

#user_escalatedBoolean Also known as: user_escalated?

Whether user was specifically asking for a live agent. Corresponds to the JSON property userEscalated

Returns:

  • (Boolean)


14358
14359
14360
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14358

def user_escalated
  @user_escalated
end

#webhook_statusesArray<String>

Human-readable statuses of the webhooks triggered during this turn. Corresponds to the JSON property webhookStatuses

Returns:

  • (Array<String>)


14364
14365
14366
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14364

def webhook_statuses
  @webhook_statuses
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14371
14372
14373
14374
14375
14376
14377
14378
14379
14380
14381
14382
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14371

def update!(**args)
  @agent_escalated = args[:agent_escalated] if args.key?(:agent_escalated)
  @dtmf_used = args[:dtmf_used] if args.key?(:dtmf_used)
  @failure_reasons = args[:failure_reasons] if args.key?(:failure_reasons)
  @no_match = args[:no_match] if args.key?(:no_match)
  @no_user_input = args[:no_user_input] if args.key?(:no_user_input)
  @reached_end_page = args[:reached_end_page] if args.key?(:reached_end_page)
  @sentiment_magnitude = args[:sentiment_magnitude] if args.key?(:sentiment_magnitude)
  @sentiment_score = args[:sentiment_score] if args.key?(:sentiment_score)
  @user_escalated = args[:user_escalated] if args.key?(:user_escalated)
  @webhook_statuses = args[:webhook_statuses] if args.key?(:webhook_statuses)
end