Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1Webhook

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

Webhooks host the developer's business logic. During a session, webhooks allow the developer to use the data extracted by Dialogflow's natural language processing to generate dynamic responses, validate collected data, or trigger actions on the backend.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowCxV3beta1Webhook

Returns a new instance of GoogleCloudDialogflowCxV3beta1Webhook.



14428
14429
14430
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14428

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#disabledBoolean Also known as: disabled?

Indicates whether the webhook is disabled. Corresponds to the JSON property disabled

Returns:

  • (Boolean)


14395
14396
14397
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14395

def disabled
  @disabled
end

#display_nameString

Required. The human-readable name of the webhook, unique within the agent. Corresponds to the JSON property displayName

Returns:

  • (String)


14401
14402
14403
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14401

def display_name
  @display_name
end

#generic_web_serviceGoogle::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1WebhookGenericWebService

Represents configuration for a generic web service. Corresponds to the JSON property genericWebService



14406
14407
14408
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14406

def generic_web_service
  @generic_web_service
end

#nameString

The unique identifier of the webhook. Required for the Webhooks.UpdateWebhook method. Webhooks.CreateWebhook populates the name automatically. Format: projects//locations//agents//webhooks/. Corresponds to the JSON property name

Returns:

  • (String)


14413
14414
14415
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14413

def name
  @name
end

#service_directoryGoogle::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1WebhookServiceDirectoryConfig

Represents configuration for a Service Directory service. Corresponds to the JSON property serviceDirectory



14419
14420
14421
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14419

def service_directory
  @service_directory
end

#timeoutString

Webhook execution timeout. Execution is considered failed if Dialogflow doesn' t receive a response from webhook at the end of the timeout period. Defaults to 5 seconds, maximum allowed timeout is 30 seconds. Corresponds to the JSON property timeout

Returns:

  • (String)


14426
14427
14428
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14426

def timeout
  @timeout
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14433
14434
14435
14436
14437
14438
14439
14440
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14433

def update!(**args)
  @disabled = args[:disabled] if args.key?(:disabled)
  @display_name = args[:display_name] if args.key?(:display_name)
  @generic_web_service = args[:generic_web_service] if args.key?(:generic_web_service)
  @name = args[:name] if args.key?(:name)
  @service_directory = args[:service_directory] if args.key?(:service_directory)
  @timeout = args[:timeout] if args.key?(:timeout)
end