Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1WebhookGenericWebService

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

Represents configuration for a generic web service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowCxV3beta1WebhookGenericWebService

Returns a new instance of GoogleCloudDialogflowCxV3beta1WebhookGenericWebService.



14538
14539
14540
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14538

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allowed_ca_certsArray<String>

Optional. Specifies a list of allowed custom CA certificates (in DER format) for HTTPS verification. This overrides the default SSL trust store. If this is empty or unspecified, Dialogflow will use Google's default trust store to verify certificates. N.B. Make sure the HTTPS server certificates are signed with "subject alt name". For instance a certificate can be self-signed using the following command, openssl x509 -req -days 200 -in example.com.csr \ - signkey example.com.key \ -out example.com.crt \ -extfile <(printf "\ nsubjectAltName='DNS:www.example.com'") Corresponds to the JSON property allowedCaCerts

Returns:

  • (Array<String>)


14457
14458
14459
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14457

def allowed_ca_certs
  @allowed_ca_certs
end

#http_methodString

Optional. HTTP method for the flexible webhook calls. Standard webhook always uses POST. Corresponds to the JSON property httpMethod

Returns:

  • (String)


14463
14464
14465
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14463

def http_method
  @http_method
end

#oauth_configGoogle::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1WebhookGenericWebServiceOAuthConfig

Represents configuration of OAuth client credential flow for 3rd party API authentication. Corresponds to the JSON property oauthConfig



14469
14470
14471
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14469

def oauth_config
  @oauth_config
end

#parameter_mappingHash<String,String>

Optional. Maps the values extracted from specific fields of the flexible webhook response into session parameters. - Key: session parameter name - Value: field path in the webhook response Corresponds to the JSON property parameterMapping

Returns:

  • (Hash<String,String>)


14476
14477
14478
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14476

def parameter_mapping
  @parameter_mapping
end

#passwordString

The password for HTTP Basic authentication. Corresponds to the JSON property password

Returns:

  • (String)


14481
14482
14483
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14481

def password
  @password
end

#request_bodyString

Optional. Defines a custom JSON object as request body to send to flexible webhook. Corresponds to the JSON property requestBody

Returns:

  • (String)


14487
14488
14489
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14487

def request_body
  @request_body
end

#request_headersHash<String,String>

The HTTP request headers to send together with webhook requests. Corresponds to the JSON property requestHeaders

Returns:

  • (Hash<String,String>)


14492
14493
14494
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14492

def request_headers
  @request_headers
end

#secret_version_for_username_passwordString

Optional. The SecretManager secret version resource storing the username: password pair for HTTP Basic authentication. Format: projects/project/ secrets/secret/versions/version` Corresponds to the JSON propertysecretVersionForUsernamePassword`

Returns:

  • (String)


14499
14500
14501
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14499

def secret_version_for_username_password
  @secret_version_for_username_password
end

#secret_versions_for_request_headersHash<String,Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1WebhookGenericWebServiceSecretVersionHeaderValue>

Optional. The HTTP request headers to send together with webhook requests. Header values are stored in SecretManager secret versions. When the same header name is specified in both request_headers and secret_versions_for_request_headers, the value in secret_versions_for_request_headers will be used. Corresponds to the JSON property secretVersionsForRequestHeaders



14508
14509
14510
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14508

def secret_versions_for_request_headers
  @secret_versions_for_request_headers
end

#service_account_auth_configGoogle::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1WebhookGenericWebServiceServiceAccountAuthConfig

Configuration for authentication using a service account. Corresponds to the JSON property serviceAccountAuthConfig



14513
14514
14515
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14513

def 
  @service_account_auth_config
end

#service_agent_authString

Optional. Indicate the auth token type generated from the Diglogflow service agent. The generated token is sent in the Authorization header. Corresponds to the JSON property serviceAgentAuth

Returns:

  • (String)


14520
14521
14522
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14520

def service_agent_auth
  @service_agent_auth
end

#uriString

Required. The webhook URI for receiving POST requests. It must use https protocol. Corresponds to the JSON property uri

Returns:

  • (String)


14526
14527
14528
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14526

def uri
  @uri
end

#usernameString

The user name for HTTP Basic authentication. Corresponds to the JSON property username

Returns:

  • (String)


14531
14532
14533
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14531

def username
  @username
end

#webhook_typeString

Optional. Type of the webhook. Corresponds to the JSON property webhookType

Returns:

  • (String)


14536
14537
14538
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14536

def webhook_type
  @webhook_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14543
14544
14545
14546
14547
14548
14549
14550
14551
14552
14553
14554
14555
14556
14557
14558
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14543

def update!(**args)
  @allowed_ca_certs = args[:allowed_ca_certs] if args.key?(:allowed_ca_certs)
  @http_method = args[:http_method] if args.key?(:http_method)
  @oauth_config = args[:oauth_config] if args.key?(:oauth_config)
  @parameter_mapping = args[:parameter_mapping] if args.key?(:parameter_mapping)
  @password = args[:password] if args.key?(:password)
  @request_body = args[:request_body] if args.key?(:request_body)
  @request_headers = args[:request_headers] if args.key?(:request_headers)
  @secret_version_for_username_password = args[:secret_version_for_username_password] if args.key?(:secret_version_for_username_password)
  @secret_versions_for_request_headers = args[:secret_versions_for_request_headers] if args.key?(:secret_versions_for_request_headers)
  @service_account_auth_config = args[:service_account_auth_config] if args.key?(:service_account_auth_config)
  @service_agent_auth = args[:service_agent_auth] if args.key?(:service_agent_auth)
  @uri = args[:uri] if args.key?(:uri)
  @username = args[:username] if args.key?(:username)
  @webhook_type = args[:webhook_type] if args.key?(:webhook_type)
end