Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1WebhookGenericWebServiceServiceAccountAuthConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

Configuration for authentication using a service account.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowCxV3beta1WebhookGenericWebServiceServiceAccountAuthConfig

Returns a new instance of GoogleCloudDialogflowCxV3beta1WebhookGenericWebServiceServiceAccountAuthConfig.



14643
14644
14645
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14643

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#service_accountString

Required. The email address of the service account used to authenticate the webhook call. Dialogflow uses this service account to exchange an access token and the access token is then sent in the Authorization header of the webhook request. The service account must have the roles/iam. serviceAccountTokenCreator role granted to the Dialogflow service agent. Corresponds to the JSON property serviceAccount

Returns:

  • (String)


14641
14642
14643
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14641

def 
  @service_account
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14648
14649
14650
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14648

def update!(**args)
  @service_account = args[:service_account] if args.key?(:service_account)
end