Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1WebhookRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

The request message for a webhook call. The request is sent as a JSON object and the field names will be presented in camel cases. You may see undocumented fields in an actual request. These fields are used internally by Dialogflow and should be ignored.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowCxV3beta1WebhookRequest

Returns a new instance of GoogleCloudDialogflowCxV3beta1WebhookRequest.



14741
14742
14743
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14741

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#detect_intent_response_idString

Always present. The unique identifier of the DetectIntentResponse that will be returned to the API caller. Corresponds to the JSON property detectIntentResponseId

Returns:

  • (String)


14664
14665
14666
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14664

def detect_intent_response_id
  @detect_intent_response_id
end

#dtmf_digitsString

If DTMF was provided as input, this field will contain the DTMF digits. Corresponds to the JSON property dtmfDigits

Returns:

  • (String)


14669
14670
14671
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14669

def dtmf_digits
  @dtmf_digits
end

#fulfillment_infoGoogle::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1WebhookRequestFulfillmentInfo

Represents fulfillment information communicated to the webhook. Corresponds to the JSON property fulfillmentInfo



14674
14675
14676
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14674

def fulfillment_info
  @fulfillment_info
end

#intent_infoGoogle::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1WebhookRequestIntentInfo

Represents intent information communicated to the webhook. Corresponds to the JSON property intentInfo



14679
14680
14681
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14679

def intent_info
  @intent_info
end

#language_codeString

The language code specified in the original request. Corresponds to the JSON property languageCode

Returns:

  • (String)


14684
14685
14686
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14684

def language_code
  @language_code
end

#language_infoGoogle::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1LanguageInfo

Represents the language information of the request. Corresponds to the JSON property languageInfo



14689
14690
14691
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14689

def language_info
  @language_info
end

#messagesArray<Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1ResponseMessage>

The list of rich message responses to present to the user. Webhook can choose to append or replace this list in WebhookResponse.fulfillment_response; Corresponds to the JSON property messages



14695
14696
14697
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14695

def messages
  @messages
end

#page_infoGoogle::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1PageInfo

Represents page information communicated to and from the webhook. Corresponds to the JSON property pageInfo



14700
14701
14702
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14700

def page_info
  @page_info
end

#payloadHash<String,Object>

Custom data set in QueryParameters.payload. Corresponds to the JSON property payload

Returns:

  • (Hash<String,Object>)


14705
14706
14707
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14705

def payload
  @payload
end

#sentiment_analysis_resultGoogle::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1WebhookRequestSentimentAnalysisResult

Represents the result of sentiment analysis. Corresponds to the JSON property sentimentAnalysisResult



14710
14711
14712
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14710

def sentiment_analysis_result
  @sentiment_analysis_result
end

#session_infoGoogle::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1SessionInfo

Represents session information communicated to and from the webhook. Corresponds to the JSON property sessionInfo



14715
14716
14717
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14715

def session_info
  @session_info
end

#textString

If natural language text was provided as input, this field will contain a copy of the text. Corresponds to the JSON property text

Returns:

  • (String)


14721
14722
14723
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14721

def text
  @text
end

#transcriptString

If natural language speech audio was provided as input, this field will contain the transcript for the audio. Corresponds to the JSON property transcript

Returns:

  • (String)


14727
14728
14729
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14727

def transcript
  @transcript
end

#trigger_eventString

If an event was provided as input, this field will contain the name of the event. Corresponds to the JSON property triggerEvent

Returns:

  • (String)


14733
14734
14735
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14733

def trigger_event
  @trigger_event
end

#trigger_intentString

If an intent was provided as input, this field will contain a copy of the intent identifier. Format: projects//locations//agents//intents/. Corresponds to the JSON property triggerIntent

Returns:

  • (String)


14739
14740
14741
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14739

def trigger_intent
  @trigger_intent
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14746
14747
14748
14749
14750
14751
14752
14753
14754
14755
14756
14757
14758
14759
14760
14761
14762
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14746

def update!(**args)
  @detect_intent_response_id = args[:detect_intent_response_id] if args.key?(:detect_intent_response_id)
  @dtmf_digits = args[:dtmf_digits] if args.key?(:dtmf_digits)
  @fulfillment_info = args[:fulfillment_info] if args.key?(:fulfillment_info)
  @intent_info = args[:intent_info] if args.key?(:intent_info)
  @language_code = args[:language_code] if args.key?(:language_code)
  @language_info = args[:language_info] if args.key?(:language_info)
  @messages = args[:messages] if args.key?(:messages)
  @page_info = args[:page_info] if args.key?(:page_info)
  @payload = args[:payload] if args.key?(:payload)
  @sentiment_analysis_result = args[:sentiment_analysis_result] if args.key?(:sentiment_analysis_result)
  @session_info = args[:session_info] if args.key?(:session_info)
  @text = args[:text] if args.key?(:text)
  @transcript = args[:transcript] if args.key?(:transcript)
  @trigger_event = args[:trigger_event] if args.key?(:trigger_event)
  @trigger_intent = args[:trigger_intent] if args.key?(:trigger_intent)
end