Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1WebhookRequestFulfillmentInfo
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1WebhookRequestFulfillmentInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
Represents fulfillment information communicated to the webhook.
Instance Attribute Summary collapse
-
#tag ⇒ String
Always present.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3beta1WebhookRequestFulfillmentInfo
constructor
A new instance of GoogleCloudDialogflowCxV3beta1WebhookRequestFulfillmentInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3beta1WebhookRequestFulfillmentInfo
Returns a new instance of GoogleCloudDialogflowCxV3beta1WebhookRequestFulfillmentInfo.
14777 14778 14779 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14777 def initialize(**args) update!(**args) end |
Instance Attribute Details
#tag ⇒ String
Always present. The value of the Fulfillment.tag field will be populated in
this field by Dialogflow when the associated webhook is called. The tag is
typically used by the webhook service to identify which fulfillment is being
called, but it could be used for other purposes.
Corresponds to the JSON property tag
14775 14776 14777 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14775 def tag @tag end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14782 14783 14784 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14782 def update!(**args) @tag = args[:tag] if args.key?(:tag) end |