Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1WebhookRequestIntentInfo
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1WebhookRequestIntentInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
Represents intent information communicated to the webhook.
Instance Attribute Summary collapse
-
#confidence ⇒ Float
The confidence of the matched intent.
-
#display_name ⇒ String
Always present.
-
#last_matched_intent ⇒ String
Always present.
-
#parameters ⇒ Hash<String,Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1WebhookRequestIntentInfoIntentParameterValue>
Parameters identified as a result of intent matching.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3beta1WebhookRequestIntentInfo
constructor
A new instance of GoogleCloudDialogflowCxV3beta1WebhookRequestIntentInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3beta1WebhookRequestIntentInfo
Returns a new instance of GoogleCloudDialogflowCxV3beta1WebhookRequestIntentInfo.
14816 14817 14818 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14816 def initialize(**args) update!(**args) end |
Instance Attribute Details
#confidence ⇒ Float
The confidence of the matched intent. Values range from 0.0 (completely
uncertain) to 1.0 (completely certain).
Corresponds to the JSON property confidence
14795 14796 14797 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14795 def confidence @confidence end |
#display_name ⇒ String
Always present. The display name of the last matched intent.
Corresponds to the JSON property displayName
14800 14801 14802 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14800 def display_name @display_name end |
#last_matched_intent ⇒ String
Always present. The unique identifier of the last matched intent. Format:
projects//locations//agents//intents/.
Corresponds to the JSON property lastMatchedIntent
14806 14807 14808 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14806 def last_matched_intent @last_matched_intent end |
#parameters ⇒ Hash<String,Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1WebhookRequestIntentInfoIntentParameterValue>
Parameters identified as a result of intent matching. This is a map of the
name of the identified parameter to the value of the parameter identified from
the user's utterance. All parameters defined in the matched intent that are
identified will be surfaced here.
Corresponds to the JSON property parameters
14814 14815 14816 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14814 def parameters @parameters end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14821 14822 14823 14824 14825 14826 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14821 def update!(**args) @confidence = args[:confidence] if args.key?(:confidence) @display_name = args[:display_name] if args.key?(:display_name) @last_matched_intent = args[:last_matched_intent] if args.key?(:last_matched_intent) @parameters = args[:parameters] if args.key?(:parameters) end |