Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1WebhookResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

The response message for a webhook call.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowCxV3beta1WebhookResponse

Returns a new instance of GoogleCloudDialogflowCxV3beta1WebhookResponse.



14917
14918
14919
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14917

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fulfillment_responseGoogle::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1WebhookResponseFulfillmentResponse

Represents a fulfillment response to the user. Corresponds to the JSON property fulfillmentResponse



14888
14889
14890
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14888

def fulfillment_response
  @fulfillment_response
end

#page_infoGoogle::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1PageInfo

Represents page information communicated to and from the webhook. Corresponds to the JSON property pageInfo



14893
14894
14895
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14893

def page_info
  @page_info
end

#payloadHash<String,Object>

Value to append directly to QueryResult.webhook_payloads. Corresponds to the JSON property payload

Returns:

  • (Hash<String,Object>)


14898
14899
14900
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14898

def payload
  @payload
end

#session_infoGoogle::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1SessionInfo

Represents session information communicated to and from the webhook. Corresponds to the JSON property sessionInfo



14903
14904
14905
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14903

def session_info
  @session_info
end

#target_flowString

The target flow to transition to. Format: projects//locations//agents//flows/ . Corresponds to the JSON property targetFlow

Returns:

  • (String)


14909
14910
14911
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14909

def target_flow
  @target_flow
end

#target_pageString

The target page to transition to. Format: projects//locations//agents//flows// pages/. Corresponds to the JSON property targetPage

Returns:

  • (String)


14915
14916
14917
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14915

def target_page
  @target_page
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14922
14923
14924
14925
14926
14927
14928
14929
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14922

def update!(**args)
  @fulfillment_response = args[:fulfillment_response] if args.key?(:fulfillment_response)
  @page_info = args[:page_info] if args.key?(:page_info)
  @payload = args[:payload] if args.key?(:payload)
  @session_info = args[:session_info] if args.key?(:session_info)
  @target_flow = args[:target_flow] if args.key?(:target_flow)
  @target_page = args[:target_page] if args.key?(:target_page)
end