Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowV2AgentCoachingInstructionDuplicateCheckResultDuplicateSuggestion

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

The duplicate suggestion details.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowV2AgentCoachingInstructionDuplicateCheckResultDuplicateSuggestion

Returns a new instance of GoogleCloudDialogflowV2AgentCoachingInstructionDuplicateCheckResultDuplicateSuggestion.



15079
15080
15081
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 15079

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#answer_recordString

Output only. The answer record id of the past duplicate suggestion. Corresponds to the JSON property answerRecord

Returns:

  • (String)


15067
15068
15069
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 15067

def answer_record
  @answer_record
end

#similarity_scoreFloat

Output only. The similarity score of between the past and current suggestion. Corresponds to the JSON property similarityScore

Returns:

  • (Float)


15072
15073
15074
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 15072

def similarity_score
  @similarity_score
end

#suggestion_indexFixnum

Output only. The index of the duplicate suggestion in the past suggestion list. Corresponds to the JSON property suggestionIndex

Returns:

  • (Fixnum)


15077
15078
15079
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 15077

def suggestion_index
  @suggestion_index
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15084
15085
15086
15087
15088
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 15084

def update!(**args)
  @answer_record = args[:answer_record] if args.key?(:answer_record)
  @similarity_score = args[:similarity_score] if args.key?(:similarity_score)
  @suggestion_index = args[:suggestion_index] if args.key?(:suggestion_index)
end