Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowV2EventInput
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowV2EventInput
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
Events allow for matching intents by event name instead of the natural
language input. For instance, input `can trigger a personalized welcome
response. The parameternamemay be used by the agent in the response:"
Hello #welcome_event.name! What can I do for you today?"`.
Instance Attribute Summary collapse
-
#language_code ⇒ String
Required.
-
#name ⇒ String
Required.
-
#parameters ⇒ Hash<String,Object>
The collection of parameters associated with the event.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowV2EventInput
constructor
A new instance of GoogleCloudDialogflowV2EventInput.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowV2EventInput
Returns a new instance of GoogleCloudDialogflowV2EventInput.
16000 16001 16002 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 16000 def initialize(**args) update!(**args) end |
Instance Attribute Details
#language_code ⇒ String
Required. The language of this query. See Language Support for a list of the currently
supported language codes. Note that queries in the same session do not
necessarily need to specify the same language. This field is ignored when used
in the context of a WebhookResponse.followup_event_input field, because the
language was already defined in the originating detect intent request.
Corresponds to the JSON property languageCode
15980 15981 15982 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 15980 def language_code @language_code end |
#name ⇒ String
Required. The unique identifier of the event.
Corresponds to the JSON property name
15985 15986 15987 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 15985 def name @name end |
#parameters ⇒ Hash<String,Object>
The collection of parameters associated with the event. Depending on your
protocol or client library language, this is a map, associative array, symbol
table, dictionary, or JSON object composed of a collection of (MapKey,
MapValue) pairs: * MapKey type: string * MapKey value: parameter name *
MapValue type: If parameter's entity type is a composite entity then use map,
otherwise, depending on the parameter value type, it could be one of string,
number, boolean, null, list or map. * MapValue value: If parameter's entity
type is a composite entity then use map from composite entity property names
to property values, otherwise, use parameter value.
Corresponds to the JSON property parameters
15998 15999 16000 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 15998 def parameters @parameters end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16005 16006 16007 16008 16009 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 16005 def update!(**args) @language_code = args[:language_code] if args.key?(:language_code) @name = args[:name] if args.key?(:name) @parameters = args[:parameters] if args.key?(:parameters) end |