Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowV2HumanAgentAssistantEvent
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowV2HumanAgentAssistantEvent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
Represents a notification sent to Cloud Pub/Sub subscribers for human agent assistant events in a specific conversation.
Instance Attribute Summary collapse
-
#conversation ⇒ String
The conversation this notification refers to.
-
#participant ⇒ String
The participant that the suggestion is compiled for.
-
#suggestion_results ⇒ Array<Google::Apis::DialogflowV3::GoogleCloudDialogflowV2SuggestionResult>
The suggestion results payload that this notification refers to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowV2HumanAgentAssistantEvent
constructor
A new instance of GoogleCloudDialogflowV2HumanAgentAssistantEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowV2HumanAgentAssistantEvent
Returns a new instance of GoogleCloudDialogflowV2HumanAgentAssistantEvent.
16295 16296 16297 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 16295 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conversation ⇒ String
The conversation this notification refers to. Format: projects//conversations/
.
Corresponds to the JSON property conversation
16282 16283 16284 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 16282 def conversation @conversation end |
#participant ⇒ String
The participant that the suggestion is compiled for. Format: projects//
conversations//participants/. It will not be set in legacy workflow.
Corresponds to the JSON property participant
16288 16289 16290 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 16288 def participant @participant end |
#suggestion_results ⇒ Array<Google::Apis::DialogflowV3::GoogleCloudDialogflowV2SuggestionResult>
The suggestion results payload that this notification refers to.
Corresponds to the JSON property suggestionResults
16293 16294 16295 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 16293 def suggestion_results @suggestion_results end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16300 16301 16302 16303 16304 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 16300 def update!(**args) @conversation = args[:conversation] if args.key?(:conversation) @participant = args[:participant] if args.key?(:participant) @suggestion_results = args[:suggestion_results] if args.key?(:suggestion_results) end |