Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowV2Intent
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowV2Intent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
An intent categorizes an end-user's intention for one conversation turn. For each agent, you define many intents, where your combined intents can handle a complete conversation. When an end-user writes or says something, referred to as an end-user expression or end-user input, Dialogflow matches the end-user input to the best intent in your agent. Matching an intent is also known as intent classification. For more information, see the intent guide.
Instance Attribute Summary collapse
-
#action ⇒ String
Optional.
-
#default_response_platforms ⇒ Array<String>
Optional.
-
#display_name ⇒ String
Required.
-
#end_interaction ⇒ Boolean
(also: #end_interaction?)
Optional.
-
#events ⇒ Array<String>
Optional.
-
#followup_intent_info ⇒ Array<Google::Apis::DialogflowV3::GoogleCloudDialogflowV2IntentFollowupIntentInfo>
Output only.
-
#input_context_names ⇒ Array<String>
Optional.
-
#is_fallback ⇒ Boolean
(also: #is_fallback?)
Optional.
-
#live_agent_handoff ⇒ Boolean
(also: #live_agent_handoff?)
Optional.
-
#messages ⇒ Array<Google::Apis::DialogflowV3::GoogleCloudDialogflowV2IntentMessage>
Optional.
-
#ml_disabled ⇒ Boolean
(also: #ml_disabled?)
Optional.
-
#name ⇒ String
Optional.
-
#output_contexts ⇒ Array<Google::Apis::DialogflowV3::GoogleCloudDialogflowV2Context>
Optional.
-
#parameters ⇒ Array<Google::Apis::DialogflowV3::GoogleCloudDialogflowV2IntentParameter>
Optional.
-
#parent_followup_intent_name ⇒ String
Read-only after creation.
-
#priority ⇒ Fixnum
Optional.
-
#reset_contexts ⇒ Boolean
(also: #reset_contexts?)
Optional.
-
#root_followup_intent_name ⇒ String
Output only.
-
#training_phrases ⇒ Array<Google::Apis::DialogflowV3::GoogleCloudDialogflowV2IntentTrainingPhrase>
Optional.
-
#webhook_state ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowV2Intent
constructor
A new instance of GoogleCloudDialogflowV2Intent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowV2Intent
Returns a new instance of GoogleCloudDialogflowV2Intent.
16594 16595 16596 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 16594 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action ⇒ String
Optional. The name of the action associated with the intent. Note: The action
name must not contain whitespaces.
Corresponds to the JSON property action
16460 16461 16462 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 16460 def action @action end |
#default_response_platforms ⇒ Array<String>
Optional. The list of platforms for which the first responses will be copied
from the messages in PLATFORM_UNSPECIFIED (i.e. default platform).
Corresponds to the JSON property defaultResponsePlatforms
16466 16467 16468 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 16466 def default_response_platforms @default_response_platforms end |
#display_name ⇒ String
Required. The name of this intent.
Corresponds to the JSON property displayName
16471 16472 16473 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 16471 def display_name @display_name end |
#end_interaction ⇒ Boolean Also known as: end_interaction?
Optional. Indicates that this intent ends an interaction. Some integrations (e.
g., Actions on Google or Dialogflow phone gateway) use this information to
close interaction with an end user. Default is false.
Corresponds to the JSON property endInteraction
16478 16479 16480 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 16478 def end_interaction @end_interaction end |
#events ⇒ Array<String>
Optional. The collection of event names that trigger the intent. If the
collection of input contexts is not empty, all of the contexts must be present
in the active user session for an event to trigger this intent. Event names
are limited to 150 characters.
Corresponds to the JSON property events
16487 16488 16489 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 16487 def events @events end |
#followup_intent_info ⇒ Array<Google::Apis::DialogflowV3::GoogleCloudDialogflowV2IntentFollowupIntentInfo>
Output only. Read-only. Information about all followup intents that have this
intent as a direct or indirect parent. We populate this field only in the
output.
Corresponds to the JSON property followupIntentInfo
16494 16495 16496 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 16494 def followup_intent_info @followup_intent_info end |
#input_context_names ⇒ Array<String>
Optional. The list of context names required for this intent to be triggered.
Format: projects//agent/sessions/-/contexts/.
Corresponds to the JSON property inputContextNames
16500 16501 16502 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 16500 def input_context_names @input_context_names end |
#is_fallback ⇒ Boolean Also known as: is_fallback?
Optional. Indicates whether this is a fallback intent.
Corresponds to the JSON property isFallback
16505 16506 16507 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 16505 def is_fallback @is_fallback end |
#live_agent_handoff ⇒ Boolean Also known as: live_agent_handoff?
Optional. Indicates that a live agent should be brought in to handle the
interaction with the user. In most cases, when you set this flag to true, you
would also want to set end_interaction to true as well. Default is false.
Corresponds to the JSON property liveAgentHandoff
16513 16514 16515 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 16513 def live_agent_handoff @live_agent_handoff end |
#messages ⇒ Array<Google::Apis::DialogflowV3::GoogleCloudDialogflowV2IntentMessage>
Optional. The collection of rich messages corresponding to the Response
field in the Dialogflow console.
Corresponds to the JSON property messages
16520 16521 16522 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 16520 def @messages end |
#ml_disabled ⇒ Boolean Also known as: ml_disabled?
Optional. Indicates whether Machine Learning is disabled for the intent. Note:
If ml_disabled setting is set to true, then this intent is not taken into
account during inference in ML ONLY match mode. Also, auto-markup in the UI
is turned off.
Corresponds to the JSON property mlDisabled
16528 16529 16530 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 16528 def ml_disabled @ml_disabled end |
#name ⇒ String
Optional. The unique identifier of this intent. Required for Intents.
UpdateIntent and Intents.BatchUpdateIntents methods. Format: projects//agent/
intents/.
Corresponds to the JSON property name
16536 16537 16538 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 16536 def name @name end |
#output_contexts ⇒ Array<Google::Apis::DialogflowV3::GoogleCloudDialogflowV2Context>
Optional. The collection of contexts that are activated when the intent is
matched. Context messages in this collection should not set the parameters
field. Setting the lifespan_count to 0 will reset the context when the
intent is matched. Format: projects//agent/sessions/-/contexts/.
Corresponds to the JSON property outputContexts
16544 16545 16546 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 16544 def output_contexts @output_contexts end |
#parameters ⇒ Array<Google::Apis::DialogflowV3::GoogleCloudDialogflowV2IntentParameter>
Optional. The collection of parameters associated with the intent.
Corresponds to the JSON property parameters
16549 16550 16551 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 16549 def parameters @parameters end |
#parent_followup_intent_name ⇒ String
Read-only after creation. The unique identifier of the parent intent in the
chain of followup intents. You can set this field when creating an intent, for
example with CreateIntent or BatchUpdateIntents, in order to make this intent
a followup intent. It identifies the parent followup intent. Format: projects/
/agent/intents/.
Corresponds to the JSON property parentFollowupIntentName
16558 16559 16560 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 16558 def parent_followup_intent_name @parent_followup_intent_name end |
#priority ⇒ Fixnum
Optional. The priority of this intent. Higher numbers represent higher
priorities. - If the supplied value is unspecified or 0, the service
translates the value to 500,000, which corresponds to the Normal priority in
the console. - If the supplied value is negative, the intent is ignored in
runtime detect intent requests.
Corresponds to the JSON property priority
16567 16568 16569 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 16567 def priority @priority end |
#reset_contexts ⇒ Boolean Also known as: reset_contexts?
Optional. Indicates whether to delete all contexts in the current session when
this intent is matched.
Corresponds to the JSON property resetContexts
16573 16574 16575 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 16573 def reset_contexts @reset_contexts end |
#root_followup_intent_name ⇒ String
Output only. Read-only. The unique identifier of the root intent in the chain
of followup intents. It identifies the correct followup intents chain for this
intent. We populate this field only in the output. Format: projects//agent/
intents/.
Corresponds to the JSON property rootFollowupIntentName
16582 16583 16584 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 16582 def root_followup_intent_name @root_followup_intent_name end |
#training_phrases ⇒ Array<Google::Apis::DialogflowV3::GoogleCloudDialogflowV2IntentTrainingPhrase>
Optional. The collection of examples that the agent is trained on.
Corresponds to the JSON property trainingPhrases
16587 16588 16589 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 16587 def training_phrases @training_phrases end |
#webhook_state ⇒ String
Optional. Indicates whether webhooks are enabled for the intent.
Corresponds to the JSON property webhookState
16592 16593 16594 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 16592 def webhook_state @webhook_state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16599 16600 16601 16602 16603 16604 16605 16606 16607 16608 16609 16610 16611 16612 16613 16614 16615 16616 16617 16618 16619 16620 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 16599 def update!(**args) @action = args[:action] if args.key?(:action) @default_response_platforms = args[:default_response_platforms] if args.key?(:default_response_platforms) @display_name = args[:display_name] if args.key?(:display_name) @end_interaction = args[:end_interaction] if args.key?(:end_interaction) @events = args[:events] if args.key?(:events) @followup_intent_info = args[:followup_intent_info] if args.key?(:followup_intent_info) @input_context_names = args[:input_context_names] if args.key?(:input_context_names) @is_fallback = args[:is_fallback] if args.key?(:is_fallback) @live_agent_handoff = args[:live_agent_handoff] if args.key?(:live_agent_handoff) @messages = args[:messages] if args.key?(:messages) @ml_disabled = args[:ml_disabled] if args.key?(:ml_disabled) @name = args[:name] if args.key?(:name) @output_contexts = args[:output_contexts] if args.key?(:output_contexts) @parameters = args[:parameters] if args.key?(:parameters) @parent_followup_intent_name = args[:parent_followup_intent_name] if args.key?(:parent_followup_intent_name) @priority = args[:priority] if args.key?(:priority) @reset_contexts = args[:reset_contexts] if args.key?(:reset_contexts) @root_followup_intent_name = args[:root_followup_intent_name] if args.key?(:root_followup_intent_name) @training_phrases = args[:training_phrases] if args.key?(:training_phrases) @webhook_state = args[:webhook_state] if args.key?(:webhook_state) end |