Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowV2IntentMessageBrowseCarouselCardBrowseCarouselCardItem
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowV2IntentMessageBrowseCarouselCardBrowseCarouselCardItem
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
Browsing carousel tile
Instance Attribute Summary collapse
-
#description ⇒ String
Optional.
-
#footer ⇒ String
Optional.
-
#image ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowV2IntentMessageImage
The image response message.
-
#open_uri_action ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowV2IntentMessageBrowseCarouselCardBrowseCarouselCardItemOpenUrlAction
Actions on Google action to open a given url.
-
#title ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowV2IntentMessageBrowseCarouselCardBrowseCarouselCardItem
constructor
A new instance of GoogleCloudDialogflowV2IntentMessageBrowseCarouselCardBrowseCarouselCardItem.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowV2IntentMessageBrowseCarouselCardBrowseCarouselCardItem
Returns a new instance of GoogleCloudDialogflowV2IntentMessageBrowseCarouselCardBrowseCarouselCardItem.
16903 16904 16905 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 16903 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Optional. Description of the carousel item. Maximum of four lines of text.
Corresponds to the JSON property description
16880 16881 16882 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 16880 def description @description end |
#footer ⇒ String
Optional. Text that appears at the bottom of the Browse Carousel Card. Maximum
of one line of text.
Corresponds to the JSON property footer
16886 16887 16888 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 16886 def @footer end |
#image ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowV2IntentMessageImage
The image response message.
Corresponds to the JSON property image
16891 16892 16893 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 16891 def image @image end |
#open_uri_action ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowV2IntentMessageBrowseCarouselCardBrowseCarouselCardItemOpenUrlAction
Actions on Google action to open a given url.
Corresponds to the JSON property openUriAction
16896 16897 16898 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 16896 def open_uri_action @open_uri_action end |
#title ⇒ String
Required. Title of the carousel item. Maximum of two lines of text.
Corresponds to the JSON property title
16901 16902 16903 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 16901 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16908 16909 16910 16911 16912 16913 16914 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 16908 def update!(**args) @description = args[:description] if args.key?(:description) @footer = args[:footer] if args.key?(:footer) @image = args[:image] if args.key?(:image) @open_uri_action = args[:open_uri_action] if args.key?(:open_uri_action) @title = args[:title] if args.key?(:title) end |