Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowV2IntentMessageLinkOutSuggestion

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

The suggestion chip message that allows the user to jump out to the app or website associated with this agent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowV2IntentMessageLinkOutSuggestion

Returns a new instance of GoogleCloudDialogflowV2IntentMessageLinkOutSuggestion.



17128
17129
17130
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 17128

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#destination_nameString

Required. The name of the app or site this chip is linking to. Corresponds to the JSON property destinationName

Returns:

  • (String)


17120
17121
17122
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 17120

def destination_name
  @destination_name
end

#uriString

Required. The URI of the app or site to open when the user taps the suggestion chip. Corresponds to the JSON property uri

Returns:

  • (String)


17126
17127
17128
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 17126

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17133
17134
17135
17136
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 17133

def update!(**args)
  @destination_name = args[:destination_name] if args.key?(:destination_name)
  @uri = args[:uri] if args.key?(:uri)
end