Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowV2IntentMessageListSelectItem
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowV2IntentMessageListSelectItem
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
An item in the list.
Instance Attribute Summary collapse
-
#description ⇒ String
Optional.
-
#image ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowV2IntentMessageImage
The image response message.
-
#info ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowV2IntentMessageSelectItemInfo
Additional info about the select item for when it is triggered in a dialog.
-
#title ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowV2IntentMessageListSelectItem
constructor
A new instance of GoogleCloudDialogflowV2IntentMessageListSelectItem.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowV2IntentMessageListSelectItem
Returns a new instance of GoogleCloudDialogflowV2IntentMessageListSelectItem.
17194 17195 17196 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 17194 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Optional. The main text describing the item.
Corresponds to the JSON property description
17177 17178 17179 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 17177 def description @description end |
#image ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowV2IntentMessageImage
The image response message.
Corresponds to the JSON property image
17182 17183 17184 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 17182 def image @image end |
#info ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowV2IntentMessageSelectItemInfo
Additional info about the select item for when it is triggered in a dialog.
Corresponds to the JSON property info
17187 17188 17189 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 17187 def info @info end |
#title ⇒ String
Required. The title of the list item.
Corresponds to the JSON property title
17192 17193 17194 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 17192 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17199 17200 17201 17202 17203 17204 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 17199 def update!(**args) @description = args[:description] if args.key?(:description) @image = args[:image] if args.key?(:image) @info = args[:info] if args.key?(:info) @title = args[:title] if args.key?(:title) end |