Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowV2IntentTrainingPhrasePart

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

Represents a part of a training phrase.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowV2IntentTrainingPhrasePart

Returns a new instance of GoogleCloudDialogflowV2IntentTrainingPhrasePart.



17684
17685
17686
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 17684

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#aliasString

Optional. The parameter name for the value extracted from the annotated part of the example. This field is required for annotated parts of the training phrase. Corresponds to the JSON property alias

Returns:

  • (String)


17663
17664
17665
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 17663

def alias
  @alias
end

#entity_typeString

Optional. The entity type name prefixed with @. This field is required for annotated parts of the training phrase. Corresponds to the JSON property entityType

Returns:

  • (String)


17669
17670
17671
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 17669

def entity_type
  @entity_type
end

#textString

Required. The text for this part. Corresponds to the JSON property text

Returns:

  • (String)


17674
17675
17676
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 17674

def text
  @text
end

#user_definedBoolean Also known as: user_defined?

Optional. Indicates whether the text was manually annotated. This field is set to true when the Dialogflow Console is used to manually annotate the part. When creating an annotated part with the API, you must set this to true. Corresponds to the JSON property userDefined

Returns:

  • (Boolean)


17681
17682
17683
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 17681

def user_defined
  @user_defined
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17689
17690
17691
17692
17693
17694
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 17689

def update!(**args)
  @alias = args[:alias] if args.key?(:alias)
  @entity_type = args[:entity_type] if args.key?(:entity_type)
  @text = args[:text] if args.key?(:text)
  @user_defined = args[:user_defined] if args.key?(:user_defined)
end