Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowV2QueryResult
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowV2QueryResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
Represents the result of conversational query or event processing.
Instance Attribute Summary collapse
-
#action ⇒ String
The action name from the matched intent.
-
#all_required_params_present ⇒ Boolean
(also: #all_required_params_present?)
This field is set to: -
falseif the matched intent has required parameters and not all of the required parameter values have been collected. -
#cancels_slot_filling ⇒ Boolean
(also: #cancels_slot_filling?)
Indicates whether the conversational query triggers a cancellation for slot filling.
-
#diagnostic_info ⇒ Hash<String,Object>
Free-form diagnostic information for the associated detect intent request.
-
#fulfillment_messages ⇒ Array<Google::Apis::DialogflowV3::GoogleCloudDialogflowV2IntentMessage>
The collection of rich messages to present to the user.
-
#fulfillment_text ⇒ String
The text to be pronounced to the user or shown on the screen.
-
#intent ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowV2Intent
An intent categorizes an end-user's intention for one conversation turn.
-
#intent_detection_confidence ⇒ Float
The intent detection confidence.
-
#language_code ⇒ String
The language that was triggered during intent detection.
-
#output_contexts ⇒ Array<Google::Apis::DialogflowV3::GoogleCloudDialogflowV2Context>
The collection of output contexts.
-
#parameters ⇒ Hash<String,Object>
The collection of extracted parameters.
-
#query_text ⇒ String
The original conversational query text: - If natural language text was provided as input,
query_textcontains a copy of the input. -
#sentiment_analysis_result ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowV2SentimentAnalysisResult
The result of sentiment analysis.
-
#speech_recognition_confidence ⇒ Float
The Speech recognition confidence between 0.0 and 1.0.
-
#webhook_payload ⇒ Hash<String,Object>
If the query was fulfilled by a webhook call, this field is set to the value of the
payloadfield returned in the webhook response. -
#webhook_source ⇒ String
If the query was fulfilled by a webhook call, this field is set to the value of the
sourcefield returned in the webhook response.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowV2QueryResult
constructor
A new instance of GoogleCloudDialogflowV2QueryResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowV2QueryResult
Returns a new instance of GoogleCloudDialogflowV2QueryResult.
18175 18176 18177 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 18175 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action ⇒ String
The action name from the matched intent.
Corresponds to the JSON property action
18044 18045 18046 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 18044 def action @action end |
#all_required_params_present ⇒ Boolean Also known as: all_required_params_present?
This field is set to: - false if the matched intent has required parameters
and not all of the required parameter values have been collected. - true if
all required parameter values have been collected, or if the matched intent
doesn't contain any required parameters.
Corresponds to the JSON property allRequiredParamsPresent
18052 18053 18054 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 18052 def all_required_params_present @all_required_params_present end |
#cancels_slot_filling ⇒ Boolean Also known as: cancels_slot_filling?
Indicates whether the conversational query triggers a cancellation for slot
filling. For more information, see the cancel slot filling documentation.
Corresponds to the JSON property cancelsSlotFilling
18060 18061 18062 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 18060 def cancels_slot_filling @cancels_slot_filling end |
#diagnostic_info ⇒ Hash<String,Object>
Free-form diagnostic information for the associated detect intent request. The
fields of this data can change without notice, so you should not write code
that depends on its structure. The data may contain: - webhook call latency -
webhook errors
Corresponds to the JSON property diagnosticInfo
18069 18070 18071 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 18069 def diagnostic_info @diagnostic_info end |
#fulfillment_messages ⇒ Array<Google::Apis::DialogflowV3::GoogleCloudDialogflowV2IntentMessage>
The collection of rich messages to present to the user.
Corresponds to the JSON property fulfillmentMessages
18074 18075 18076 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 18074 def @fulfillment_messages end |
#fulfillment_text ⇒ String
The text to be pronounced to the user or shown on the screen. Note: This is a
legacy field, fulfillment_messages should be preferred.
Corresponds to the JSON property fulfillmentText
18080 18081 18082 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 18080 def fulfillment_text @fulfillment_text end |
#intent ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowV2Intent
An intent categorizes an end-user's intention for one conversation turn. For
each agent, you define many intents, where your combined intents can handle a
complete conversation. When an end-user writes or says something, referred to
as an end-user expression or end-user input, Dialogflow matches the end-user
input to the best intent in your agent. Matching an intent is also known as
intent classification. For more information, see the intent guide.
Corresponds to the JSON property intent
18091 18092 18093 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 18091 def intent @intent end |
#intent_detection_confidence ⇒ Float
The intent detection confidence. Values range from 0.0 (completely uncertain)
to 1.0 (completely certain). This value is for informational purpose only and
is only used to help match the best intent within the classification threshold.
This value may change for the same end-user expression at any time due to a
model retraining or change in implementation. If there are multiple
knowledge_answers messages, this value is set to the greatest
knowledgeAnswers.match_confidence value in the list.
Corresponds to the JSON property intentDetectionConfidence
18102 18103 18104 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 18102 def intent_detection_confidence @intent_detection_confidence end |
#language_code ⇒ String
The language that was triggered during intent detection. See Language Support for a list of
the currently supported language codes.
Corresponds to the JSON property languageCode
18109 18110 18111 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 18109 def language_code @language_code end |
#output_contexts ⇒ Array<Google::Apis::DialogflowV3::GoogleCloudDialogflowV2Context>
The collection of output contexts. If applicable, output_contexts.parameters
contains entries with name .original containing the original parameter
values before the query.
Corresponds to the JSON property outputContexts
18116 18117 18118 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 18116 def output_contexts @output_contexts end |
#parameters ⇒ Hash<String,Object>
The collection of extracted parameters. Depending on your protocol or client
library language, this is a map, associative array, symbol table, dictionary,
or JSON object composed of a collection of (MapKey, MapValue) pairs: * MapKey
type: string * MapKey value: parameter name * MapValue type: If parameter's
entity type is a composite entity then use map, otherwise, depending on the
parameter value type, it could be one of string, number, boolean, null, list
or map. * MapValue value: If parameter's entity type is a composite entity
then use map from composite entity property names to property values,
otherwise, use parameter value.
Corresponds to the JSON property parameters
18129 18130 18131 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 18129 def parameters @parameters end |
#query_text ⇒ String
The original conversational query text: - If natural language text was
provided as input, query_text contains a copy of the input. - If natural
language speech audio was provided as input, query_text contains the speech
recognition result. If speech recognizer produced multiple alternatives, a
particular one is picked. - If automatic spell correction is enabled,
query_text will contain the corrected user input.
Corresponds to the JSON property queryText
18139 18140 18141 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 18139 def query_text @query_text end |
#sentiment_analysis_result ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowV2SentimentAnalysisResult
The result of sentiment analysis. Sentiment analysis inspects user input and
identifies the prevailing subjective opinion, especially to determine a user's
attitude as positive, negative, or neutral. For DetectIntent, it needs to be
configured in DetectIntentRequest.query_params. For StreamingDetectIntent, it
needs to be configured in StreamingDetectIntentRequest.query_params. And for
Participants.AnalyzeContent and Participants.StreamingAnalyzeContent, it needs
to be configured in ConversationProfile.human_agent_assistant_config
Corresponds to the JSON property sentimentAnalysisResult
18150 18151 18152 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 18150 def sentiment_analysis_result @sentiment_analysis_result end |
#speech_recognition_confidence ⇒ Float
The Speech recognition confidence between 0.0 and 1.0. A higher number
indicates an estimated greater likelihood that the recognized words are
correct. The default of 0.0 is a sentinel value indicating that confidence was
not set. This field is not guaranteed to be accurate or set. In particular
this field isn't set for StreamingDetectIntent since the streaming endpoint
has separate confidence estimates per portion of the audio in
StreamingRecognitionResult.
Corresponds to the JSON property speechRecognitionConfidence
18161 18162 18163 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 18161 def speech_recognition_confidence @speech_recognition_confidence end |
#webhook_payload ⇒ Hash<String,Object>
If the query was fulfilled by a webhook call, this field is set to the value
of the payload field returned in the webhook response.
Corresponds to the JSON property webhookPayload
18167 18168 18169 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 18167 def webhook_payload @webhook_payload end |
#webhook_source ⇒ String
If the query was fulfilled by a webhook call, this field is set to the value
of the source field returned in the webhook response.
Corresponds to the JSON property webhookSource
18173 18174 18175 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 18173 def webhook_source @webhook_source end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18180 18181 18182 18183 18184 18185 18186 18187 18188 18189 18190 18191 18192 18193 18194 18195 18196 18197 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 18180 def update!(**args) @action = args[:action] if args.key?(:action) @all_required_params_present = args[:all_required_params_present] if args.key?(:all_required_params_present) @cancels_slot_filling = args[:cancels_slot_filling] if args.key?(:cancels_slot_filling) @diagnostic_info = args[:diagnostic_info] if args.key?(:diagnostic_info) @fulfillment_messages = args[:fulfillment_messages] if args.key?(:fulfillment_messages) @fulfillment_text = args[:fulfillment_text] if args.key?(:fulfillment_text) @intent = args[:intent] if args.key?(:intent) @intent_detection_confidence = args[:intent_detection_confidence] if args.key?(:intent_detection_confidence) @language_code = args[:language_code] if args.key?(:language_code) @output_contexts = args[:output_contexts] if args.key?(:output_contexts) @parameters = args[:parameters] if args.key?(:parameters) @query_text = args[:query_text] if args.key?(:query_text) @sentiment_analysis_result = args[:sentiment_analysis_result] if args.key?(:sentiment_analysis_result) @speech_recognition_confidence = args[:speech_recognition_confidence] if args.key?(:speech_recognition_confidence) @webhook_payload = args[:webhook_payload] if args.key?(:webhook_payload) @webhook_source = args[:webhook_source] if args.key?(:webhook_source) end |