Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowV2SessionEntityType
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowV2SessionEntityType
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
A session represents a conversation between a Dialogflow agent and an end-user. You can create special entities, called session entities, during a session. Session entities can extend or replace custom entity types and only exist during the session that they were created for. All session data, including session entities, is stored by Dialogflow for 20 minutes. For more information, see the session entity guide.
Instance Attribute Summary collapse
-
#entities ⇒ Array<Google::Apis::DialogflowV3::GoogleCloudDialogflowV2EntityTypeEntity>
Required.
-
#entity_override_mode ⇒ String
Required.
-
#name ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowV2SessionEntityType
constructor
A new instance of GoogleCloudDialogflowV2SessionEntityType.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowV2SessionEntityType
Returns a new instance of GoogleCloudDialogflowV2SessionEntityType.
18288 18289 18290 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 18288 def initialize(**args) update!(**args) end |
Instance Attribute Details
#entities ⇒ Array<Google::Apis::DialogflowV3::GoogleCloudDialogflowV2EntityTypeEntity>
Required. The collection of entities associated with this session entity type.
Corresponds to the JSON property entities
18270 18271 18272 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 18270 def entities @entities end |
#entity_override_mode ⇒ String
Required. Indicates whether the additional data should override or supplement
the custom entity type definition.
Corresponds to the JSON property entityOverrideMode
18276 18277 18278 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 18276 def entity_override_mode @entity_override_mode end |
#name ⇒ String
Required. The unique identifier of this session entity type. Format: projects/
/agent/sessions//entityTypes/, or projects//agent/environments//users//
sessions//entityTypes/. If Environment ID is not specified, we assume
default 'draft' environment. If User ID is not specified, we assume default '
-' user. `must be the display name of an existing entity type in the same
agent that will be overridden or supplemented.
Corresponds to the JSON propertyname`
18286 18287 18288 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 18286 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18293 18294 18295 18296 18297 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 18293 def update!(**args) @entities = args[:entities] if args.key?(:entities) @entity_override_mode = args[:entity_override_mode] if args.key?(:entity_override_mode) @name = args[:name] if args.key?(:name) end |