Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowV2SuggestionResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

One response of different type of suggestion response which is used in the response of Participants.AnalyzeContent and Participants.AnalyzeContent, as well as HumanAgentAssistantEvent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowV2SuggestionResult

Returns a new instance of GoogleCloudDialogflowV2SuggestionResult.



18706
18707
18708
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 18706

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorGoogle::Apis::DialogflowV3::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



18679
18680
18681
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 18679

def error
  @error
end

#generate_suggestions_responseGoogle::Apis::DialogflowV3::GoogleCloudDialogflowV2GenerateSuggestionsResponse

The response message for Conversations.GenerateSuggestions. Corresponds to the JSON property generateSuggestionsResponse



18684
18685
18686
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 18684

def generate_suggestions_response
  @generate_suggestions_response
end

#suggest_articles_responseGoogle::Apis::DialogflowV3::GoogleCloudDialogflowV2SuggestArticlesResponse

The response message for Participants.SuggestArticles. Corresponds to the JSON property suggestArticlesResponse



18689
18690
18691
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 18689

def suggest_articles_response
  @suggest_articles_response
end

#suggest_faq_answers_responseGoogle::Apis::DialogflowV3::GoogleCloudDialogflowV2SuggestFaqAnswersResponse

The request message for Participants.SuggestFaqAnswers. Corresponds to the JSON property suggestFaqAnswersResponse



18694
18695
18696
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 18694

def suggest_faq_answers_response
  @suggest_faq_answers_response
end

#suggest_knowledge_assist_responseGoogle::Apis::DialogflowV3::GoogleCloudDialogflowV2SuggestKnowledgeAssistResponse

The response message for Participants.SuggestKnowledgeAssist. Corresponds to the JSON property suggestKnowledgeAssistResponse



18699
18700
18701
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 18699

def suggest_knowledge_assist_response
  @suggest_knowledge_assist_response
end

#suggest_smart_replies_responseGoogle::Apis::DialogflowV3::GoogleCloudDialogflowV2SuggestSmartRepliesResponse

The response message for Participants.SuggestSmartReplies. Corresponds to the JSON property suggestSmartRepliesResponse



18704
18705
18706
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 18704

def suggest_smart_replies_response
  @suggest_smart_replies_response
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18711
18712
18713
18714
18715
18716
18717
18718
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 18711

def update!(**args)
  @error = args[:error] if args.key?(:error)
  @generate_suggestions_response = args[:generate_suggestions_response] if args.key?(:generate_suggestions_response)
  @suggest_articles_response = args[:suggest_articles_response] if args.key?(:suggest_articles_response)
  @suggest_faq_answers_response = args[:suggest_faq_answers_response] if args.key?(:suggest_faq_answers_response)
  @suggest_knowledge_assist_response = args[:suggest_knowledge_assist_response] if args.key?(:suggest_knowledge_assist_response)
  @suggest_smart_replies_response = args[:suggest_smart_replies_response] if args.key?(:suggest_smart_replies_response)
end