Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowV2ToolCallResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

The result of calling a tool's action.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowV2ToolCallResult

Returns a new instance of GoogleCloudDialogflowV2ToolCallResult.



18869
18870
18871
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 18869

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionString

Optional. The name of the tool's action associated with this call. Corresponds to the JSON property action

Returns:

  • (String)


18834
18835
18836
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 18834

def action
  @action
end

#answer_recordString

Optional. The answer record associated with this tool call result. Corresponds to the JSON property answerRecord

Returns:

  • (String)


18839
18840
18841
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 18839

def answer_record
  @answer_record
end

#contentString

Only populated if the response content is utf-8 encoded. Corresponds to the JSON property content

Returns:

  • (String)


18844
18845
18846
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 18844

def content
  @content
end

#create_timeString

Output only. Create time of the tool call result. Corresponds to the JSON property createTime

Returns:

  • (String)


18849
18850
18851
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 18849

def create_time
  @create_time
end

#errorGoogle::Apis::DialogflowV3::GoogleCloudDialogflowV2ToolCallResultError

An error produced by the tool call. Corresponds to the JSON property error



18854
18855
18856
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 18854

def error
  @error
end

#raw_contentString

Only populated if the response content is not utf-8 encoded. (by definition byte fields are base64 encoded). Corresponds to the JSON property rawContent NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


18861
18862
18863
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 18861

def raw_content
  @raw_content
end

#toolString

Optional. The tool associated with this call. Format: projects//locations// tools/. Corresponds to the JSON property tool

Returns:

  • (String)


18867
18868
18869
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 18867

def tool
  @tool
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18874
18875
18876
18877
18878
18879
18880
18881
18882
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 18874

def update!(**args)
  @action = args[:action] if args.key?(:action)
  @answer_record = args[:answer_record] if args.key?(:answer_record)
  @content = args[:content] if args.key?(:content)
  @create_time = args[:create_time] if args.key?(:create_time)
  @error = args[:error] if args.key?(:error)
  @raw_content = args[:raw_content] if args.key?(:raw_content)
  @tool = args[:tool] if args.key?(:tool)
end