Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowV2UndeployConversationModelOperationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowV2UndeployConversationModelOperationMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
Metadata for a ConversationModels.UndeployConversationModel operation.
Instance Attribute Summary collapse
-
#conversation_model ⇒ String
The resource name of the conversation model.
-
#create_time ⇒ String
Timestamp when the request to undeploy conversation model was submitted.
-
#done_time ⇒ String
The time when the operation finished.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowV2UndeployConversationModelOperationMetadata
constructor
A new instance of GoogleCloudDialogflowV2UndeployConversationModelOperationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowV2UndeployConversationModelOperationMetadata
Returns a new instance of GoogleCloudDialogflowV2UndeployConversationModelOperationMetadata.
18925 18926 18927 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 18925 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conversation_model ⇒ String
The resource name of the conversation model. Format: projects//
conversationModels/
Corresponds to the JSON property conversationModel
18912 18913 18914 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 18912 def conversation_model @conversation_model end |
#create_time ⇒ String
Timestamp when the request to undeploy conversation model was submitted. The
time is measured on server side.
Corresponds to the JSON property createTime
18918 18919 18920 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 18918 def create_time @create_time end |
#done_time ⇒ String
The time when the operation finished.
Corresponds to the JSON property doneTime
18923 18924 18925 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 18923 def done_time @done_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18930 18931 18932 18933 18934 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 18930 def update!(**args) @conversation_model = args[:conversation_model] if args.key?(:conversation_model) @create_time = args[:create_time] if args.key?(:create_time) @done_time = args[:done_time] if args.key?(:done_time) end |