Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1AgentCoachingInstructionDuplicateCheckResultDuplicateSuggestion

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

The duplicate suggestion details.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowV2beta1AgentCoachingInstructionDuplicateCheckResultDuplicateSuggestion

Returns a new instance of GoogleCloudDialogflowV2beta1AgentCoachingInstructionDuplicateCheckResultDuplicateSuggestion.



19156
19157
19158
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 19156

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#answer_recordString

Output only. The answer record id of the past duplicate suggestion. Corresponds to the JSON property answerRecord

Returns:

  • (String)


19144
19145
19146
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 19144

def answer_record
  @answer_record
end

#similarity_scoreFloat

Output only. The similarity score of between the past and current suggestion. Corresponds to the JSON property similarityScore

Returns:

  • (Float)


19149
19150
19151
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 19149

def similarity_score
  @similarity_score
end

#suggestion_indexFixnum

Output only. The index of the duplicate suggestion in the past suggestion list. Corresponds to the JSON property suggestionIndex

Returns:

  • (Fixnum)


19154
19155
19156
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 19154

def suggestion_index
  @suggestion_index
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19161
19162
19163
19164
19165
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 19161

def update!(**args)
  @answer_record = args[:answer_record] if args.key?(:answer_record)
  @similarity_score = args[:similarity_score] if args.key?(:similarity_score)
  @suggestion_index = args[:suggestion_index] if args.key?(:suggestion_index)
end