Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1ArticleAnswer
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1ArticleAnswer
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
Represents article answer.
Instance Attribute Summary collapse
-
#answer_record ⇒ String
The name of answer record, in the format of "projects//locations// answerRecords/" Corresponds to the JSON property
answerRecord. -
#metadata ⇒ Hash<String,String>
A map that contains metadata about the answer and the document from which it originates.
-
#snippets ⇒ Array<String>
Output only.
-
#title ⇒ String
The article title.
-
#uri ⇒ String
The article URI.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowV2beta1ArticleAnswer
constructor
A new instance of GoogleCloudDialogflowV2beta1ArticleAnswer.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowV2beta1ArticleAnswer
Returns a new instance of GoogleCloudDialogflowV2beta1ArticleAnswer.
19408 19409 19410 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 19408 def initialize(**args) update!(**args) end |
Instance Attribute Details
#answer_record ⇒ String
The name of answer record, in the format of "projects//locations//
answerRecords/"
Corresponds to the JSON property answerRecord
19385 19386 19387 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 19385 def answer_record @answer_record end |
#metadata ⇒ Hash<String,String>
A map that contains metadata about the answer and the document from which it
originates.
Corresponds to the JSON property metadata
19391 19392 19393 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 19391 def @metadata end |
#snippets ⇒ Array<String>
Output only. Article snippets.
Corresponds to the JSON property snippets
19396 19397 19398 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 19396 def snippets @snippets end |
#title ⇒ String
The article title.
Corresponds to the JSON property title
19401 19402 19403 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 19401 def title @title end |
#uri ⇒ String
The article URI.
Corresponds to the JSON property uri
19406 19407 19408 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 19406 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19413 19414 19415 19416 19417 19418 19419 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 19413 def update!(**args) @answer_record = args[:answer_record] if args.key?(:answer_record) @metadata = args[:metadata] if args.key?(:metadata) @snippets = args[:snippets] if args.key?(:snippets) @title = args[:title] if args.key?(:title) @uri = args[:uri] if args.key?(:uri) end |