Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1EntityType
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1EntityType
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
Each intent parameter has a type, called the entity type, which dictates exactly how data from an end-user expression is extracted. Dialogflow provides predefined system entities that can match many common types of data. For example, there are system entities for matching dates, times, colors, email addresses, and so on. You can also create your own custom entities for matching custom data. For example, you could define a vegetable entity that can match the types of vegetables available for purchase with a grocery store agent. For more information, see the Entity guide.
Instance Attribute Summary collapse
-
#auto_expansion_mode ⇒ String
Optional.
-
#display_name ⇒ String
Required.
-
#enable_fuzzy_extraction ⇒ Boolean
(also: #enable_fuzzy_extraction?)
Optional.
-
#entities ⇒ Array<Google::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1EntityTypeEntity>
Optional.
-
#kind ⇒ String
Required.
-
#name ⇒ String
The unique identifier of the entity type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowV2beta1EntityType
constructor
A new instance of GoogleCloudDialogflowV2beta1EntityType.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowV2beta1EntityType
Returns a new instance of GoogleCloudDialogflowV2beta1EntityType.
19742 19743 19744 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 19742 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_expansion_mode ⇒ String
Optional. Indicates whether the entity type can be automatically expanded.
Corresponds to the JSON property autoExpansionMode
19711 19712 19713 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 19711 def auto_expansion_mode @auto_expansion_mode end |
#display_name ⇒ String
Required. The name of the entity type.
Corresponds to the JSON property displayName
19716 19717 19718 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 19716 def display_name @display_name end |
#enable_fuzzy_extraction ⇒ Boolean Also known as: enable_fuzzy_extraction?
Optional. Enables fuzzy entity extraction during classification.
Corresponds to the JSON property enableFuzzyExtraction
19721 19722 19723 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 19721 def enable_fuzzy_extraction @enable_fuzzy_extraction end |
#entities ⇒ Array<Google::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1EntityTypeEntity>
Optional. The collection of entity entries associated with the entity type.
Corresponds to the JSON property entities
19727 19728 19729 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 19727 def entities @entities end |
#kind ⇒ String
Required. Indicates the kind of entity type.
Corresponds to the JSON property kind
19732 19733 19734 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 19732 def kind @kind end |
#name ⇒ String
The unique identifier of the entity type. Required for EntityTypes.
UpdateEntityType and EntityTypes.BatchUpdateEntityTypes methods. Supported
formats: - projects//agent/entityTypes/ - projects//locations//agent/
entityTypes/
Corresponds to the JSON property name
19740 19741 19742 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 19740 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19747 19748 19749 19750 19751 19752 19753 19754 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 19747 def update!(**args) @auto_expansion_mode = args[:auto_expansion_mode] if args.key?(:auto_expansion_mode) @display_name = args[:display_name] if args.key?(:display_name) @enable_fuzzy_extraction = args[:enable_fuzzy_extraction] if args.key?(:enable_fuzzy_extraction) @entities = args[:entities] if args.key?(:entities) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) end |