Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1FaqAnswer
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1FaqAnswer
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
Represents answer from "frequently asked questions".
Instance Attribute Summary collapse
-
#answer ⇒ String
The piece of text from the
sourceknowledge base document. -
#answer_record ⇒ String
The name of answer record, in the format of "projects//locations// answerRecords/" Corresponds to the JSON property
answerRecord. -
#confidence ⇒ Float
The system's confidence score that this Knowledge answer is a good match for this conversational query, range from 0.0 (completely uncertain) to 1.0 ( completely certain).
-
#metadata ⇒ Hash<String,String>
A map that contains metadata about the answer and the document from which it originates.
-
#question ⇒ String
The corresponding FAQ question.
-
#source ⇒ String
Indicates which Knowledge Document this answer was extracted from.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowV2beta1FaqAnswer
constructor
A new instance of GoogleCloudDialogflowV2beta1FaqAnswer.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowV2beta1FaqAnswer
Returns a new instance of GoogleCloudDialogflowV2beta1FaqAnswer.
19921 19922 19923 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 19921 def initialize(**args) update!(**args) end |
Instance Attribute Details
#answer ⇒ String
The piece of text from the source knowledge base document.
Corresponds to the JSON property answer
19889 19890 19891 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 19889 def answer @answer end |
#answer_record ⇒ String
The name of answer record, in the format of "projects//locations//
answerRecords/"
Corresponds to the JSON property answerRecord
19895 19896 19897 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 19895 def answer_record @answer_record end |
#confidence ⇒ Float
The system's confidence score that this Knowledge answer is a good match for
this conversational query, range from 0.0 (completely uncertain) to 1.0 (
completely certain).
Corresponds to the JSON property confidence
19902 19903 19904 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 19902 def confidence @confidence end |
#metadata ⇒ Hash<String,String>
A map that contains metadata about the answer and the document from which it
originates.
Corresponds to the JSON property metadata
19908 19909 19910 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 19908 def @metadata end |
#question ⇒ String
The corresponding FAQ question.
Corresponds to the JSON property question
19913 19914 19915 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 19913 def question @question end |
#source ⇒ String
Indicates which Knowledge Document this answer was extracted from. Format:
projects//locations//agent/knowledgeBases//documents/.
Corresponds to the JSON property source
19919 19920 19921 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 19919 def source @source end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19926 19927 19928 19929 19930 19931 19932 19933 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 19926 def update!(**args) @answer = args[:answer] if args.key?(:answer) @answer_record = args[:answer_record] if args.key?(:answer_record) @confidence = args[:confidence] if args.key?(:confidence) @metadata = args[:metadata] if args.key?(:metadata) @question = args[:question] if args.key?(:question) @source = args[:source] if args.key?(:source) end |