Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1GenerateSuggestionsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

The response message for Conversations.GenerateSuggestions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowV2beta1GenerateSuggestionsResponse

Returns a new instance of GoogleCloudDialogflowV2beta1GenerateSuggestionsResponse.



19991
19992
19993
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 19991

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#generator_suggestion_answersArray<Google::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1GenerateSuggestionsResponseGeneratorSuggestionAnswer>

The answers generated for the conversation based on context. Corresponds to the JSON property generatorSuggestionAnswers



19983
19984
19985
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 19983

def generator_suggestion_answers
  @generator_suggestion_answers
end

#latest_messageString

The name of the latest conversation message used as context for compiling suggestion. Format: projects//locations//conversations//messages/. Corresponds to the JSON property latestMessage

Returns:

  • (String)


19989
19990
19991
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 19989

def latest_message
  @latest_message
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19996
19997
19998
19999
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 19996

def update!(**args)
  @generator_suggestion_answers = args[:generator_suggestion_answers] if args.key?(:generator_suggestion_answers)
  @latest_message = args[:latest_message] if args.key?(:latest_message)
end