Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1IntentMessage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

Corresponds to the Response field in the Dialogflow console.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowV2beta1IntentMessage

Returns a new instance of GoogleCloudDialogflowV2beta1IntentMessage.



20532
20533
20534
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 20532

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#basic_cardGoogle::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1IntentMessageBasicCard

The basic card message. Useful for displaying information. Corresponds to the JSON property basicCard



20417
20418
20419
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 20417

def basic_card
  @basic_card
end

Browse Carousel Card for Actions on Google. https://developers.google.com/ actions/assistant/responses#browsing_carousel Corresponds to the JSON property browseCarouselCard



20423
20424
20425
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 20423

def browse_carousel_card
  @browse_carousel_card
end

#cardGoogle::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1IntentMessageCard

The card response message. Corresponds to the JSON property card



20428
20429
20430
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 20428

def card
  @card
end

The card for presenting a carousel of options to select from. Corresponds to the JSON property carouselSelect



20433
20434
20435
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 20433

def carousel_select
  @carousel_select
end

#imageGoogle::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1IntentMessageImage

The image response message. Corresponds to the JSON property image



20438
20439
20440
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 20438

def image
  @image
end

The suggestion chip message that allows the user to jump out to the app or website associated with this agent. Corresponds to the JSON property linkOutSuggestion



20444
20445
20446
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 20444

def link_out_suggestion
  @link_out_suggestion
end

#list_selectGoogle::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1IntentMessageListSelect

The card for presenting a list of options to select from. Corresponds to the JSON property listSelect



20449
20450
20451
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 20449

def list_select
  @list_select
end

#media_contentGoogle::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1IntentMessageMediaContent

The media content card for Actions on Google. Corresponds to the JSON property mediaContent



20454
20455
20456
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 20454

def media_content
  @media_content
end

#payloadHash<String,Object>

A custom platform-specific response. Corresponds to the JSON property payload

Returns:

  • (Hash<String,Object>)


20459
20460
20461
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 20459

def payload
  @payload
end

#platformString

Optional. The platform that this message is intended for. Corresponds to the JSON property platform

Returns:

  • (String)


20464
20465
20466
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 20464

def platform
  @platform
end

#quick_repliesGoogle::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1IntentMessageQuickReplies

The quick replies response message. Corresponds to the JSON property quickReplies



20469
20470
20471
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 20469

def quick_replies
  @quick_replies
end

Carousel Rich Business Messaging (RBM) rich card. Rich cards allow you to respond to users with more vivid content, e.g. with media and suggestions. If you want to show a single card with more control over the layout, please use RbmStandaloneCard instead. Corresponds to the JSON property rbmCarouselRichCard



20477
20478
20479
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 20477

def rbm_carousel_rich_card
  @rbm_carousel_rich_card
end

#rbm_standalone_rich_cardGoogle::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1IntentMessageRbmStandaloneCard

Standalone Rich Business Messaging (RBM) rich card. Rich cards allow you to respond to users with more vivid content, e.g. with media and suggestions. You can group multiple rich cards into one using RbmCarouselCard but carousel cards will give you less control over the card layout. Corresponds to the JSON property rbmStandaloneRichCard



20485
20486
20487
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 20485

def rbm_standalone_rich_card
  @rbm_standalone_rich_card
end

#rbm_textGoogle::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1IntentMessageRbmText

Rich Business Messaging (RBM) text response with suggestions. Corresponds to the JSON property rbmText



20490
20491
20492
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 20490

def rbm_text
  @rbm_text
end

#simple_responsesGoogle::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1IntentMessageSimpleResponses

The collection of simple response candidates. This message in QueryResult. fulfillment_messages and WebhookResponse.fulfillment_messages should contain only one SimpleResponse. Corresponds to the JSON property simpleResponses



20497
20498
20499
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 20497

def simple_responses
  @simple_responses
end

#suggestionsGoogle::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1IntentMessageSuggestions

The collection of suggestions. Corresponds to the JSON property suggestions



20502
20503
20504
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 20502

def suggestions
  @suggestions
end

#table_cardGoogle::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1IntentMessageTableCard

Table card for Actions on Google. Corresponds to the JSON property tableCard



20507
20508
20509
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 20507

def table_card
  @table_card
end

#telephony_play_audioGoogle::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1IntentMessageTelephonyPlayAudio

Plays audio from a file in Telephony Gateway. Corresponds to the JSON property telephonyPlayAudio



20512
20513
20514
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 20512

def telephony_play_audio
  @telephony_play_audio
end

#telephony_synthesize_speechGoogle::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1IntentMessageTelephonySynthesizeSpeech

Synthesizes speech and plays back the synthesized audio to the caller in Telephony Gateway. Telephony Gateway takes the synthesizer settings from DetectIntentResponse.output_audio_config which can either be set at request- level or can come from the agent-level synthesizer config. Corresponds to the JSON property telephonySynthesizeSpeech



20520
20521
20522
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 20520

def telephony_synthesize_speech
  @telephony_synthesize_speech
end

#telephony_transfer_callGoogle::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1IntentMessageTelephonyTransferCall

Transfers the call in Telephony Gateway. Corresponds to the JSON property telephonyTransferCall



20525
20526
20527
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 20525

def telephony_transfer_call
  @telephony_transfer_call
end

#textGoogle::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1IntentMessageText

The text response message. Corresponds to the JSON property text



20530
20531
20532
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 20530

def text
  @text
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20537
20538
20539
20540
20541
20542
20543
20544
20545
20546
20547
20548
20549
20550
20551
20552
20553
20554
20555
20556
20557
20558
20559
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 20537

def update!(**args)
  @basic_card = args[:basic_card] if args.key?(:basic_card)
  @browse_carousel_card = args[:browse_carousel_card] if args.key?(:browse_carousel_card)
  @card = args[:card] if args.key?(:card)
  @carousel_select = args[:carousel_select] if args.key?(:carousel_select)
  @image = args[:image] if args.key?(:image)
  @link_out_suggestion = args[:link_out_suggestion] if args.key?(:link_out_suggestion)
  @list_select = args[:list_select] if args.key?(:list_select)
  @media_content = args[:media_content] if args.key?(:media_content)
  @payload = args[:payload] if args.key?(:payload)
  @platform = args[:platform] if args.key?(:platform)
  @quick_replies = args[:quick_replies] if args.key?(:quick_replies)
  @rbm_carousel_rich_card = args[:rbm_carousel_rich_card] if args.key?(:rbm_carousel_rich_card)
  @rbm_standalone_rich_card = args[:rbm_standalone_rich_card] if args.key?(:rbm_standalone_rich_card)
  @rbm_text = args[:rbm_text] if args.key?(:rbm_text)
  @simple_responses = args[:simple_responses] if args.key?(:simple_responses)
  @suggestions = args[:suggestions] if args.key?(:suggestions)
  @table_card = args[:table_card] if args.key?(:table_card)
  @telephony_play_audio = args[:telephony_play_audio] if args.key?(:telephony_play_audio)
  @telephony_synthesize_speech = args[:telephony_synthesize_speech] if args.key?(:telephony_synthesize_speech)
  @telephony_transfer_call = args[:telephony_transfer_call] if args.key?(:telephony_transfer_call)
  @text = args[:text] if args.key?(:text)
end