Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1IntentMessageRbmCarouselCard

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

Carousel Rich Business Messaging (RBM) rich card. Rich cards allow you to respond to users with more vivid content, e.g. with media and suggestions. If you want to show a single card with more control over the layout, please use RbmStandaloneCard instead.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowV2beta1IntentMessageRbmCarouselCard

Returns a new instance of GoogleCloudDialogflowV2beta1IntentMessageRbmCarouselCard.



21206
21207
21208
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 21206

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#card_contentsArray<Google::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1IntentMessageRbmCardContent>

Required. The cards in the carousel. A carousel must have at least 2 cards and at most 10. Corresponds to the JSON property cardContents



21199
21200
21201
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 21199

def card_contents
  @card_contents
end

#card_widthString

Required. The width of the cards in the carousel. Corresponds to the JSON property cardWidth

Returns:

  • (String)


21204
21205
21206
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 21204

def card_width
  @card_width
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21211
21212
21213
21214
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 21211

def update!(**args)
  @card_contents = args[:card_contents] if args.key?(:card_contents)
  @card_width = args[:card_width] if args.key?(:card_width)
end