Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1IntentMessageRbmStandaloneCard

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

Standalone Rich Business Messaging (RBM) rich card. Rich cards allow you to respond to users with more vivid content, e.g. with media and suggestions. You can group multiple rich cards into one using RbmCarouselCard but carousel cards will give you less control over the card layout.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowV2beta1IntentMessageRbmStandaloneCard

Returns a new instance of GoogleCloudDialogflowV2beta1IntentMessageRbmStandaloneCard.



21240
21241
21242
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 21240

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#card_contentGoogle::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1IntentMessageRbmCardContent

Rich Business Messaging (RBM) Card content Corresponds to the JSON property cardContent



21227
21228
21229
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 21227

def card_content
  @card_content
end

#card_orientationString

Required. Orientation of the card. Corresponds to the JSON property cardOrientation

Returns:

  • (String)


21232
21233
21234
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 21232

def card_orientation
  @card_orientation
end

#thumbnail_image_alignmentString

Required if orientation is horizontal. Image preview alignment for standalone cards with horizontal layout. Corresponds to the JSON property thumbnailImageAlignment

Returns:

  • (String)


21238
21239
21240
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 21238

def thumbnail_image_alignment
  @thumbnail_image_alignment
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21245
21246
21247
21248
21249
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 21245

def update!(**args)
  @card_content = args[:card_content] if args.key?(:card_content)
  @card_orientation = args[:card_orientation] if args.key?(:card_orientation)
  @thumbnail_image_alignment = args[:thumbnail_image_alignment] if args.key?(:thumbnail_image_alignment)
end