Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1IntentMessageRbmSuggestedAction

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

Rich Business Messaging (RBM) suggested client-side action that the user can choose from the card.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowV2beta1IntentMessageRbmSuggestedAction

Returns a new instance of GoogleCloudDialogflowV2beta1IntentMessageRbmSuggestedAction.



21289
21290
21291
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 21289

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dialGoogle::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1IntentMessageRbmSuggestedActionRbmSuggestedActionDial

Opens the user's default dialer app with the specified phone number but does not dial automatically. Corresponds to the JSON property dial



21261
21262
21263
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 21261

def dial
  @dial
end

#open_urlGoogle::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1IntentMessageRbmSuggestedActionRbmSuggestedActionOpenUri

Opens the user's default web browser app to the specified uri If the user has an app installed that is registered as the default handler for the URL, then this app will be opened instead, and its icon will be used in the suggested action UI. Corresponds to the JSON property openUrl



21269
21270
21271
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 21269

def open_url
  @open_url
end

#postback_dataString

Opaque payload that the Dialogflow receives in a user event when the user taps the suggested action. This data will be also forwarded to webhook to allow performing custom business logic. Corresponds to the JSON property postbackData

Returns:

  • (String)


21276
21277
21278
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 21276

def postback_data
  @postback_data
end

#share_locationGoogle::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1IntentMessageRbmSuggestedActionRbmSuggestedActionShareLocation

Opens the device's location chooser so the user can pick a location to send back to the agent. Corresponds to the JSON property shareLocation



21282
21283
21284
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 21282

def share_location
  @share_location
end

#textString

Text to display alongside the action. Corresponds to the JSON property text

Returns:

  • (String)


21287
21288
21289
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 21287

def text
  @text
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21294
21295
21296
21297
21298
21299
21300
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 21294

def update!(**args)
  @dial = args[:dial] if args.key?(:dial)
  @open_url = args[:open_url] if args.key?(:open_url)
  @postback_data = args[:postback_data] if args.key?(:postback_data)
  @share_location = args[:share_location] if args.key?(:share_location)
  @text = args[:text] if args.key?(:text)
end