Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1IntentMessageRbmSuggestedActionRbmSuggestedActionOpenUri
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1IntentMessageRbmSuggestedActionRbmSuggestedActionOpenUri
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
Opens the user's default web browser app to the specified uri If the user has an app installed that is registered as the default handler for the URL, then this app will be opened instead, and its icon will be used in the suggested action UI.
Instance Attribute Summary collapse
-
#uri ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowV2beta1IntentMessageRbmSuggestedActionRbmSuggestedActionOpenUri
constructor
A new instance of GoogleCloudDialogflowV2beta1IntentMessageRbmSuggestedActionRbmSuggestedActionOpenUri.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowV2beta1IntentMessageRbmSuggestedActionRbmSuggestedActionOpenUri
Returns a new instance of GoogleCloudDialogflowV2beta1IntentMessageRbmSuggestedActionRbmSuggestedActionOpenUri.
21337 21338 21339 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 21337 def initialize(**args) update!(**args) end |
Instance Attribute Details
#uri ⇒ String
Required. The uri to open on the user device
Corresponds to the JSON property uri
21335 21336 21337 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 21335 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21342 21343 21344 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 21342 def update!(**args) @uri = args[:uri] if args.key?(:uri) end |