Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1IntentMessageRbmSuggestedReply
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1IntentMessageRbmSuggestedReply
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
Rich Business Messaging (RBM) suggested reply that the user can click instead of typing in their own response.
Instance Attribute Summary collapse
-
#postback_data ⇒ String
Opaque payload that the Dialogflow receives in a user event when the user taps the suggested reply.
-
#text ⇒ String
Suggested reply text.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowV2beta1IntentMessageRbmSuggestedReply
constructor
A new instance of GoogleCloudDialogflowV2beta1IntentMessageRbmSuggestedReply.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowV2beta1IntentMessageRbmSuggestedReply
Returns a new instance of GoogleCloudDialogflowV2beta1IntentMessageRbmSuggestedReply.
21378 21379 21380 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 21378 def initialize(**args) update!(**args) end |
Instance Attribute Details
#postback_data ⇒ String
Opaque payload that the Dialogflow receives in a user event when the user taps
the suggested reply. This data will be also forwarded to webhook to allow
performing custom business logic.
Corresponds to the JSON property postbackData
21371 21372 21373 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 21371 def postback_data @postback_data end |
#text ⇒ String
Suggested reply text.
Corresponds to the JSON property text
21376 21377 21378 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 21376 def text @text end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21383 21384 21385 21386 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 21383 def update!(**args) @postback_data = args[:postback_data] if args.key?(:postback_data) @text = args[:text] if args.key?(:text) end |