Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1IntentMessageSuggestion

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

The suggestion chip message that the user can tap to quickly post a reply to the conversation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowV2beta1IntentMessageSuggestion

Returns a new instance of GoogleCloudDialogflowV2beta1IntentMessageSuggestion.



21534
21535
21536
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 21534

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#titleString

Required. The text shown the in the suggestion chip. Corresponds to the JSON property title

Returns:

  • (String)


21532
21533
21534
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 21532

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21539
21540
21541
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 21539

def update!(**args)
  @title = args[:title] if args.key?(:title)
end