Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1IntentTrainingPhrase

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

Represents an example that the agent is trained on.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowV2beta1IntentTrainingPhrase

Returns a new instance of GoogleCloudDialogflowV2beta1IntentTrainingPhrase.



21894
21895
21896
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 21894

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Output only. The unique identifier of this training phrase. Corresponds to the JSON property name

Returns:

  • (String)


21864
21865
21866
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 21864

def name
  @name
end

#partsArray<Google::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1IntentTrainingPhrasePart>

Required. The ordered list of training phrase parts. The parts are concatenated in order to form the training phrase. Note: The API does not automatically annotate training phrases like the Dialogflow Console does. Note: Do not forget to include whitespace at part boundaries, so the training phrase is well formatted when the parts are concatenated. If the training phrase does not need to be annotated with parameters, you just need a single part with only the Part.text field set. If you want to annotate the training phrase, you must create multiple parts, where the fields of each part are populated in one of two ways: - Part.text is set to a part of the phrase that has no parameters. - Part.text is set to a part of the phrase that you want to annotate, and the entity_type, alias, and user_defined fields are all set. Corresponds to the JSON property parts



21880
21881
21882
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 21880

def parts
  @parts
end

#times_added_countFixnum

Optional. Indicates how many times this example was added to the intent. Each time a developer adds an existing sample by editing an intent or training, this counter is increased. Corresponds to the JSON property timesAddedCount

Returns:

  • (Fixnum)


21887
21888
21889
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 21887

def times_added_count
  @times_added_count
end

#typeString

Required. The type of the training phrase. Corresponds to the JSON property type

Returns:

  • (String)


21892
21893
21894
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 21892

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21899
21900
21901
21902
21903
21904
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 21899

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @parts = args[:parts] if args.key?(:parts)
  @times_added_count = args[:times_added_count] if args.key?(:times_added_count)
  @type = args[:type] if args.key?(:type)
end