Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1IntentTrainingPhrasePart

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

Represents a part of a training phrase.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowV2beta1IntentTrainingPhrasePart

Returns a new instance of GoogleCloudDialogflowV2beta1IntentTrainingPhrasePart.



21937
21938
21939
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 21937

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#aliasString

Optional. The parameter name for the value extracted from the annotated part of the example. This field is required for annotated parts of the training phrase. Corresponds to the JSON property alias

Returns:

  • (String)


21916
21917
21918
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 21916

def alias
  @alias
end

#entity_typeString

Optional. The entity type name prefixed with @. This field is required for annotated parts of the training phrase. Corresponds to the JSON property entityType

Returns:

  • (String)


21922
21923
21924
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 21922

def entity_type
  @entity_type
end

#textString

Required. The text for this part. Corresponds to the JSON property text

Returns:

  • (String)


21927
21928
21929
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 21927

def text
  @text
end

#user_definedBoolean Also known as: user_defined?

Optional. Indicates whether the text was manually annotated. This field is set to true when the Dialogflow Console is used to manually annotate the part. When creating an annotated part with the API, you must set this to true. Corresponds to the JSON property userDefined

Returns:

  • (Boolean)


21934
21935
21936
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 21934

def user_defined
  @user_defined
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21942
21943
21944
21945
21946
21947
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 21942

def update!(**args)
  @alias = args[:alias] if args.key?(:alias)
  @entity_type = args[:entity_type] if args.key?(:entity_type)
  @text = args[:text] if args.key?(:text)
  @user_defined = args[:user_defined] if args.key?(:user_defined)
end