Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1KnowledgeAnswersAnswer

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

An answer from Knowledge Connector.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowV2beta1KnowledgeAnswersAnswer

Returns a new instance of GoogleCloudDialogflowV2beta1KnowledgeAnswersAnswer.



22010
22011
22012
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 22010

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#answerString

The piece of text from the source knowledge base document that answers this conversational query. Corresponds to the JSON property answer

Returns:

  • (String)


21977
21978
21979
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 21977

def answer
  @answer
end

#faq_questionString

The corresponding FAQ question if the answer was extracted from a FAQ Document, empty otherwise. Corresponds to the JSON property faqQuestion

Returns:

  • (String)


21983
21984
21985
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 21983

def faq_question
  @faq_question
end

#match_confidenceFloat

The system's confidence score that this Knowledge answer is a good match for this conversational query. The range is from 0.0 (completely uncertain) to 1.0 (completely certain). Note: The confidence score is likely to vary somewhat ( possibly even for identical requests), as the underlying model is under constant improvement. It may be deprecated in the future. We recommend using match_confidence_level which should be generally more stable. Corresponds to the JSON property matchConfidence

Returns:

  • (Float)


21993
21994
21995
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 21993

def match_confidence
  @match_confidence
end

#match_confidence_levelString

The system's confidence level that this knowledge answer is a good match for this conversational query. NOTE: The confidence level for a given `pair may change without notice, as it depends on models that are constantly being improved. However, it will change less frequently than the confidence score below, and should be preferred for referencing the quality of an answer. Corresponds to the JSON propertymatchConfidenceLevel`

Returns:

  • (String)


22002
22003
22004
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 22002

def match_confidence_level
  @match_confidence_level
end

#sourceString

Indicates which Knowledge Document this answer was extracted from. Format: projects//knowledgeBases//documents/. Corresponds to the JSON property source

Returns:

  • (String)


22008
22009
22010
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 22008

def source
  @source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22015
22016
22017
22018
22019
22020
22021
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 22015

def update!(**args)
  @answer = args[:answer] if args.key?(:answer)
  @faq_question = args[:faq_question] if args.key?(:faq_question)
  @match_confidence = args[:match_confidence] if args.key?(:match_confidence)
  @match_confidence_level = args[:match_confidence_level] if args.key?(:match_confidence_level)
  @source = args[:source] if args.key?(:source)
end