Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1ResponseMessage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

Response messages from an automated agent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowV2beta1ResponseMessage

Returns a new instance of GoogleCloudDialogflowV2beta1ResponseMessage.



22583
22584
22585
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 22583

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_interactionGoogle::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1ResponseMessageEndInteraction

Indicates that interaction with the Dialogflow agent has ended. Corresponds to the JSON property endInteraction



22548
22549
22550
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 22548

def end_interaction
  @end_interaction
end

#live_agent_handoffGoogle::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1ResponseMessageLiveAgentHandoff

Indicates that the conversation should be handed off to a human agent. Dialogflow only uses this to determine which conversations were handed off to a human agent for measurement purposes. What else to do with this signal is up to you and your handoff procedures. You may set this, for example: * In the entry fulfillment of a Dialogflow CX Page if entering the page indicates something went extremely wrong in the conversation. * In a webhook response when you determine that the customer issue can only be handled by a human. Corresponds to the JSON property liveAgentHandoff



22559
22560
22561
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 22559

def live_agent_handoff
  @live_agent_handoff
end

#mixed_audioGoogle::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1ResponseMessageMixedAudio

Represents an audio message that is composed of both segments synthesized from the Dialogflow agent prompts and ones hosted externally at the specified URIs. Corresponds to the JSON property mixedAudio



22565
22566
22567
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 22565

def mixed_audio
  @mixed_audio
end

#payloadHash<String,Object>

Returns a response containing a custom, platform-specific payload. Corresponds to the JSON property payload

Returns:

  • (Hash<String,Object>)


22570
22571
22572
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 22570

def payload
  @payload
end

#telephony_transfer_callGoogle::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1ResponseMessageTelephonyTransferCall

Represents the signal that telles the client to transfer the phone call connected to the agent to a third-party endpoint. Corresponds to the JSON property telephonyTransferCall



22576
22577
22578
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 22576

def telephony_transfer_call
  @telephony_transfer_call
end

#textGoogle::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1ResponseMessageText

The text response message. Corresponds to the JSON property text



22581
22582
22583
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 22581

def text
  @text
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22588
22589
22590
22591
22592
22593
22594
22595
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 22588

def update!(**args)
  @end_interaction = args[:end_interaction] if args.key?(:end_interaction)
  @live_agent_handoff = args[:live_agent_handoff] if args.key?(:live_agent_handoff)
  @mixed_audio = args[:mixed_audio] if args.key?(:mixed_audio)
  @payload = args[:payload] if args.key?(:payload)
  @telephony_transfer_call = args[:telephony_transfer_call] if args.key?(:telephony_transfer_call)
  @text = args[:text] if args.key?(:text)
end