Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1ResponseMessageMixedAudioSegment
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1ResponseMessageMixedAudioSegment
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
Represents one segment of audio.
Instance Attribute Summary collapse
-
#allow_playback_interruption ⇒ Boolean
(also: #allow_playback_interruption?)
Whether the playback of this segment can be interrupted by the end user's speech and the client should then start the next Dialogflow request.
-
#audio ⇒ String
Raw audio synthesized from the Dialogflow agent's response using the output config specified in the request.
-
#uri ⇒ String
Client-specific URI that points to an audio clip accessible to the client.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowV2beta1ResponseMessageMixedAudioSegment
constructor
A new instance of GoogleCloudDialogflowV2beta1ResponseMessageMixedAudioSegment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowV2beta1ResponseMessageMixedAudioSegment
Returns a new instance of GoogleCloudDialogflowV2beta1ResponseMessageMixedAudioSegment.
22680 22681 22682 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 22680 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allow_playback_interruption ⇒ Boolean Also known as: allow_playback_interruption?
Whether the playback of this segment can be interrupted by the end user's
speech and the client should then start the next Dialogflow request.
Corresponds to the JSON property allowPlaybackInterruption
22665 22666 22667 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 22665 def allow_playback_interruption @allow_playback_interruption end |
#audio ⇒ String
Raw audio synthesized from the Dialogflow agent's response using the output
config specified in the request.
Corresponds to the JSON property audio
NOTE: Values are automatically base64 encoded/decoded in the client library.
22673 22674 22675 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 22673 def audio @audio end |
#uri ⇒ String
Client-specific URI that points to an audio clip accessible to the client.
Corresponds to the JSON property uri
22678 22679 22680 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 22678 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22685 22686 22687 22688 22689 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 22685 def update!(**args) @allow_playback_interruption = args[:allow_playback_interruption] if args.key?(:allow_playback_interruption) @audio = args[:audio] if args.key?(:audio) @uri = args[:uri] if args.key?(:uri) end |