Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1SpeechWordInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

Information for a word recognized by the speech recognizer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowV2beta1SpeechWordInfo

Returns a new instance of GoogleCloudDialogflowV2beta1SpeechWordInfo.



22948
22949
22950
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 22948

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#confidenceFloat

The Speech confidence between 0.0 and 1.0 for this word. A higher number indicates an estimated greater likelihood that the recognized word is correct. The default of 0.0 is a sentinel value indicating that confidence was not set. This field is not guaranteed to be fully stable over time for the same audio input. Users should also not rely on it to always be provided. Corresponds to the JSON property confidence

Returns:

  • (Float)


22927
22928
22929
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 22927

def confidence
  @confidence
end

#end_offsetString

Time offset relative to the beginning of the audio that corresponds to the end of the spoken word. This is an experimental feature and the accuracy of the time offset can vary. Corresponds to the JSON property endOffset

Returns:

  • (String)


22934
22935
22936
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 22934

def end_offset
  @end_offset
end

#start_offsetString

Time offset relative to the beginning of the audio that corresponds to the start of the spoken word. This is an experimental feature and the accuracy of the time offset can vary. Corresponds to the JSON property startOffset

Returns:

  • (String)


22941
22942
22943
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 22941

def start_offset
  @start_offset
end

#wordString

The word this info is for. Corresponds to the JSON property word

Returns:

  • (String)


22946
22947
22948
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 22946

def word
  @word
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22953
22954
22955
22956
22957
22958
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 22953

def update!(**args)
  @confidence = args[:confidence] if args.key?(:confidence)
  @end_offset = args[:end_offset] if args.key?(:end_offset)
  @start_offset = args[:start_offset] if args.key?(:start_offset)
  @word = args[:word] if args.key?(:word)
end