Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1SuggestSmartRepliesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

The response message for Participants.SuggestSmartReplies.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowV2beta1SuggestSmartRepliesResponse

Returns a new instance of GoogleCloudDialogflowV2beta1SuggestSmartRepliesResponse.



23230
23231
23232
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 23230

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#context_sizeFixnum

Number of messages prior to and including latest_message to compile the suggestion. It may be smaller than the SuggestSmartRepliesRequest.context_size field in the request if there aren't that many messages in the conversation. Corresponds to the JSON property contextSize

Returns:

  • (Fixnum)


23215
23216
23217
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 23215

def context_size
  @context_size
end

#latest_messageString

The name of the latest conversation message used to compile suggestion for. Format: projects//locations//conversations//messages/. Corresponds to the JSON property latestMessage

Returns:

  • (String)


23221
23222
23223
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 23221

def latest_message
  @latest_message
end

#smart_reply_answersArray<Google::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1SmartReplyAnswer>

Output only. Multiple reply options provided by smart reply service. The order is based on the rank of the model prediction. The maximum number of the returned replies is set in SmartReplyConfig. Corresponds to the JSON property smartReplyAnswers



23228
23229
23230
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 23228

def smart_reply_answers
  @smart_reply_answers
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23235
23236
23237
23238
23239
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 23235

def update!(**args)
  @context_size = args[:context_size] if args.key?(:context_size)
  @latest_message = args[:latest_message] if args.key?(:latest_message)
  @smart_reply_answers = args[:smart_reply_answers] if args.key?(:smart_reply_answers)
end