Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1SuggestionResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

One response of different type of suggestion response which is used in the response of Participants.AnalyzeContent and Participants.AnalyzeContent, as well as HumanAgentAssistantEvent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowV2beta1SuggestionResult

Returns a new instance of GoogleCloudDialogflowV2beta1SuggestionResult.



23293
23294
23295
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 23293

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorGoogle::Apis::DialogflowV3::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



23256
23257
23258
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 23256

def error
  @error
end

#generate_suggestions_responseGoogle::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1GenerateSuggestionsResponse

The response message for Conversations.GenerateSuggestions. Corresponds to the JSON property generateSuggestionsResponse



23261
23262
23263
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 23261

def generate_suggestions_response
  @generate_suggestions_response
end

#suggest_articles_responseGoogle::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1SuggestArticlesResponse

The response message for Participants.SuggestArticles. Corresponds to the JSON property suggestArticlesResponse



23266
23267
23268
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 23266

def suggest_articles_response
  @suggest_articles_response
end

#suggest_dialogflow_assists_responseGoogle::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1SuggestDialogflowAssistsResponse

The response message for Participants.SuggestDialogflowAssists. Corresponds to the JSON property suggestDialogflowAssistsResponse



23271
23272
23273
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 23271

def suggest_dialogflow_assists_response
  @suggest_dialogflow_assists_response
end

#suggest_entity_extraction_responseGoogle::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1SuggestDialogflowAssistsResponse

The response message for Participants.SuggestDialogflowAssists. Corresponds to the JSON property suggestEntityExtractionResponse



23276
23277
23278
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 23276

def suggest_entity_extraction_response
  @suggest_entity_extraction_response
end

#suggest_faq_answers_responseGoogle::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1SuggestFaqAnswersResponse

The request message for Participants.SuggestFaqAnswers. Corresponds to the JSON property suggestFaqAnswersResponse



23281
23282
23283
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 23281

def suggest_faq_answers_response
  @suggest_faq_answers_response
end

#suggest_knowledge_assist_responseGoogle::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1SuggestKnowledgeAssistResponse

The response message for Participants.SuggestKnowledgeAssist. Corresponds to the JSON property suggestKnowledgeAssistResponse



23286
23287
23288
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 23286

def suggest_knowledge_assist_response
  @suggest_knowledge_assist_response
end

#suggest_smart_replies_responseGoogle::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1SuggestSmartRepliesResponse

The response message for Participants.SuggestSmartReplies. Corresponds to the JSON property suggestSmartRepliesResponse



23291
23292
23293
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 23291

def suggest_smart_replies_response
  @suggest_smart_replies_response
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23298
23299
23300
23301
23302
23303
23304
23305
23306
23307
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 23298

def update!(**args)
  @error = args[:error] if args.key?(:error)
  @generate_suggestions_response = args[:generate_suggestions_response] if args.key?(:generate_suggestions_response)
  @suggest_articles_response = args[:suggest_articles_response] if args.key?(:suggest_articles_response)
  @suggest_dialogflow_assists_response = args[:suggest_dialogflow_assists_response] if args.key?(:suggest_dialogflow_assists_response)
  @suggest_entity_extraction_response = args[:suggest_entity_extraction_response] if args.key?(:suggest_entity_extraction_response)
  @suggest_faq_answers_response = args[:suggest_faq_answers_response] if args.key?(:suggest_faq_answers_response)
  @suggest_knowledge_assist_response = args[:suggest_knowledge_assist_response] if args.key?(:suggest_knowledge_assist_response)
  @suggest_smart_replies_response = args[:suggest_smart_replies_response] if args.key?(:suggest_smart_replies_response)
end