Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1ToolCall

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

Represents a call of a specific tool's action with the specified inputs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowV2beta1ToolCall

Returns a new instance of GoogleCloudDialogflowV2beta1ToolCall.



23418
23419
23420
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 23418

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionString

Optional. The name of the tool's action associated with this call. Corresponds to the JSON property action

Returns:

  • (String)


23380
23381
23382
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 23380

def action
  @action
end

#answer_recordString

Optional. The answer record associated with this tool call. Corresponds to the JSON property answerRecord

Returns:

  • (String)


23385
23386
23387
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 23385

def answer_record
  @answer_record
end

#create_timeString

Output only. Create time of the tool call. Corresponds to the JSON property createTime

Returns:

  • (String)


23390
23391
23392
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 23390

def create_time
  @create_time
end

#input_parametersHash<String,Object>

Optional. The action's input parameters. Corresponds to the JSON property inputParameters

Returns:

  • (Hash<String,Object>)


23395
23396
23397
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 23395

def input_parameters
  @input_parameters
end

#stateString

Output only. State of the tool call Corresponds to the JSON property state

Returns:

  • (String)


23400
23401
23402
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 23400

def state
  @state
end

#toolString

Optional. The tool associated with this call. Format: projects//locations// tools/. Corresponds to the JSON property tool

Returns:

  • (String)


23406
23407
23408
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 23406

def tool
  @tool
end

#tool_display_detailsString

Optional. A human readable description of the tool. Corresponds to the JSON property toolDisplayDetails

Returns:

  • (String)


23411
23412
23413
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 23411

def tool_display_details
  @tool_display_details
end

#tool_display_nameString

Optional. A human readable short name of the tool, to be shown on the UI. Corresponds to the JSON property toolDisplayName

Returns:

  • (String)


23416
23417
23418
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 23416

def tool_display_name
  @tool_display_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23423
23424
23425
23426
23427
23428
23429
23430
23431
23432
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 23423

def update!(**args)
  @action = args[:action] if args.key?(:action)
  @answer_record = args[:answer_record] if args.key?(:answer_record)
  @create_time = args[:create_time] if args.key?(:create_time)
  @input_parameters = args[:input_parameters] if args.key?(:input_parameters)
  @state = args[:state] if args.key?(:state)
  @tool = args[:tool] if args.key?(:tool)
  @tool_display_details = args[:tool_display_details] if args.key?(:tool_display_details)
  @tool_display_name = args[:tool_display_name] if args.key?(:tool_display_name)
end