Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowV3alpha1ConversationSignals

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

This message is used to hold all the Conversation Signals data, which will be converted to JSON and exported to BigQuery.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowV3alpha1ConversationSignals

Returns a new instance of GoogleCloudDialogflowV3alpha1ConversationSignals.



23675
23676
23677
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 23675

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#turn_signalsGoogle::Apis::DialogflowV3::GoogleCloudDialogflowV3alpha1TurnSignals

Collection of all signals that were extracted for a single turn of the conversation. Corresponds to the JSON property turnSignals



23673
23674
23675
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 23673

def turn_signals
  @turn_signals
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23680
23681
23682
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 23680

def update!(**args)
  @turn_signals = args[:turn_signals] if args.key?(:turn_signals)
end