Class: Google::Apis::DialogflowV3::GoogleLongrunningListOperationsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb

Overview

The response message for Operations.ListOperations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleLongrunningListOperationsResponse

Returns a new instance of GoogleLongrunningListOperationsResponse.



23869
23870
23871
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 23869

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

The standard List next-page token. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


23854
23855
23856
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 23854

def next_page_token
  @next_page_token
end

#operationsArray<Google::Apis::DialogflowV3::GoogleLongrunningOperation>

A list of operations that matches the specified filter in the request. Corresponds to the JSON property operations



23859
23860
23861
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 23859

def operations
  @operations
end

#unreachableArray<String>

Unordered list. Unreachable resources. Populated when the request sets ListOperationsRequest.return_partial_success and reads across collections. For example, when attempting to list all resources across all supported locations. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


23867
23868
23869
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 23867

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23874
23875
23876
23877
23878
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 23874

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @operations = args[:operations] if args.key?(:operations)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end