Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3Action
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3Action
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
Action performed by end user or Dialogflow agent in the conversation.
Instance Attribute Summary collapse
-
#agent_utterance ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3AgentUtterance
AgentUtterance represents one message sent by the agent.
-
#flow_invocation ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3FlowInvocation
Stores metadata of the invocation of a CX flow.
-
#flow_transition ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3FlowTransition
Stores metadata of the transition to a target CX flow.
-
#playbook_invocation ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3PlaybookInvocation
Stores metadata of the invocation of a child playbook.
-
#playbook_transition ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3PlaybookTransition
Stores metadata of the transition to another target playbook.
-
#tool_use ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3ToolUse
Stores metadata of the invocation of an action supported by a tool.
-
#user_utterance ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3UserUtterance
UserUtterance represents one message sent by the customer.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3Action
constructor
A new instance of GoogleCloudDialogflowCxV3Action.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3Action
Returns a new instance of GoogleCloudDialogflowCxV3Action.
66 67 68 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 66 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_utterance ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3AgentUtterance
AgentUtterance represents one message sent by the agent.
Corresponds to the JSON property agentUtterance
32 33 34 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 32 def agent_utterance @agent_utterance end |
#flow_invocation ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3FlowInvocation
Stores metadata of the invocation of a CX flow.
Corresponds to the JSON property flowInvocation
37 38 39 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 37 def flow_invocation @flow_invocation end |
#flow_transition ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3FlowTransition
Stores metadata of the transition to a target CX flow. Flow transition actions
exit the caller playbook and enter the child flow.
Corresponds to the JSON property flowTransition
43 44 45 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 43 def flow_transition @flow_transition end |
#playbook_invocation ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3PlaybookInvocation
Stores metadata of the invocation of a child playbook.
Corresponds to the JSON property playbookInvocation
48 49 50 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 48 def playbook_invocation @playbook_invocation end |
#playbook_transition ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3PlaybookTransition
Stores metadata of the transition to another target playbook. Playbook
transition actions exit the caller playbook and enter the target playbook.
Corresponds to the JSON property playbookTransition
54 55 56 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 54 def playbook_transition @playbook_transition end |
#tool_use ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3ToolUse
Stores metadata of the invocation of an action supported by a tool.
Corresponds to the JSON property toolUse
59 60 61 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 59 def tool_use @tool_use end |
#user_utterance ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3UserUtterance
UserUtterance represents one message sent by the customer.
Corresponds to the JSON property userUtterance
64 65 66 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 64 def user_utterance @user_utterance end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
71 72 73 74 75 76 77 78 79 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 71 def update!(**args) @agent_utterance = args[:agent_utterance] if args.key?(:agent_utterance) @flow_invocation = args[:flow_invocation] if args.key?(:flow_invocation) @flow_transition = args[:flow_transition] if args.key?(:flow_transition) @playbook_invocation = args[:playbook_invocation] if args.key?(:playbook_invocation) @playbook_transition = args[:playbook_transition] if args.key?(:playbook_transition) @tool_use = args[:tool_use] if args.key?(:tool_use) @user_utterance = args[:user_utterance] if args.key?(:user_utterance) end |