Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3AdvancedSettings
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3AdvancedSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
Hierarchical advanced settings for agent/flow/page/fulfillment/parameter. Settings exposed at lower level overrides the settings exposed at higher level. Overriding occurs at the sub-setting level. For example, the playback_interruption_settings at fulfillment level only overrides the playback_interruption_settings at the agent level, leaving other settings at the agent level unchanged. DTMF settings does not override each other. DTMF settings set at different levels define DTMF detections running in parallel. Hierarchy: Agent->Flow->Page->Fulfillment/Parameter.
Instance Attribute Summary collapse
-
#audio_export_gcs_destination ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3GcsDestination
Google Cloud Storage location for a Dialogflow operation that writes or exports objects (e.g. exported agent or transcripts) outside of Dialogflow.
-
#dtmf_settings ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3AdvancedSettingsDtmfSettings
Define behaviors for DTMF (dual tone multi frequency).
-
#logging_settings ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3AdvancedSettingsLoggingSettings
Define behaviors on logging.
-
#speech_settings ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3AdvancedSettingsSpeechSettings
Define behaviors of speech to text detection.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3AdvancedSettings
constructor
A new instance of GoogleCloudDialogflowCxV3AdvancedSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3AdvancedSettings
Returns a new instance of GoogleCloudDialogflowCxV3AdvancedSettings.
114 115 116 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 114 def initialize(**args) update!(**args) end |
Instance Attribute Details
#audio_export_gcs_destination ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3GcsDestination
Google Cloud Storage location for a Dialogflow operation that writes or
exports objects (e.g. exported agent or transcripts) outside of Dialogflow.
Corresponds to the JSON property audioExportGcsDestination
97 98 99 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 97 def audio_export_gcs_destination @audio_export_gcs_destination end |
#dtmf_settings ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3AdvancedSettingsDtmfSettings
Define behaviors for DTMF (dual tone multi frequency).
Corresponds to the JSON property dtmfSettings
102 103 104 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 102 def dtmf_settings @dtmf_settings end |
#logging_settings ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3AdvancedSettingsLoggingSettings
Define behaviors on logging.
Corresponds to the JSON property loggingSettings
107 108 109 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 107 def logging_settings @logging_settings end |
#speech_settings ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3AdvancedSettingsSpeechSettings
Define behaviors of speech to text detection.
Corresponds to the JSON property speechSettings
112 113 114 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 112 def speech_settings @speech_settings end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
119 120 121 122 123 124 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 119 def update!(**args) @audio_export_gcs_destination = args[:audio_export_gcs_destination] if args.key?(:audio_export_gcs_destination) @dtmf_settings = args[:dtmf_settings] if args.key?(:dtmf_settings) @logging_settings = args[:logging_settings] if args.key?(:logging_settings) @speech_settings = args[:speech_settings] if args.key?(:speech_settings) end |