Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3Agent
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3Agent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
Agents are best described as Natural Language Understanding (NLU) modules that transform user requests into actionable data. You can include agents in your app, product, or service to determine user intent and respond to the user in a natural way. After you create an agent, you can add Intents, Entity Types, Flows, Fulfillments, Webhooks, TransitionRouteGroups and so on to manage the conversation flows.
Instance Attribute Summary collapse
-
#advanced_settings ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3AdvancedSettings
Hierarchical advanced settings for agent/flow/page/fulfillment/parameter.
-
#answer_feedback_settings ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3AgentAnswerFeedbackSettings
Settings for answer feedback collection.
-
#avatar_uri ⇒ String
The URI of the agent's avatar.
-
#client_certificate_settings ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3AgentClientCertificateSettings
Settings for custom client certificates.
-
#default_language_code ⇒ String
Required.
-
#description ⇒ String
The description of the agent.
-
#display_name ⇒ String
Required.
-
#enable_multi_language_training ⇒ Boolean
(also: #enable_multi_language_training?)
Optional.
-
#enable_spell_correction ⇒ Boolean
(also: #enable_spell_correction?)
Indicates if automatic spell correction is enabled in detect intent requests.
-
#enable_stackdriver_logging ⇒ Boolean
(also: #enable_stackdriver_logging?)
Indicates if stackdriver logging is enabled for the agent.
-
#gen_app_builder_settings ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3AgentGenAppBuilderSettings
Settings for Gen App Builder.
-
#git_integration_settings ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3AgentGitIntegrationSettings
Settings for connecting to Git repository for an agent.
-
#locked ⇒ Boolean
(also: #locked?)
Indicates whether the agent is locked for changes.
-
#name ⇒ String
The unique identifier of the agent.
-
#personalization_settings ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3AgentPersonalizationSettings
Settings for end user personalization.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Optional.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Optional.
-
#security_settings ⇒ String
Name of the SecuritySettings reference for the agent.
-
#speech_to_text_settings ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3SpeechToTextSettings
Settings related to speech recognition.
-
#start_flow ⇒ String
Name of the start flow in this agent.
-
#start_playbook ⇒ String
Name of the start playbook in this agent.
-
#supported_language_codes ⇒ Array<String>
The list of all languages supported by the agent (except for the
default_language_code). -
#text_to_speech_settings ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3TextToSpeechSettings
Settings related to speech synthesizing.
-
#time_zone ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3Agent
constructor
A new instance of GoogleCloudDialogflowCxV3Agent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3Agent
Returns a new instance of GoogleCloudDialogflowCxV3Agent.
419 420 421 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 419 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advanced_settings ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3AdvancedSettings
Hierarchical advanced settings for agent/flow/page/fulfillment/parameter.
Settings exposed at lower level overrides the settings exposed at higher level.
Overriding occurs at the sub-setting level. For example, the
playback_interruption_settings at fulfillment level only overrides the
playback_interruption_settings at the agent level, leaving other settings at
the agent level unchanged. DTMF settings does not override each other. DTMF
settings set at different levels define DTMF detections running in parallel.
Hierarchy: Agent->Flow->Page->Fulfillment/Parameter.
Corresponds to the JSON property advancedSettings
273 274 275 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 273 def advanced_settings @advanced_settings end |
#answer_feedback_settings ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3AgentAnswerFeedbackSettings
Settings for answer feedback collection.
Corresponds to the JSON property answerFeedbackSettings
278 279 280 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 278 def answer_feedback_settings @answer_feedback_settings end |
#avatar_uri ⇒ String
The URI of the agent's avatar. Avatars are used throughout the Dialogflow
console and in the self-hosted Web Demo integration.
Corresponds to the JSON property avatarUri
285 286 287 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 285 def avatar_uri @avatar_uri end |
#client_certificate_settings ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3AgentClientCertificateSettings
Settings for custom client certificates.
Corresponds to the JSON property clientCertificateSettings
290 291 292 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 290 def client_certificate_settings @client_certificate_settings end |
#default_language_code ⇒ String
Required. Immutable. The default language of the agent as a language tag. See
Language Support for a list of the currently supported language codes. This field
cannot be set by the Agents.UpdateAgent method.
Corresponds to the JSON property defaultLanguageCode
298 299 300 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 298 def default_language_code @default_language_code end |
#description ⇒ String
The description of the agent. The maximum length is 500 characters. If
exceeded, the request is rejected.
Corresponds to the JSON property description
304 305 306 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 304 def description @description end |
#display_name ⇒ String
Required. The human-readable name of the agent, unique within the location.
Corresponds to the JSON property displayName
309 310 311 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 309 def display_name @display_name end |
#enable_multi_language_training ⇒ Boolean Also known as: enable_multi_language_training?
Optional. Enable training multi-lingual models for this agent. These models
will be trained on all the languages supported by the agent.
Corresponds to the JSON property enableMultiLanguageTraining
315 316 317 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 315 def enable_multi_language_training @enable_multi_language_training end |
#enable_spell_correction ⇒ Boolean Also known as: enable_spell_correction?
Indicates if automatic spell correction is enabled in detect intent requests.
Corresponds to the JSON property enableSpellCorrection
321 322 323 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 321 def enable_spell_correction @enable_spell_correction end |
#enable_stackdriver_logging ⇒ Boolean Also known as: enable_stackdriver_logging?
Indicates if stackdriver logging is enabled for the agent. Please use agent.
advanced_settings instead.
Corresponds to the JSON property enableStackdriverLogging
328 329 330 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 328 def enable_stackdriver_logging @enable_stackdriver_logging end |
#gen_app_builder_settings ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3AgentGenAppBuilderSettings
Settings for Gen App Builder.
Corresponds to the JSON property genAppBuilderSettings
334 335 336 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 334 def gen_app_builder_settings @gen_app_builder_settings end |
#git_integration_settings ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3AgentGitIntegrationSettings
Settings for connecting to Git repository for an agent.
Corresponds to the JSON property gitIntegrationSettings
339 340 341 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 339 def git_integration_settings @git_integration_settings end |
#locked ⇒ Boolean Also known as: locked?
Indicates whether the agent is locked for changes. If the agent is locked,
modifications to the agent will be rejected except for RestoreAgent.
Corresponds to the JSON property locked
345 346 347 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 345 def locked @locked end |
#name ⇒ String
The unique identifier of the agent. Required for the Agents.UpdateAgent method.
Agents.CreateAgent populates the name automatically. Format: projects//
locations//agents/.
Corresponds to the JSON property name
353 354 355 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 353 def name @name end |
#personalization_settings ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3AgentPersonalizationSettings
Settings for end user personalization.
Corresponds to the JSON property personalizationSettings
358 359 360 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 358 def personalization_settings @personalization_settings end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Optional. Output only. A read only boolean field reflecting Zone Isolation
status of the agent.
Corresponds to the JSON property satisfiesPzi
364 365 366 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 364 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Optional. Output only. A read only boolean field reflecting Zone Separation
status of the agent.
Corresponds to the JSON property satisfiesPzs
371 372 373 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 371 def satisfies_pzs @satisfies_pzs end |
#security_settings ⇒ String
Name of the SecuritySettings reference for the agent. Format: projects//
locations//securitySettings/.
Corresponds to the JSON property securitySettings
378 379 380 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 378 def security_settings @security_settings end |
#speech_to_text_settings ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3SpeechToTextSettings
Settings related to speech recognition.
Corresponds to the JSON property speechToTextSettings
383 384 385 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 383 def speech_to_text_settings @speech_to_text_settings end |
#start_flow ⇒ String
Name of the start flow in this agent. A start flow will be automatically
created when the agent is created, and can only be deleted by deleting the
agent. Format: projects//locations//agents//flows/. Currently only the
default start flow with id "00000000-0000-0000-0000-000000000000" is allowed.
Corresponds to the JSON property startFlow
391 392 393 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 391 def start_flow @start_flow end |
#start_playbook ⇒ String
Name of the start playbook in this agent. A start playbook will be
automatically created when the agent is created, and can only be deleted by
deleting the agent. Format: projects//locations//agents//playbooks/.
Currently only the default playbook with id "00000000-0000-0000-0000-
000000000000" is allowed.
Corresponds to the JSON property startPlaybook
400 401 402 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 400 def start_playbook @start_playbook end |
#supported_language_codes ⇒ Array<String>
The list of all languages supported by the agent (except for the
default_language_code).
Corresponds to the JSON property supportedLanguageCodes
406 407 408 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 406 def supported_language_codes @supported_language_codes end |
#text_to_speech_settings ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3TextToSpeechSettings
Settings related to speech synthesizing.
Corresponds to the JSON property textToSpeechSettings
411 412 413 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 411 def text_to_speech_settings @text_to_speech_settings end |
#time_zone ⇒ String
Required. The time zone of the agent from the time zone database, e.g., America/New_York, Europe/Paris.
Corresponds to the JSON property timeZone
417 418 419 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 417 def time_zone @time_zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 424 def update!(**args) @advanced_settings = args[:advanced_settings] if args.key?(:advanced_settings) @answer_feedback_settings = args[:answer_feedback_settings] if args.key?(:answer_feedback_settings) @avatar_uri = args[:avatar_uri] if args.key?(:avatar_uri) @client_certificate_settings = args[:client_certificate_settings] if args.key?(:client_certificate_settings) @default_language_code = args[:default_language_code] if args.key?(:default_language_code) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @enable_multi_language_training = args[:enable_multi_language_training] if args.key?(:enable_multi_language_training) @enable_spell_correction = args[:enable_spell_correction] if args.key?(:enable_spell_correction) @enable_stackdriver_logging = args[:enable_stackdriver_logging] if args.key?(:enable_stackdriver_logging) @gen_app_builder_settings = args[:gen_app_builder_settings] if args.key?(:gen_app_builder_settings) @git_integration_settings = args[:git_integration_settings] if args.key?(:git_integration_settings) @locked = args[:locked] if args.key?(:locked) @name = args[:name] if args.key?(:name) @personalization_settings = args[:personalization_settings] if args.key?(:personalization_settings) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @security_settings = args[:security_settings] if args.key?(:security_settings) @speech_to_text_settings = args[:speech_to_text_settings] if args.key?(:speech_to_text_settings) @start_flow = args[:start_flow] if args.key?(:start_flow) @start_playbook = args[:start_playbook] if args.key?(:start_playbook) @supported_language_codes = args[:supported_language_codes] if args.key?(:supported_language_codes) @text_to_speech_settings = args[:text_to_speech_settings] if args.key?(:text_to_speech_settings) @time_zone = args[:time_zone] if args.key?(:time_zone) end |