Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3EventHandler
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3EventHandler
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
An event handler specifies an event that can be handled during a session. When
the specified event happens, the following actions are taken in order: * If
there is a trigger_fulfillment associated with the event, it will be called.
- If there is a
target_pageassociated with the event, the session will transition into the specified page. * If there is atarget_flowassociated with the event, the session will transition into the specified flow.
Instance Attribute Summary collapse
-
#event ⇒ String
Required.
-
#name ⇒ String
Output only.
-
#target_flow ⇒ String
The target flow to transition to.
-
#target_page ⇒ String
The target page to transition to.
-
#target_playbook ⇒ String
The target playbook to transition to.
-
#trigger_fulfillment ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3Fulfillment
A fulfillment can do one or more of the following actions at the same time: * Generate rich message responses.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3EventHandler
constructor
A new instance of GoogleCloudDialogflowCxV3EventHandler.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3EventHandler
Returns a new instance of GoogleCloudDialogflowCxV3EventHandler.
2390 2391 2392 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 2390 def initialize(**args) update!(**args) end |
Instance Attribute Details
#event ⇒ String
Required. The name of the event to handle.
Corresponds to the JSON property event
2354 2355 2356 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 2354 def event @event end |
#name ⇒ String
Output only. The unique identifier of this event handler.
Corresponds to the JSON property name
2359 2360 2361 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 2359 def name @name end |
#target_flow ⇒ String
The target flow to transition to. Format: projects//locations//agents//flows/
.
Corresponds to the JSON property targetFlow
2365 2366 2367 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 2365 def target_flow @target_flow end |
#target_page ⇒ String
The target page to transition to. Format: projects//locations//agents//flows//
pages/.
Corresponds to the JSON property targetPage
2371 2372 2373 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 2371 def target_page @target_page end |
#target_playbook ⇒ String
The target playbook to transition to. Format: projects//locations//agents//
playbooks/.
Corresponds to the JSON property targetPlaybook
2377 2378 2379 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 2377 def target_playbook @target_playbook end |
#trigger_fulfillment ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3Fulfillment
A fulfillment can do one or more of the following actions at the same time: *
Generate rich message responses. * Set parameter values. * Call the webhook.
Fulfillments can be called at various stages in the Page or Form lifecycle.
For example, when a DetectIntentRequest drives a session to enter a new page,
the page's entry fulfillment can add a static response to the QueryResult in
the returning DetectIntentResponse, call the webhook (for example, to load
user data from a database), or both.
Corresponds to the JSON property triggerFulfillment
2388 2389 2390 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 2388 def trigger_fulfillment @trigger_fulfillment end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2395 2396 2397 2398 2399 2400 2401 2402 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 2395 def update!(**args) @event = args[:event] if args.key?(:event) @name = args[:name] if args.key?(:name) @target_flow = args[:target_flow] if args.key?(:target_flow) @target_page = args[:target_page] if args.key?(:target_page) @target_playbook = args[:target_playbook] if args.key?(:target_playbook) @trigger_fulfillment = args[:trigger_fulfillment] if args.key?(:trigger_fulfillment) end |