Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3ExportPlaybookRequest
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3ExportPlaybookRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
The request message for Playbooks.ExportPlaybook.
Instance Attribute Summary collapse
-
#data_format ⇒ String
Optional.
-
#playbook_uri ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3ExportPlaybookRequest
constructor
A new instance of GoogleCloudDialogflowCxV3ExportPlaybookRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3ExportPlaybookRequest
Returns a new instance of GoogleCloudDialogflowCxV3ExportPlaybookRequest.
3169 3170 3171 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 3169 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_format ⇒ String
Optional. The data format of the exported agent. If not specified, BLOB is
assumed.
Corresponds to the JSON property dataFormat
3156 3157 3158 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 3156 def data_format @data_format end |
#playbook_uri ⇒ String
Optional. The Google Cloud Storage
URI to export the playbook to. The format of this URI must be gs:///. If
left unspecified, the serialized playbook is returned inline. Dialogflow
performs a write operation for the Cloud Storage object on the caller's behalf,
so your request authentication must have write permissions for the object.
For more information, see Dialogflow access control.
Corresponds to the JSON property playbookUri
3167 3168 3169 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 3167 def playbook_uri @playbook_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3174 3175 3176 3177 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 3174 def update!(**args) @data_format = args[:data_format] if args.key?(:data_format) @playbook_uri = args[:playbook_uri] if args.key?(:playbook_uri) end |