Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3FormParameter
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3FormParameter
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
Represents a form parameter.
Instance Attribute Summary collapse
-
#advanced_settings ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3AdvancedSettings
Hierarchical advanced settings for agent/flow/page/fulfillment/parameter.
-
#default_value ⇒ Object
The default value of an optional parameter.
-
#display_name ⇒ String
Required.
-
#entity_type ⇒ String
Required.
-
#fill_behavior ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3FormParameterFillBehavior
Configuration for how the filling of a parameter should be handled.
-
#is_list ⇒ Boolean
(also: #is_list?)
Indicates whether the parameter represents a list of values.
-
#redact ⇒ Boolean
(also: #redact?)
Indicates whether the parameter content should be redacted in log.
-
#required ⇒ Boolean
(also: #required?)
Indicates whether the parameter is required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3FormParameter
constructor
A new instance of GoogleCloudDialogflowCxV3FormParameter.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3FormParameter
Returns a new instance of GoogleCloudDialogflowCxV3FormParameter.
3655 3656 3657 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 3655 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advanced_settings ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3AdvancedSettings
Hierarchical advanced settings for agent/flow/page/fulfillment/parameter.
Settings exposed at lower level overrides the settings exposed at higher level.
Overriding occurs at the sub-setting level. For example, the
playback_interruption_settings at fulfillment level only overrides the
playback_interruption_settings at the agent level, leaving other settings at
the agent level unchanged. DTMF settings does not override each other. DTMF
settings set at different levels define DTMF detections running in parallel.
Hierarchy: Agent->Flow->Page->Fulfillment/Parameter.
Corresponds to the JSON property advancedSettings
3606 3607 3608 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 3606 def advanced_settings @advanced_settings end |
#default_value ⇒ Object
The default value of an optional parameter. If the parameter is required, the
default value will be ignored.
Corresponds to the JSON property defaultValue
3612 3613 3614 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 3612 def default_value @default_value end |
#display_name ⇒ String
Required. The human-readable name of the parameter, unique within the form.
Corresponds to the JSON property displayName
3617 3618 3619 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 3617 def display_name @display_name end |
#entity_type ⇒ String
Required. The entity type of the parameter. Format: projects/-/locations/-/
agents/-/entityTypes/ for system entity types (for example, projects/-/
locations/-/agents/-/entityTypes/sys.date), or projects//locations//agents//
entityTypes/ for developer entity types.
Corresponds to the JSON property entityType
3625 3626 3627 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 3625 def entity_type @entity_type end |
#fill_behavior ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3FormParameterFillBehavior
Configuration for how the filling of a parameter should be handled.
Corresponds to the JSON property fillBehavior
3630 3631 3632 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 3630 def fill_behavior @fill_behavior end |
#is_list ⇒ Boolean Also known as: is_list?
Indicates whether the parameter represents a list of values.
Corresponds to the JSON property isList
3635 3636 3637 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 3635 def is_list @is_list end |
#redact ⇒ Boolean Also known as: redact?
Indicates whether the parameter content should be redacted in log. If
redaction is enabled, the parameter content will be replaced by parameter name
during logging. Note: the parameter content is subject to redaction if either
parameter level redaction or entity type level redaction is enabled.
Corresponds to the JSON property redact
3644 3645 3646 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 3644 def redact @redact end |
#required ⇒ Boolean Also known as: required?
Indicates whether the parameter is required. Optional parameters will not
trigger prompts; however, they are filled if the user specifies them. Required
parameters must be filled before form filling concludes.
Corresponds to the JSON property required
3652 3653 3654 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 3652 def required @required end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3660 3661 3662 3663 3664 3665 3666 3667 3668 3669 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 3660 def update!(**args) @advanced_settings = args[:advanced_settings] if args.key?(:advanced_settings) @default_value = args[:default_value] if args.key?(:default_value) @display_name = args[:display_name] if args.key?(:display_name) @entity_type = args[:entity_type] if args.key?(:entity_type) @fill_behavior = args[:fill_behavior] if args.key?(:fill_behavior) @is_list = args[:is_list] if args.key?(:is_list) @redact = args[:redact] if args.key?(:redact) @required = args[:required] if args.key?(:required) end |