Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3ImportIntentsRequest
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3ImportIntentsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
The request message for Intents.ImportIntents.
Instance Attribute Summary collapse
-
#intents_content ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3InlineSource
Inline source for a Dialogflow operation that reads or imports objects (e.g. intents) into Dialogflow.
-
#intents_uri ⇒ String
The Google Cloud Storage URI to import intents from.
-
#merge_option ⇒ String
Merge option for importing intents.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3ImportIntentsRequest
constructor
A new instance of GoogleCloudDialogflowCxV3ImportIntentsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3ImportIntentsRequest
Returns a new instance of GoogleCloudDialogflowCxV3ImportIntentsRequest.
4679 4680 4681 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 4679 def initialize(**args) update!(**args) end |
Instance Attribute Details
#intents_content ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3InlineSource
Inline source for a Dialogflow operation that reads or imports objects (e.g.
intents) into Dialogflow.
Corresponds to the JSON property intentsContent
4662 4663 4664 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 4662 def intents_content @intents_content end |
#intents_uri ⇒ String
The Google Cloud Storage URI to
import intents from. The format of this URI must be gs:///. Dialogflow
performs a read operation for the Cloud Storage object on the caller's behalf,
so your request authentication must have read permissions for the object. For
more information, see Dialogflow access control.
Corresponds to the JSON property intentsUri
4672 4673 4674 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 4672 def intents_uri @intents_uri end |
#merge_option ⇒ String
Merge option for importing intents. If not specified, REJECT is assumed.
Corresponds to the JSON property mergeOption
4677 4678 4679 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 4677 def merge_option @merge_option end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4684 4685 4686 4687 4688 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 4684 def update!(**args) @intents_content = args[:intents_content] if args.key?(:intents_content) @intents_uri = args[:intents_uri] if args.key?(:intents_uri) @merge_option = args[:merge_option] if args.key?(:merge_option) end |