Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3ParameterDefinition
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3ParameterDefinition
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
Defines the properties of a parameter. Used to define parameters used in the agent and the input / output parameters for each fulfillment.
Instance Attribute Summary collapse
-
#description ⇒ String
Human-readable description of the parameter.
-
#name ⇒ String
Required.
-
#type ⇒ String
Type of parameter.
-
#type_schema ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3TypeSchema
Encapsulates different type schema variations: either a reference to an a schema that's already defined by a tool, or an inline definition.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3ParameterDefinition
constructor
A new instance of GoogleCloudDialogflowCxV3ParameterDefinition.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3ParameterDefinition
Returns a new instance of GoogleCloudDialogflowCxV3ParameterDefinition.
6575 6576 6577 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 6575 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Human-readable description of the parameter. Limited to 300 characters.
Corresponds to the JSON property description
6557 6558 6559 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 6557 def description @description end |
#name ⇒ String
Required. Name of parameter.
Corresponds to the JSON property name
6562 6563 6564 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 6562 def name @name end |
#type ⇒ String
Type of parameter.
Corresponds to the JSON property type
6567 6568 6569 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 6567 def type @type end |
#type_schema ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3TypeSchema
Encapsulates different type schema variations: either a reference to an a
schema that's already defined by a tool, or an inline definition.
Corresponds to the JSON property typeSchema
6573 6574 6575 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 6573 def type_schema @type_schema end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6580 6581 6582 6583 6584 6585 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 6580 def update!(**args) @description = args[:description] if args.key?(:description) @name = args[:name] if args.key?(:name) @type = args[:type] if args.key?(:type) @type_schema = args[:type_schema] if args.key?(:type_schema) end |