Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3PlaybookVersion
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3PlaybookVersion
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
Playbook version is a snapshot of the playbook at certain timestamp.
Instance Attribute Summary collapse
-
#description ⇒ String
Optional.
-
#examples ⇒ Array<Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3Example>
Output only.
-
#name ⇒ String
The unique identifier of the playbook version.
-
#playbook ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3Playbook
Playbook is the basic building block to instruct the LLM how to execute a certain task.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3PlaybookVersion
constructor
A new instance of GoogleCloudDialogflowCxV3PlaybookVersion.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3PlaybookVersion
Returns a new instance of GoogleCloudDialogflowCxV3PlaybookVersion.
6974 6975 6976 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 6974 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Optional. The description of the playbook version.
Corresponds to the JSON property description
6945 6946 6947 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 6945 def description @description end |
#examples ⇒ Array<Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3Example>
Output only. Snapshot of the examples belonging to the playbook when the
playbook version is created.
Corresponds to the JSON property examples
6951 6952 6953 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 6951 def examples @examples end |
#name ⇒ String
The unique identifier of the playbook version. Format: projects//locations//
agents//playbooks//versions/.
Corresponds to the JSON property name
6957 6958 6959 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 6957 def name @name end |
#playbook ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3Playbook
Playbook is the basic building block to instruct the LLM how to execute a
certain task. A playbook consists of a goal to accomplish, an optional list of
step by step instructions (the step instruction may refers to name of the
custom or default plugin tools to use) to perform the task, a list of
contextual input data to be passed in at the beginning of the invoked, and a
list of output parameters to store the playbook result.
Corresponds to the JSON property playbook
6967 6968 6969 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 6967 def playbook @playbook end |
#update_time ⇒ String
Output only. Last time the playbook version was created or modified.
Corresponds to the JSON property updateTime
6972 6973 6974 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 6972 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6979 6980 6981 6982 6983 6984 6985 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 6979 def update!(**args) @description = args[:description] if args.key?(:description) @examples = args[:examples] if args.key?(:examples) @name = args[:name] if args.key?(:name) @playbook = args[:playbook] if args.key?(:playbook) @update_time = args[:update_time] if args.key?(:update_time) end |