Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3QueryParameters
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3QueryParameters
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
Represents the parameters of a conversational query.
Instance Attribute Summary collapse
-
#analyze_query_text_sentiment ⇒ Boolean
(also: #analyze_query_text_sentiment?)
Configures whether sentiment analysis should be performed.
-
#channel ⇒ String
The channel which this query is for.
-
#current_page ⇒ String
The unique identifier of the page to override the current page in the session.
-
#current_playbook ⇒ String
Optional.
-
#disable_webhook ⇒ Boolean
(also: #disable_webhook?)
Whether to disable webhook calls for this request.
-
#end_user_metadata ⇒ Hash<String,Object>
Optional.
-
#flow_versions ⇒ Array<String>
A list of flow versions to override for the request.
-
#geo_location ⇒ Google::Apis::DialogflowV3::GoogleTypeLatLng
An object that represents a latitude/longitude pair.
-
#llm_model_settings ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3LlmModelSettings
Settings for LLM models.
-
#parameter_scope ⇒ String
Scope for the parameters.
-
#parameters ⇒ Hash<String,Object>
Additional parameters to be put into session parameters.
-
#payload ⇒ Hash<String,Object>
This field can be used to pass custom data into the webhook associated with the agent.
-
#populate_data_store_connection_signals ⇒ Boolean
(also: #populate_data_store_connection_signals?)
Optional.
-
#search_config ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3SearchConfig
Search configuration for UCS search queries.
-
#session_entity_types ⇒ Array<Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3SessionEntityType>
Additional session entity types to replace or extend developer entity types with.
-
#session_ttl ⇒ String
Optional.
-
#time_zone ⇒ String
The time zone of this conversational query from the time zone database, e.g., America/New_York, Europe/Paris.
-
#webhook_headers ⇒ Hash<String,String>
This field can be used to pass HTTP headers for a webhook call.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3QueryParameters
constructor
A new instance of GoogleCloudDialogflowCxV3QueryParameters.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3QueryParameters
Returns a new instance of GoogleCloudDialogflowCxV3QueryParameters.
7207 7208 7209 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7207 def initialize(**args) update!(**args) end |
Instance Attribute Details
#analyze_query_text_sentiment ⇒ Boolean Also known as: analyze_query_text_sentiment?
Configures whether sentiment analysis should be performed. If not provided,
sentiment analysis is not performed.
Corresponds to the JSON property analyzeQueryTextSentiment
7059 7060 7061 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7059 def analyze_query_text_sentiment @analyze_query_text_sentiment end |
#channel ⇒ String
The channel which this query is for. If specified, only the ResponseMessage
associated with the channel will be returned. If no ResponseMessage is
associated with the channel, it falls back to the ResponseMessage with
unspecified channel. If unspecified, the ResponseMessage with unspecified
channel will be returned.
Corresponds to the JSON property channel
7069 7070 7071 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7069 def channel @channel end |
#current_page ⇒ String
The unique identifier of the page to override the current page in the session.
Format: projects//locations//agents//flows//pages/. If current_page is
specified, the previous state of the session will be ignored by Dialogflow,
including the previous page and the previous session parameters. In most cases,
current_page and parameters should be configured together to direct a session
to a specific state.
Corresponds to the JSON property currentPage
7079 7080 7081 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7079 def current_page @current_page end |
#current_playbook ⇒ String
Optional. The unique identifier of the playbook to start or continue the
session with. If current_playbook is specified, the previous state of the
session will be ignored by Dialogflow. Format: projects//locations//agents//
playbooks/.
Corresponds to the JSON property currentPlaybook
7087 7088 7089 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7087 def current_playbook @current_playbook end |
#disable_webhook ⇒ Boolean Also known as: disable_webhook?
Whether to disable webhook calls for this request.
Corresponds to the JSON property disableWebhook
7092 7093 7094 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7092 def disable_webhook @disable_webhook end |
#end_user_metadata ⇒ Hash<String,Object>
Optional. Information about the end-user to improve the relevance and accuracy
of generative answers. This will be interpreted and used by a language model,
so, for good results, the data should be self-descriptive, and in a simple
structure. Example: json ` "subscription plan": "Business Premium Plus", "
devices owned": [ `"model": "Google Pixel 7"`, `"model": "Google Pixel Tablet"`
] `
Corresponds to the JSON property endUserMetadata
7103 7104 7105 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7103 def @end_user_metadata end |
#flow_versions ⇒ Array<String>
A list of flow versions to override for the request. Format: projects//
locations//agents//flows//versions/. If version 1 of flow X is included in
this list, the traffic of flow X will go through version 1 regardless of the
version configuration in the environment. Each flow can have at most one
version specified in this list.
Corresponds to the JSON property flowVersions
7112 7113 7114 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7112 def flow_versions @flow_versions end |
#geo_location ⇒ Google::Apis::DialogflowV3::GoogleTypeLatLng
An object that represents a latitude/longitude pair. This is expressed as a
pair of doubles to represent degrees latitude and degrees longitude. Unless
specified otherwise, this object must conform to the WGS84 standard. Values
must be within normalized ranges.
Corresponds to the JSON property geoLocation
7120 7121 7122 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7120 def geo_location @geo_location end |
#llm_model_settings ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3LlmModelSettings
Settings for LLM models.
Corresponds to the JSON property llmModelSettings
7125 7126 7127 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7125 def llm_model_settings @llm_model_settings end |
#parameter_scope ⇒ String
Scope for the parameters. If not specified, parameters will be treated as
session parameters. Parameters with custom scope will not be put into session
parameters. You can reference the parameters with custom scope in the agent
with the following format: $parameter-scope.params.parameter-id.
Corresponds to the JSON property parameterScope
7133 7134 7135 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7133 def parameter_scope @parameter_scope end |
#parameters ⇒ Hash<String,Object>
Additional parameters to be put into session parameters. To remove a parameter
from the session, clients should explicitly set the parameter value to null.
You can reference the session parameters in the agent with the following
format: $session.params.parameter-id. Depending on your protocol or client
library language, this is a map, associative array, symbol table, dictionary,
or JSON object composed of a collection of (MapKey, MapValue) pairs: * MapKey
type: string * MapKey value: parameter name * MapValue type: If parameter's
entity type is a composite entity then use map, otherwise, depending on the
parameter value type, it could be one of string, number, boolean, null, list
or map. * MapValue value: If parameter's entity type is a composite entity
then use map from composite entity property names to property values,
otherwise, use parameter value.
Corresponds to the JSON property parameters
7149 7150 7151 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7149 def parameters @parameters end |
#payload ⇒ Hash<String,Object>
This field can be used to pass custom data into the webhook associated with
the agent. Arbitrary JSON objects are supported. Some integrations that query
a Dialogflow agent may provide additional information in the payload. In
particular, for the Dialogflow Phone Gateway integration, this field has the
form: ` "telephony": ` "caller_id": "+18558363987" ` `
Corresponds to the JSON property payload
7158 7159 7160 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7158 def payload @payload end |
#populate_data_store_connection_signals ⇒ Boolean Also known as: populate_data_store_connection_signals?
Optional. If set to true and data stores are involved in serving the request
then DetectIntentResponse.query_result.data_store_connection_signals will be
filled with data that can help evaluations.
Corresponds to the JSON property populateDataStoreConnectionSignals
7165 7166 7167 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7165 def populate_data_store_connection_signals @populate_data_store_connection_signals end |
#search_config ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3SearchConfig
Search configuration for UCS search queries.
Corresponds to the JSON property searchConfig
7171 7172 7173 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7171 def search_config @search_config end |
#session_entity_types ⇒ Array<Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3SessionEntityType>
Additional session entity types to replace or extend developer entity types
with. The entity synonyms apply to all languages and persist for the session
of this query.
Corresponds to the JSON property sessionEntityTypes
7178 7179 7180 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7178 def session_entity_types @session_entity_types end |
#session_ttl ⇒ String
Optional. Configure lifetime of the Dialogflow session. By default, a
Dialogflow session remains active and its data is stored for 30 minutes after
the last request is sent for the session. This value should be no longer than
1 day.
Corresponds to the JSON property sessionTtl
7186 7187 7188 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7186 def session_ttl @session_ttl end |
#time_zone ⇒ String
The time zone of this conversational query from the time zone database, e.g., America/New_York, Europe/Paris. If not
provided, the time zone specified in the agent is used.
Corresponds to the JSON property timeZone
7193 7194 7195 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7193 def time_zone @time_zone end |
#webhook_headers ⇒ Hash<String,String>
This field can be used to pass HTTP headers for a webhook call. These headers
will be sent to webhook along with the headers that have been configured
through Dialogflow web console. The headers defined within this field will
overwrite the headers configured through Dialogflow console if there is a
conflict. Header names are case-insensitive. Google's specified headers are
not allowed. Including: "Host", "Content-Length", "Connection", "From", "User-
Agent", "Accept-Encoding", "If-Modified-Since", "If-None-Match", "X-Forwarded-
For", etc.
Corresponds to the JSON property webhookHeaders
7205 7206 7207 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7205 def webhook_headers @webhook_headers end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7212 7213 7214 7215 7216 7217 7218 7219 7220 7221 7222 7223 7224 7225 7226 7227 7228 7229 7230 7231 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7212 def update!(**args) @analyze_query_text_sentiment = args[:analyze_query_text_sentiment] if args.key?(:analyze_query_text_sentiment) @channel = args[:channel] if args.key?(:channel) @current_page = args[:current_page] if args.key?(:current_page) @current_playbook = args[:current_playbook] if args.key?(:current_playbook) @disable_webhook = args[:disable_webhook] if args.key?(:disable_webhook) @end_user_metadata = args[:end_user_metadata] if args.key?(:end_user_metadata) @flow_versions = args[:flow_versions] if args.key?(:flow_versions) @geo_location = args[:geo_location] if args.key?(:geo_location) @llm_model_settings = args[:llm_model_settings] if args.key?(:llm_model_settings) @parameter_scope = args[:parameter_scope] if args.key?(:parameter_scope) @parameters = args[:parameters] if args.key?(:parameters) @payload = args[:payload] if args.key?(:payload) @populate_data_store_connection_signals = args[:populate_data_store_connection_signals] if args.key?(:populate_data_store_connection_signals) @search_config = args[:search_config] if args.key?(:search_config) @session_entity_types = args[:session_entity_types] if args.key?(:session_entity_types) @session_ttl = args[:session_ttl] if args.key?(:session_ttl) @time_zone = args[:time_zone] if args.key?(:time_zone) @webhook_headers = args[:webhook_headers] if args.key?(:webhook_headers) end |