Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3RestoreAgentRequest
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3RestoreAgentRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
The request message for Agents.RestoreAgent.
Instance Attribute Summary collapse
-
#agent_content ⇒ String
Uncompressed raw byte content for agent.
-
#agent_uri ⇒ String
The Google Cloud Storage URI to restore agent from.
-
#git_source ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3RestoreAgentRequestGitSource
Settings for restoring from a git branch Corresponds to the JSON property
gitSource. -
#restore_option ⇒ String
Agent restore mode.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3RestoreAgentRequest
constructor
A new instance of GoogleCloudDialogflowCxV3RestoreAgentRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3RestoreAgentRequest
Returns a new instance of GoogleCloudDialogflowCxV3RestoreAgentRequest.
7856 7857 7858 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7856 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_content ⇒ String
Uncompressed raw byte content for agent.
Corresponds to the JSON property agentContent
NOTE: Values are automatically base64 encoded/decoded in the client library.
7834 7835 7836 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7834 def agent_content @agent_content end |
#agent_uri ⇒ String
The Google Cloud Storage URI to
restore agent from. The format of this URI must be gs:///. Dialogflow
performs a read operation for the Cloud Storage object on the caller's behalf,
so your request authentication must have read permissions for the object. For
more information, see Dialogflow access control.
Corresponds to the JSON property agentUri
7844 7845 7846 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7844 def agent_uri @agent_uri end |
#git_source ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3RestoreAgentRequestGitSource
Settings for restoring from a git branch
Corresponds to the JSON property gitSource
7849 7850 7851 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7849 def git_source @git_source end |
#restore_option ⇒ String
Agent restore mode. If not specified, KEEP is assumed.
Corresponds to the JSON property restoreOption
7854 7855 7856 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7854 def restore_option @restore_option end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7861 7862 7863 7864 7865 7866 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7861 def update!(**args) @agent_content = args[:agent_content] if args.key?(:agent_content) @agent_uri = args[:agent_uri] if args.key?(:agent_uri) @git_source = args[:git_source] if args.key?(:git_source) @restore_option = args[:restore_option] if args.key?(:restore_option) end |