Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3RestoreToolVersionResponse
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3RestoreToolVersionResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
The response message for Tools.RestoreToolVersion.
Instance Attribute Summary collapse
-
#tool ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3Tool
A tool provides a list of actions which are available to the Playbook to attain its goal.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3RestoreToolVersionResponse
constructor
A new instance of GoogleCloudDialogflowCxV3RestoreToolVersionResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3RestoreToolVersionResponse
Returns a new instance of GoogleCloudDialogflowCxV3RestoreToolVersionResponse.
7950 7951 7952 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7950 def initialize(**args) update!(**args) end |
Instance Attribute Details
#tool ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3Tool
A tool provides a list of actions which are available to the Playbook to
attain its goal. A Tool consists of a description of the tool's usage and a
specification of the tool which contains the schema and authentication
information.
Corresponds to the JSON property tool
7948 7949 7950 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7948 def tool @tool end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7955 7956 7957 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 7955 def update!(**args) @tool = args[:tool] if args.key?(:tool) end |