Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3TestCase
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3TestCase
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
Represents a test case.
Instance Attribute Summary collapse
-
#creation_time ⇒ String
Output only.
-
#display_name ⇒ String
Required.
-
#last_test_result ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3TestCaseResult
Represents a result from running a test case in an agent environment.
-
#name ⇒ String
The unique identifier of the test case.
-
#notes ⇒ String
Additional freeform notes about the test case.
-
#tags ⇒ Array<String>
Tags are short descriptions that users may apply to test cases for organizational and filtering purposes.
-
#test_case_conversation_turns ⇒ Array<Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3ConversationTurn>
The conversation turns uttered when the test case was created, in chronological order.
-
#test_config ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3TestConfig
Represents configurations for a test case.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3TestCase
constructor
A new instance of GoogleCloudDialogflowCxV3TestCase.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3TestCase
Returns a new instance of GoogleCloudDialogflowCxV3TestCase.
8804 8805 8806 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 8804 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_time ⇒ String
Output only. When the test was created.
Corresponds to the JSON property creationTime
8760 8761 8762 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 8760 def creation_time @creation_time end |
#display_name ⇒ String
Required. The human-readable name of the test case, unique within the agent.
Limit of 200 characters.
Corresponds to the JSON property displayName
8766 8767 8768 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 8766 def display_name @display_name end |
#last_test_result ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3TestCaseResult
Represents a result from running a test case in an agent environment.
Corresponds to the JSON property lastTestResult
8771 8772 8773 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 8771 def last_test_result @last_test_result end |
#name ⇒ String
The unique identifier of the test case. TestCases.CreateTestCase will populate
the name automatically. Otherwise use format: projects//locations//agents//
testCases/.
Corresponds to the JSON property name
8778 8779 8780 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 8778 def name @name end |
#notes ⇒ String
Additional freeform notes about the test case. Limit of 400 characters.
Corresponds to the JSON property notes
8783 8784 8785 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 8783 def notes @notes end |
#tags ⇒ Array<String>
Tags are short descriptions that users may apply to test cases for
organizational and filtering purposes. Each tag should start with "#" and has
a limit of 30 characters.
Corresponds to the JSON property tags
8790 8791 8792 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 8790 def @tags end |
#test_case_conversation_turns ⇒ Array<Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3ConversationTurn>
The conversation turns uttered when the test case was created, in
chronological order. These include the canonical set of agent utterances that
should occur when the agent is working properly.
Corresponds to the JSON property testCaseConversationTurns
8797 8798 8799 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 8797 def test_case_conversation_turns @test_case_conversation_turns end |
#test_config ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3TestConfig
Represents configurations for a test case.
Corresponds to the JSON property testConfig
8802 8803 8804 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 8802 def test_config @test_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8809 8810 8811 8812 8813 8814 8815 8816 8817 8818 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 8809 def update!(**args) @creation_time = args[:creation_time] if args.key?(:creation_time) @display_name = args[:display_name] if args.key?(:display_name) @last_test_result = args[:last_test_result] if args.key?(:last_test_result) @name = args[:name] if args.key?(:name) @notes = args[:notes] if args.key?(:notes) @tags = args[:tags] if args.key?(:tags) @test_case_conversation_turns = args[:test_case_conversation_turns] if args.key?(:test_case_conversation_turns) @test_config = args[:test_config] if args.key?(:test_config) end |