Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3ToolAuthenticationServiceAccountAuthConfig
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3ToolAuthenticationServiceAccountAuthConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
Configuration for authentication using a service account.
Instance Attribute Summary collapse
-
#service_account ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3ToolAuthenticationServiceAccountAuthConfig
constructor
A new instance of GoogleCloudDialogflowCxV3ToolAuthenticationServiceAccountAuthConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3ToolAuthenticationServiceAccountAuthConfig
Returns a new instance of GoogleCloudDialogflowCxV3ToolAuthenticationServiceAccountAuthConfig.
9284 9285 9286 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 9284 def initialize(**args) update!(**args) end |
Instance Attribute Details
#service_account ⇒ String
Required. The email address of the service account used to authenticate the
tool call. Dialogflow uses this service account to exchange an access token
and the access token is then sent in the Authorization header of the tool
request. The service account must have the roles/iam.
serviceAccountTokenCreator role granted to the Dialogflow service agent.
Corresponds to the JSON property serviceAccount
9282 9283 9284 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 9282 def service_account @service_account end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9289 9290 9291 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 9289 def update!(**args) @service_account = args[:service_account] if args.key?(:service_account) end |