Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3ToolAuthenticationServiceAgentAuthConfig
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3ToolAuthenticationServiceAgentAuthConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
Config for auth using Diglogflow service agent.
Instance Attribute Summary collapse
-
#service_agent_auth ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3ToolAuthenticationServiceAgentAuthConfig
constructor
A new instance of GoogleCloudDialogflowCxV3ToolAuthenticationServiceAgentAuthConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3ToolAuthenticationServiceAgentAuthConfig
Returns a new instance of GoogleCloudDialogflowCxV3ToolAuthenticationServiceAgentAuthConfig.
9306 9307 9308 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 9306 def initialize(**args) update!(**args) end |
Instance Attribute Details
#service_agent_auth ⇒ String
Optional. Indicate the auth token type generated from the Diglogflow service
agent. The generated token is sent in the Authorization header.
Corresponds to the JSON property serviceAgentAuth
9304 9305 9306 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 9304 def service_agent_auth @service_agent_auth end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9311 9312 9313 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 9311 def update!(**args) @service_agent_auth = args[:service_agent_auth] if args.key?(:service_agent_auth) end |