Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3ToolDataStoreTool
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3ToolDataStoreTool
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
A DataStoreTool is a way to provide specifications needed to search a list of data stores.
Instance Attribute Summary collapse
-
#data_store_connections ⇒ Array<Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3DataStoreConnection>
Required.
-
#fallback_prompt ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3ToolDataStoreToolFallbackPrompt
A FallbackPrompt is a way to provide specifications for the Data Store fallback prompt when generating responses.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3ToolDataStoreTool
constructor
A new instance of GoogleCloudDialogflowCxV3ToolDataStoreTool.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3ToolDataStoreTool
Returns a new instance of GoogleCloudDialogflowCxV3ToolDataStoreTool.
9421 9422 9423 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 9421 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_store_connections ⇒ Array<Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3DataStoreConnection>
Required. List of data stores to search.
Corresponds to the JSON property dataStoreConnections
9413 9414 9415 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 9413 def data_store_connections @data_store_connections end |
#fallback_prompt ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3ToolDataStoreToolFallbackPrompt
A FallbackPrompt is a way to provide specifications for the Data Store
fallback prompt when generating responses.
Corresponds to the JSON property fallbackPrompt
9419 9420 9421 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 9419 def fallback_prompt @fallback_prompt end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9426 9427 9428 9429 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 9426 def update!(**args) @data_store_connections = args[:data_store_connections] if args.key?(:data_store_connections) @fallback_prompt = args[:fallback_prompt] if args.key?(:fallback_prompt) end |