Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3ToolUse
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3ToolUse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
Stores metadata of the invocation of an action supported by a tool.
Instance Attribute Summary collapse
-
#action ⇒ String
Optional.
-
#display_name ⇒ String
Output only.
-
#input_action_parameters ⇒ Hash<String,Object>
Optional.
-
#output_action_parameters ⇒ Hash<String,Object>
Optional.
-
#tool ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3ToolUse
constructor
A new instance of GoogleCloudDialogflowCxV3ToolUse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3ToolUse
Returns a new instance of GoogleCloudDialogflowCxV3ToolUse.
9619 9620 9621 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 9619 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action ⇒ String
Optional. Name of the action to be called during the tool use.
Corresponds to the JSON property action
9596 9597 9598 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 9596 def action @action end |
#display_name ⇒ String
Output only. The display name of the tool.
Corresponds to the JSON property displayName
9601 9602 9603 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 9601 def display_name @display_name end |
#input_action_parameters ⇒ Hash<String,Object>
Optional. A list of input parameters for the action.
Corresponds to the JSON property inputActionParameters
9606 9607 9608 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 9606 def input_action_parameters @input_action_parameters end |
#output_action_parameters ⇒ Hash<String,Object>
Optional. A list of output parameters generated by the action.
Corresponds to the JSON property outputActionParameters
9611 9612 9613 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 9611 def output_action_parameters @output_action_parameters end |
#tool ⇒ String
Required. The tool that should be used. Format: projects//locations//agents//
tools/.
Corresponds to the JSON property tool
9617 9618 9619 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 9617 def tool @tool end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9624 9625 9626 9627 9628 9629 9630 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 9624 def update!(**args) @action = args[:action] if args.key?(:action) @display_name = args[:display_name] if args.key?(:display_name) @input_action_parameters = args[:input_action_parameters] if args.key?(:input_action_parameters) @output_action_parameters = args[:output_action_parameters] if args.key?(:output_action_parameters) @tool = args[:tool] if args.key?(:tool) end |