Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3ToolVersion
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3ToolVersion
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
Tool version is a snapshot of the tool at certain timestamp.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Required.
-
#name ⇒ String
Identifier.
-
#tool ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3Tool
A tool provides a list of actions which are available to the Playbook to attain its goal.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3ToolVersion
constructor
A new instance of GoogleCloudDialogflowCxV3ToolVersion.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3ToolVersion
Returns a new instance of GoogleCloudDialogflowCxV3ToolVersion.
9666 9667 9668 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 9666 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Last time the tool version was created or modified.
Corresponds to the JSON property createTime
9640 9641 9642 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 9640 def create_time @create_time end |
#display_name ⇒ String
Required. The display name of the tool version.
Corresponds to the JSON property displayName
9645 9646 9647 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 9645 def display_name @display_name end |
#name ⇒ String
Identifier. The unique identifier of the tool version. Format: projects//
locations//agents//tools//versions/.
Corresponds to the JSON property name
9651 9652 9653 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 9651 def name @name end |
#tool ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3Tool
A tool provides a list of actions which are available to the Playbook to
attain its goal. A Tool consists of a description of the tool's usage and a
specification of the tool which contains the schema and authentication
information.
Corresponds to the JSON property tool
9659 9660 9661 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 9659 def tool @tool end |
#update_time ⇒ String
Output only. Last time the tool version was created or modified.
Corresponds to the JSON property updateTime
9664 9665 9666 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 9664 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9671 9672 9673 9674 9675 9676 9677 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 9671 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @name = args[:name] if args.key?(:name) @tool = args[:tool] if args.key?(:tool) @update_time = args[:update_time] if args.key?(:update_time) end |