Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3TransitionRoute
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3TransitionRoute
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
A transition route specifies a intent that can be matched and/or a data
condition that can be evaluated during a session. When a specified transition
is matched, the following actions are taken in order: * If there is a
trigger_fulfillment associated with the transition, it will be called. * If
there is a target_page associated with the transition, the session will
transition into the specified page. * If there is a target_flow associated
with the transition, the session will transition into the specified flow.
Instance Attribute Summary collapse
-
#condition ⇒ String
The condition to evaluate against form parameters or session parameters.
-
#description ⇒ String
Optional.
-
#intent ⇒ String
The unique identifier of an Intent.
-
#name ⇒ String
Output only.
-
#target_flow ⇒ String
The target flow to transition to.
-
#target_page ⇒ String
The target page to transition to.
-
#trigger_fulfillment ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3Fulfillment
A fulfillment can do one or more of the following actions at the same time: * Generate rich message responses.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3TransitionRoute
constructor
A new instance of GoogleCloudDialogflowCxV3TransitionRoute.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3TransitionRoute
Returns a new instance of GoogleCloudDialogflowCxV3TransitionRoute.
9889 9890 9891 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 9889 def initialize(**args) update!(**args) end |
Instance Attribute Details
#condition ⇒ String
The condition to evaluate against form parameters or session parameters. See
the conditions reference. At least one of intent or condition must be
specified. When both intent and condition are specified, the transition
can only happen when both are fulfilled.
Corresponds to the JSON property condition
9844 9845 9846 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 9844 def condition @condition end |
#description ⇒ String
Optional. The description of the transition route. The maximum length is 500
characters.
Corresponds to the JSON property description
9850 9851 9852 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 9850 def description @description end |
#intent ⇒ String
The unique identifier of an Intent. Format: projects//locations//agents//
intents/. Indicates that the transition can only happen when the given intent
is matched. At least one of intent or condition must be specified. When
both intent and condition are specified, the transition can only happen
when both are fulfilled.
Corresponds to the JSON property intent
9859 9860 9861 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 9859 def intent @intent end |
#name ⇒ String
Output only. The unique identifier of this transition route.
Corresponds to the JSON property name
9864 9865 9866 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 9864 def name @name end |
#target_flow ⇒ String
The target flow to transition to. Format: projects//locations//agents//flows/
.
Corresponds to the JSON property targetFlow
9870 9871 9872 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 9870 def target_flow @target_flow end |
#target_page ⇒ String
The target page to transition to. Format: projects//locations//agents//flows//
pages/.
Corresponds to the JSON property targetPage
9876 9877 9878 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 9876 def target_page @target_page end |
#trigger_fulfillment ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3Fulfillment
A fulfillment can do one or more of the following actions at the same time: *
Generate rich message responses. * Set parameter values. * Call the webhook.
Fulfillments can be called at various stages in the Page or Form lifecycle.
For example, when a DetectIntentRequest drives a session to enter a new page,
the page's entry fulfillment can add a static response to the QueryResult in
the returning DetectIntentResponse, call the webhook (for example, to load
user data from a database), or both.
Corresponds to the JSON property triggerFulfillment
9887 9888 9889 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 9887 def trigger_fulfillment @trigger_fulfillment end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9894 9895 9896 9897 9898 9899 9900 9901 9902 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 9894 def update!(**args) @condition = args[:condition] if args.key?(:condition) @description = args[:description] if args.key?(:description) @intent = args[:intent] if args.key?(:intent) @name = args[:name] if args.key?(:name) @target_flow = args[:target_flow] if args.key?(:target_flow) @target_page = args[:target_page] if args.key?(:target_page) @trigger_fulfillment = args[:trigger_fulfillment] if args.key?(:trigger_fulfillment) end |