Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3Webhook
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3Webhook
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
Webhooks host the developer's business logic. During a session, webhooks allow the developer to use the data extracted by Dialogflow's natural language processing to generate dynamic responses, validate collected data, or trigger actions on the backend.
Instance Attribute Summary collapse
-
#disabled ⇒ Boolean
(also: #disabled?)
Indicates whether the webhook is disabled.
-
#display_name ⇒ String
Required.
-
#generic_web_service ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3WebhookGenericWebService
Represents configuration for a generic web service.
-
#name ⇒ String
The unique identifier of the webhook.
-
#service_directory ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3WebhookServiceDirectoryConfig
Represents configuration for a Service Directory service.
-
#timeout ⇒ String
Webhook execution timeout.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3Webhook
constructor
A new instance of GoogleCloudDialogflowCxV3Webhook.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3Webhook
Returns a new instance of GoogleCloudDialogflowCxV3Webhook.
10473 10474 10475 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10473 def initialize(**args) update!(**args) end |
Instance Attribute Details
#disabled ⇒ Boolean Also known as: disabled?
Indicates whether the webhook is disabled.
Corresponds to the JSON property disabled
10440 10441 10442 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10440 def disabled @disabled end |
#display_name ⇒ String
Required. The human-readable name of the webhook, unique within the agent.
Corresponds to the JSON property displayName
10446 10447 10448 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10446 def display_name @display_name end |
#generic_web_service ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3WebhookGenericWebService
Represents configuration for a generic web service.
Corresponds to the JSON property genericWebService
10451 10452 10453 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10451 def generic_web_service @generic_web_service end |
#name ⇒ String
The unique identifier of the webhook. Required for the Webhooks.UpdateWebhook
method. Webhooks.CreateWebhook populates the name automatically. Format:
projects//locations//agents//webhooks/.
Corresponds to the JSON property name
10458 10459 10460 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10458 def name @name end |
#service_directory ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3WebhookServiceDirectoryConfig
Represents configuration for a Service Directory service.
Corresponds to the JSON property serviceDirectory
10464 10465 10466 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10464 def service_directory @service_directory end |
#timeout ⇒ String
Webhook execution timeout. Execution is considered failed if Dialogflow doesn'
t receive a response from webhook at the end of the timeout period. Defaults
to 5 seconds, maximum allowed timeout is 30 seconds.
Corresponds to the JSON property timeout
10471 10472 10473 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10471 def timeout @timeout end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10478 10479 10480 10481 10482 10483 10484 10485 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10478 def update!(**args) @disabled = args[:disabled] if args.key?(:disabled) @display_name = args[:display_name] if args.key?(:display_name) @generic_web_service = args[:generic_web_service] if args.key?(:generic_web_service) @name = args[:name] if args.key?(:name) @service_directory = args[:service_directory] if args.key?(:service_directory) @timeout = args[:timeout] if args.key?(:timeout) end |