Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3WebhookGenericWebService
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3WebhookGenericWebService
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
Represents configuration for a generic web service.
Instance Attribute Summary collapse
-
#allowed_ca_certs ⇒ Array<String>
Optional.
-
#http_method ⇒ String
Optional.
-
#oauth_config ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3WebhookGenericWebServiceOAuthConfig
Represents configuration of OAuth client credential flow for 3rd party API authentication.
-
#parameter_mapping ⇒ Hash<String,String>
Optional.
-
#password ⇒ String
The password for HTTP Basic authentication.
-
#request_body ⇒ String
Optional.
-
#request_headers ⇒ Hash<String,String>
The HTTP request headers to send together with webhook requests.
-
#secret_version_for_username_password ⇒ String
Optional.
-
#secret_versions_for_request_headers ⇒ Hash<String,Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3WebhookGenericWebServiceSecretVersionHeaderValue>
Optional.
-
#service_account_auth_config ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3WebhookGenericWebServiceServiceAccountAuthConfig
Configuration for authentication using a service account.
-
#service_agent_auth ⇒ String
Optional.
-
#uri ⇒ String
Required.
-
#username ⇒ String
The user name for HTTP Basic authentication.
-
#webhook_type ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3WebhookGenericWebService
constructor
A new instance of GoogleCloudDialogflowCxV3WebhookGenericWebService.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3WebhookGenericWebService
Returns a new instance of GoogleCloudDialogflowCxV3WebhookGenericWebService.
10583 10584 10585 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10583 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allowed_ca_certs ⇒ Array<String>
Optional. Specifies a list of allowed custom CA certificates (in DER format)
for HTTPS verification. This overrides the default SSL trust store. If this is
empty or unspecified, Dialogflow will use Google's default trust store to
verify certificates. N.B. Make sure the HTTPS server certificates are signed
with "subject alt name". For instance a certificate can be self-signed using
the following command, openssl x509 -req -days 200 -in example.com.csr \ -
signkey example.com.key \ -out example.com.crt \ -extfile <(printf "\
nsubjectAltName='DNS:www.example.com'")
Corresponds to the JSON property allowedCaCerts
10502 10503 10504 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10502 def allowed_ca_certs @allowed_ca_certs end |
#http_method ⇒ String
Optional. HTTP method for the flexible webhook calls. Standard webhook always
uses POST.
Corresponds to the JSON property httpMethod
10508 10509 10510 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10508 def http_method @http_method end |
#oauth_config ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3WebhookGenericWebServiceOAuthConfig
Represents configuration of OAuth client credential flow for 3rd party API
authentication.
Corresponds to the JSON property oauthConfig
10514 10515 10516 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10514 def oauth_config @oauth_config end |
#parameter_mapping ⇒ Hash<String,String>
Optional. Maps the values extracted from specific fields of the flexible
webhook response into session parameters. - Key: session parameter name -
Value: field path in the webhook response
Corresponds to the JSON property parameterMapping
10521 10522 10523 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10521 def parameter_mapping @parameter_mapping end |
#password ⇒ String
The password for HTTP Basic authentication.
Corresponds to the JSON property password
10526 10527 10528 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10526 def password @password end |
#request_body ⇒ String
Optional. Defines a custom JSON object as request body to send to flexible
webhook.
Corresponds to the JSON property requestBody
10532 10533 10534 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10532 def request_body @request_body end |
#request_headers ⇒ Hash<String,String>
The HTTP request headers to send together with webhook requests.
Corresponds to the JSON property requestHeaders
10537 10538 10539 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10537 def request_headers @request_headers end |
#secret_version_for_username_password ⇒ String
Optional. The SecretManager secret version resource storing the username:
password pair for HTTP Basic authentication. Format: projects/project/
secrets/secret/versions/version`
Corresponds to the JSON propertysecretVersionForUsernamePassword`
10544 10545 10546 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10544 def secret_version_for_username_password @secret_version_for_username_password end |
#secret_versions_for_request_headers ⇒ Hash<String,Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3WebhookGenericWebServiceSecretVersionHeaderValue>
Optional. The HTTP request headers to send together with webhook requests.
Header values are stored in SecretManager secret versions. When the same
header name is specified in both request_headers and
secret_versions_for_request_headers, the value in
secret_versions_for_request_headers will be used.
Corresponds to the JSON property secretVersionsForRequestHeaders
10553 10554 10555 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10553 def secret_versions_for_request_headers @secret_versions_for_request_headers end |
#service_account_auth_config ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3WebhookGenericWebServiceServiceAccountAuthConfig
Configuration for authentication using a service account.
Corresponds to the JSON property serviceAccountAuthConfig
10558 10559 10560 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10558 def service_account_auth_config @service_account_auth_config end |
#service_agent_auth ⇒ String
Optional. Indicate the auth token type generated from the Diglogflow service
agent. The generated token is sent in the Authorization header.
Corresponds to the JSON property serviceAgentAuth
10565 10566 10567 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10565 def service_agent_auth @service_agent_auth end |
#uri ⇒ String
Required. The webhook URI for receiving POST requests. It must use https
protocol.
Corresponds to the JSON property uri
10571 10572 10573 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10571 def uri @uri end |
#username ⇒ String
The user name for HTTP Basic authentication.
Corresponds to the JSON property username
10576 10577 10578 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10576 def username @username end |
#webhook_type ⇒ String
Optional. Type of the webhook.
Corresponds to the JSON property webhookType
10581 10582 10583 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10581 def webhook_type @webhook_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10588 10589 10590 10591 10592 10593 10594 10595 10596 10597 10598 10599 10600 10601 10602 10603 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 10588 def update!(**args) @allowed_ca_certs = args[:allowed_ca_certs] if args.key?(:allowed_ca_certs) @http_method = args[:http_method] if args.key?(:http_method) @oauth_config = args[:oauth_config] if args.key?(:oauth_config) @parameter_mapping = args[:parameter_mapping] if args.key?(:parameter_mapping) @password = args[:password] if args.key?(:password) @request_body = args[:request_body] if args.key?(:request_body) @request_headers = args[:request_headers] if args.key?(:request_headers) @secret_version_for_username_password = args[:secret_version_for_username_password] if args.key?(:secret_version_for_username_password) @secret_versions_for_request_headers = args[:secret_versions_for_request_headers] if args.key?(:secret_versions_for_request_headers) @service_account_auth_config = args[:service_account_auth_config] if args.key?(:service_account_auth_config) @service_agent_auth = args[:service_agent_auth] if args.key?(:service_agent_auth) @uri = args[:uri] if args.key?(:uri) @username = args[:username] if args.key?(:username) @webhook_type = args[:webhook_type] if args.key?(:webhook_type) end |