Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1AdvancedSettings
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1AdvancedSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
Hierarchical advanced settings for agent/flow/page/fulfillment/parameter. Settings exposed at lower level overrides the settings exposed at higher level. Overriding occurs at the sub-setting level. For example, the playback_interruption_settings at fulfillment level only overrides the playback_interruption_settings at the agent level, leaving other settings at the agent level unchanged. DTMF settings does not override each other. DTMF settings set at different levels define DTMF detections running in parallel. Hierarchy: Agent->Flow->Page->Fulfillment/Parameter.
Instance Attribute Summary collapse
-
#audio_export_gcs_destination ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1GcsDestination
Google Cloud Storage location for a Dialogflow operation that writes or exports objects (e.g. exported agent or transcripts) outside of Dialogflow.
-
#dtmf_settings ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1AdvancedSettingsDtmfSettings
Define behaviors for DTMF (dual tone multi frequency).
-
#logging_settings ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1AdvancedSettingsLoggingSettings
Define behaviors on logging.
-
#speech_settings ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1AdvancedSettingsSpeechSettings
Define behaviors of speech to text detection.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3beta1AdvancedSettings
constructor
A new instance of GoogleCloudDialogflowCxV3beta1AdvancedSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3beta1AdvancedSettings
Returns a new instance of GoogleCloudDialogflowCxV3beta1AdvancedSettings.
11063 11064 11065 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 11063 def initialize(**args) update!(**args) end |
Instance Attribute Details
#audio_export_gcs_destination ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1GcsDestination
Google Cloud Storage location for a Dialogflow operation that writes or
exports objects (e.g. exported agent or transcripts) outside of Dialogflow.
Corresponds to the JSON property audioExportGcsDestination
11046 11047 11048 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 11046 def audio_export_gcs_destination @audio_export_gcs_destination end |
#dtmf_settings ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1AdvancedSettingsDtmfSettings
Define behaviors for DTMF (dual tone multi frequency).
Corresponds to the JSON property dtmfSettings
11051 11052 11053 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 11051 def dtmf_settings @dtmf_settings end |
#logging_settings ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1AdvancedSettingsLoggingSettings
Define behaviors on logging.
Corresponds to the JSON property loggingSettings
11056 11057 11058 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 11056 def logging_settings @logging_settings end |
#speech_settings ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1AdvancedSettingsSpeechSettings
Define behaviors of speech to text detection.
Corresponds to the JSON property speechSettings
11061 11062 11063 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 11061 def speech_settings @speech_settings end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11068 11069 11070 11071 11072 11073 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 11068 def update!(**args) @audio_export_gcs_destination = args[:audio_export_gcs_destination] if args.key?(:audio_export_gcs_destination) @dtmf_settings = args[:dtmf_settings] if args.key?(:dtmf_settings) @logging_settings = args[:logging_settings] if args.key?(:logging_settings) @speech_settings = args[:speech_settings] if args.key?(:speech_settings) end |