Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1FormParameter
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1FormParameter
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
Represents a form parameter.
Instance Attribute Summary collapse
-
#advanced_settings ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1AdvancedSettings
Hierarchical advanced settings for agent/flow/page/fulfillment/parameter.
-
#default_value ⇒ Object
The default value of an optional parameter.
-
#display_name ⇒ String
Required.
-
#entity_type ⇒ String
Required.
-
#fill_behavior ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1FormParameterFillBehavior
Configuration for how the filling of a parameter should be handled.
-
#is_list ⇒ Boolean
(also: #is_list?)
Indicates whether the parameter represents a list of values.
-
#redact ⇒ Boolean
(also: #redact?)
Indicates whether the parameter content should be redacted in log.
-
#required ⇒ Boolean
(also: #required?)
Indicates whether the parameter is required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3beta1FormParameter
constructor
A new instance of GoogleCloudDialogflowCxV3beta1FormParameter.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3beta1FormParameter
Returns a new instance of GoogleCloudDialogflowCxV3beta1FormParameter.
12147 12148 12149 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 12147 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advanced_settings ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1AdvancedSettings
Hierarchical advanced settings for agent/flow/page/fulfillment/parameter.
Settings exposed at lower level overrides the settings exposed at higher level.
Overriding occurs at the sub-setting level. For example, the
playback_interruption_settings at fulfillment level only overrides the
playback_interruption_settings at the agent level, leaving other settings at
the agent level unchanged. DTMF settings does not override each other. DTMF
settings set at different levels define DTMF detections running in parallel.
Hierarchy: Agent->Flow->Page->Fulfillment/Parameter.
Corresponds to the JSON property advancedSettings
12098 12099 12100 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 12098 def advanced_settings @advanced_settings end |
#default_value ⇒ Object
The default value of an optional parameter. If the parameter is required, the
default value will be ignored.
Corresponds to the JSON property defaultValue
12104 12105 12106 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 12104 def default_value @default_value end |
#display_name ⇒ String
Required. The human-readable name of the parameter, unique within the form.
Corresponds to the JSON property displayName
12109 12110 12111 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 12109 def display_name @display_name end |
#entity_type ⇒ String
Required. The entity type of the parameter. Format: projects/-/locations/-/
agents/-/entityTypes/ for system entity types (for example, projects/-/
locations/-/agents/-/entityTypes/sys.date), or projects//locations//agents//
entityTypes/ for developer entity types.
Corresponds to the JSON property entityType
12117 12118 12119 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 12117 def entity_type @entity_type end |
#fill_behavior ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1FormParameterFillBehavior
Configuration for how the filling of a parameter should be handled.
Corresponds to the JSON property fillBehavior
12122 12123 12124 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 12122 def fill_behavior @fill_behavior end |
#is_list ⇒ Boolean Also known as: is_list?
Indicates whether the parameter represents a list of values.
Corresponds to the JSON property isList
12127 12128 12129 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 12127 def is_list @is_list end |
#redact ⇒ Boolean Also known as: redact?
Indicates whether the parameter content should be redacted in log. If
redaction is enabled, the parameter content will be replaced by parameter name
during logging. Note: the parameter content is subject to redaction if either
parameter level redaction or entity type level redaction is enabled.
Corresponds to the JSON property redact
12136 12137 12138 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 12136 def redact @redact end |
#required ⇒ Boolean Also known as: required?
Indicates whether the parameter is required. Optional parameters will not
trigger prompts; however, they are filled if the user specifies them. Required
parameters must be filled before form filling concludes.
Corresponds to the JSON property required
12144 12145 12146 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 12144 def required @required end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12152 12153 12154 12155 12156 12157 12158 12159 12160 12161 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 12152 def update!(**args) @advanced_settings = args[:advanced_settings] if args.key?(:advanced_settings) @default_value = args[:default_value] if args.key?(:default_value) @display_name = args[:display_name] if args.key?(:display_name) @entity_type = args[:entity_type] if args.key?(:entity_type) @fill_behavior = args[:fill_behavior] if args.key?(:fill_behavior) @is_list = args[:is_list] if args.key?(:is_list) @redact = args[:redact] if args.key?(:redact) @required = args[:required] if args.key?(:required) end |