Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1ResponseMessagePlayAudio
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1ResponseMessagePlayAudio
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
Specifies an audio clip to be played by the client as part of the response.
Instance Attribute Summary collapse
-
#allow_playback_interruption ⇒ Boolean
(also: #allow_playback_interruption?)
Output only.
-
#audio_uri ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3beta1ResponseMessagePlayAudio
constructor
A new instance of GoogleCloudDialogflowCxV3beta1ResponseMessagePlayAudio.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3beta1ResponseMessagePlayAudio
Returns a new instance of GoogleCloudDialogflowCxV3beta1ResponseMessagePlayAudio.
13710 13711 13712 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13710 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allow_playback_interruption ⇒ Boolean Also known as: allow_playback_interruption?
Output only. Whether the playback of this message can be interrupted by the
end user's speech and the client can then starts the next Dialogflow request.
Corresponds to the JSON property allowPlaybackInterruption
13701 13702 13703 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13701 def allow_playback_interruption @allow_playback_interruption end |
#audio_uri ⇒ String
Required. URI of the audio clip. Dialogflow does not impose any validation on
this value. It is specific to the client that reads it.
Corresponds to the JSON property audioUri
13708 13709 13710 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13708 def audio_uri @audio_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13715 13716 13717 13718 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13715 def update!(**args) @allow_playback_interruption = args[:allow_playback_interruption] if args.key?(:allow_playback_interruption) @audio_uri = args[:audio_uri] if args.key?(:audio_uri) end |