Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1TestCaseResult
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1TestCaseResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
Represents a result from running a test case in an agent environment.
Instance Attribute Summary collapse
-
#conversation_turns ⇒ Array<Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1ConversationTurn>
The conversation turns uttered during the test case replay in chronological order.
-
#environment ⇒ String
Environment where the test was run.
-
#name ⇒ String
The resource name for the test case result.
-
#test_result ⇒ String
Whether the test case passed in the agent environment.
-
#test_time ⇒ String
The time that the test was run.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3beta1TestCaseResult
constructor
A new instance of GoogleCloudDialogflowCxV3beta1TestCaseResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3beta1TestCaseResult
Returns a new instance of GoogleCloudDialogflowCxV3beta1TestCaseResult.
14004 14005 14006 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14004 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conversation_turns ⇒ Array<Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1ConversationTurn>
The conversation turns uttered during the test case replay in chronological
order.
Corresponds to the JSON property conversationTurns
13980 13981 13982 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13980 def conversation_turns @conversation_turns end |
#environment ⇒ String
Environment where the test was run. If not set, it indicates the draft
environment.
Corresponds to the JSON property environment
13986 13987 13988 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13986 def environment @environment end |
#name ⇒ String
The resource name for the test case result. Format: projects//locations//
agents//testCases//results/.
Corresponds to the JSON property name
13992 13993 13994 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13992 def name @name end |
#test_result ⇒ String
Whether the test case passed in the agent environment.
Corresponds to the JSON property testResult
13997 13998 13999 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 13997 def test_result @test_result end |
#test_time ⇒ String
The time that the test was run.
Corresponds to the JSON property testTime
14002 14003 14004 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14002 def test_time @test_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14009 14010 14011 14012 14013 14014 14015 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14009 def update!(**args) @conversation_turns = args[:conversation_turns] if args.key?(:conversation_turns) @environment = args[:environment] if args.key?(:environment) @name = args[:name] if args.key?(:name) @test_result = args[:test_result] if args.key?(:test_result) @test_time = args[:test_time] if args.key?(:test_time) end |