Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1TestError
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowCxV3beta1TestError
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
Error info for running a test.
Instance Attribute Summary collapse
-
#status ⇒ Google::Apis::DialogflowV3::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#test_case ⇒ String
The test case resource name.
-
#test_time ⇒ String
The timestamp when the test was completed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3beta1TestError
constructor
A new instance of GoogleCloudDialogflowCxV3beta1TestError.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowCxV3beta1TestError
Returns a new instance of GoogleCloudDialogflowCxV3beta1TestError.
14079 14080 14081 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14079 def initialize(**args) update!(**args) end |
Instance Attribute Details
#status ⇒ Google::Apis::DialogflowV3::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property status
14067 14068 14069 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14067 def status @status end |
#test_case ⇒ String
The test case resource name.
Corresponds to the JSON property testCase
14072 14073 14074 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14072 def test_case @test_case end |
#test_time ⇒ String
The timestamp when the test was completed.
Corresponds to the JSON property testTime
14077 14078 14079 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14077 def test_time @test_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14084 14085 14086 14087 14088 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14084 def update!(**args) @status = args[:status] if args.key?(:status) @test_case = args[:test_case] if args.key?(:test_case) @test_time = args[:test_time] if args.key?(:test_time) end |