Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowV2AgentCoachingInstruction
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowV2AgentCoachingInstruction
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
Agent Coaching instructions that customer can configure.
Instance Attribute Summary collapse
-
#agent_action ⇒ String
Optional.
-
#condition ⇒ String
Optional.
-
#display_details ⇒ String
Optional.
-
#display_name ⇒ String
Optional.
-
#duplicate_check_result ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowV2AgentCoachingInstructionDuplicateCheckResult
Duplication check for the suggestion.
-
#system_action ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowV2AgentCoachingInstruction
constructor
A new instance of GoogleCloudDialogflowV2AgentCoachingInstruction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowV2AgentCoachingInstruction
Returns a new instance of GoogleCloudDialogflowV2AgentCoachingInstruction.
15026 15027 15028 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 15026 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_action ⇒ String
Optional. The action that human agent should take. For example, "apologize for
the slow shipping". If the users only want to use agent coaching for intent
detection, agent_action can be empty
Corresponds to the JSON property agentAction
14995 14996 14997 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 14995 def agent_action @agent_action end |
#condition ⇒ String
Optional. The condition of the instruction. For example, "the customer wants
to cancel an order". If the users want the instruction to be triggered
unconditionally, the condition can be empty.
Corresponds to the JSON property condition
15002 15003 15004 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 15002 def condition @condition end |
#display_details ⇒ String
Optional. The detailed description of this instruction.
Corresponds to the JSON property displayDetails
15007 15008 15009 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 15007 def display_details @display_details end |
#display_name ⇒ String
Optional. Display name for the instruction.
Corresponds to the JSON property displayName
15012 15013 15014 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 15012 def display_name @display_name end |
#duplicate_check_result ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowV2AgentCoachingInstructionDuplicateCheckResult
Duplication check for the suggestion.
Corresponds to the JSON property duplicateCheckResult
15017 15018 15019 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 15017 def duplicate_check_result @duplicate_check_result end |
#system_action ⇒ String
Optional. The action that system should take. For example, "call GetOrderTime
with order_number=order number provided by the customer". If the users don't
have plugins or don't want to trigger plugins, the system_action can be empty
Corresponds to the JSON property systemAction
15024 15025 15026 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 15024 def system_action @system_action end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15031 15032 15033 15034 15035 15036 15037 15038 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 15031 def update!(**args) @agent_action = args[:agent_action] if args.key?(:agent_action) @condition = args[:condition] if args.key?(:condition) @display_details = args[:display_details] if args.key?(:display_details) @display_name = args[:display_name] if args.key?(:display_name) @duplicate_check_result = args[:duplicate_check_result] if args.key?(:duplicate_check_result) @system_action = args[:system_action] if args.key?(:system_action) end |