Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowV2AgentCoachingSuggestionDuplicateCheckResultDuplicateSuggestion
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowV2AgentCoachingSuggestionDuplicateCheckResultDuplicateSuggestion
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
The duplicate suggestion details. Keeping answer_record and sources together as they are identifiers for duplicate suggestions.
Instance Attribute Summary collapse
-
#answer_record ⇒ String
Output only.
-
#similarity_score ⇒ Float
Output only.
-
#sources ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowV2AgentCoachingSuggestionSources
Sources for the suggestion.
-
#suggestion_index ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowV2AgentCoachingSuggestionDuplicateCheckResultDuplicateSuggestion
constructor
A new instance of GoogleCloudDialogflowV2AgentCoachingSuggestionDuplicateCheckResultDuplicateSuggestion.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowV2AgentCoachingSuggestionDuplicateCheckResultDuplicateSuggestion
Returns a new instance of GoogleCloudDialogflowV2AgentCoachingSuggestionDuplicateCheckResultDuplicateSuggestion.
15197 15198 15199 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 15197 def initialize(**args) update!(**args) end |
Instance Attribute Details
#answer_record ⇒ String
Output only. The answer record id of the past duplicate suggestion.
Corresponds to the JSON property answerRecord
15180 15181 15182 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 15180 def answer_record @answer_record end |
#similarity_score ⇒ Float
Output only. The similarity score of between the past and current suggestion.
Corresponds to the JSON property similarityScore
15185 15186 15187 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 15185 def similarity_score @similarity_score end |
#sources ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowV2AgentCoachingSuggestionSources
Sources for the suggestion.
Corresponds to the JSON property sources
15190 15191 15192 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 15190 def sources @sources end |
#suggestion_index ⇒ Fixnum
Output only. The index of the duplicate suggestion in the past suggestion list.
Corresponds to the JSON property suggestionIndex
15195 15196 15197 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 15195 def suggestion_index @suggestion_index end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15202 15203 15204 15205 15206 15207 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 15202 def update!(**args) @answer_record = args[:answer_record] if args.key?(:answer_record) @similarity_score = args[:similarity_score] if args.key?(:similarity_score) @sources = args[:sources] if args.key?(:sources) @suggestion_index = args[:suggestion_index] if args.key?(:suggestion_index) end |