Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowV2EntityType
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowV2EntityType
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
Each intent parameter has a type, called the entity type, which dictates exactly how data from an end-user expression is extracted. Dialogflow provides predefined system entities that can match many common types of data. For example, there are system entities for matching dates, times, colors, email addresses, and so on. You can also create your own custom entities for matching custom data. For example, you could define a vegetable entity that can match the types of vegetables available for purchase with a grocery store agent. For more information, see the Entity guide.
Instance Attribute Summary collapse
-
#auto_expansion_mode ⇒ String
Optional.
-
#display_name ⇒ String
Required.
-
#enable_fuzzy_extraction ⇒ Boolean
(also: #enable_fuzzy_extraction?)
Optional.
-
#entities ⇒ Array<Google::Apis::DialogflowV3::GoogleCloudDialogflowV2EntityTypeEntity>
Optional.
-
#kind ⇒ String
Required.
-
#name ⇒ String
The unique identifier of the entity type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowV2EntityType
constructor
A new instance of GoogleCloudDialogflowV2EntityType.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowV2EntityType
Returns a new instance of GoogleCloudDialogflowV2EntityType.
15918 15919 15920 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 15918 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_expansion_mode ⇒ String
Optional. Indicates whether the entity type can be automatically expanded.
Corresponds to the JSON property autoExpansionMode
15888 15889 15890 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 15888 def auto_expansion_mode @auto_expansion_mode end |
#display_name ⇒ String
Required. The name of the entity type.
Corresponds to the JSON property displayName
15893 15894 15895 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 15893 def display_name @display_name end |
#enable_fuzzy_extraction ⇒ Boolean Also known as: enable_fuzzy_extraction?
Optional. Enables fuzzy entity extraction during classification.
Corresponds to the JSON property enableFuzzyExtraction
15898 15899 15900 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 15898 def enable_fuzzy_extraction @enable_fuzzy_extraction end |
#entities ⇒ Array<Google::Apis::DialogflowV3::GoogleCloudDialogflowV2EntityTypeEntity>
Optional. The collection of entity entries associated with the entity type.
Corresponds to the JSON property entities
15904 15905 15906 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 15904 def entities @entities end |
#kind ⇒ String
Required. Indicates the kind of entity type.
Corresponds to the JSON property kind
15909 15910 15911 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 15909 def kind @kind end |
#name ⇒ String
The unique identifier of the entity type. Required for EntityTypes.
UpdateEntityType and EntityTypes.BatchUpdateEntityTypes methods. Format:
projects//agent/entityTypes/.
Corresponds to the JSON property name
15916 15917 15918 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 15916 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15923 15924 15925 15926 15927 15928 15929 15930 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 15923 def update!(**args) @auto_expansion_mode = args[:auto_expansion_mode] if args.key?(:auto_expansion_mode) @display_name = args[:display_name] if args.key?(:display_name) @enable_fuzzy_extraction = args[:enable_fuzzy_extraction] if args.key?(:enable_fuzzy_extraction) @entities = args[:entities] if args.key?(:entities) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) end |