Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowV2IntentMessage
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowV2IntentMessage
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
A rich response message. Corresponds to the intent Response field in the
Dialogflow console. For more information, see Rich response messages.
Instance Attribute Summary collapse
-
#basic_card ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowV2IntentMessageBasicCard
The basic card message.
-
#browse_carousel_card ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowV2IntentMessageBrowseCarouselCard
Browse Carousel Card for Actions on Google.
-
#card ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowV2IntentMessageCard
The card response message.
-
#carousel_select ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowV2IntentMessageCarouselSelect
The card for presenting a carousel of options to select from.
-
#image ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowV2IntentMessageImage
The image response message.
-
#link_out_suggestion ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowV2IntentMessageLinkOutSuggestion
The suggestion chip message that allows the user to jump out to the app or website associated with this agent.
-
#list_select ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowV2IntentMessageListSelect
The card for presenting a list of options to select from.
-
#media_content ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowV2IntentMessageMediaContent
The media content card for Actions on Google.
-
#payload ⇒ Hash<String,Object>
A custom platform-specific response.
-
#platform ⇒ String
Optional.
-
#quick_replies ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowV2IntentMessageQuickReplies
The quick replies response message.
-
#simple_responses ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowV2IntentMessageSimpleResponses
The collection of simple response candidates.
-
#suggestions ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowV2IntentMessageSuggestions
The collection of suggestions.
-
#table_card ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowV2IntentMessageTableCard
Table card for Actions on Google.
-
#text ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowV2IntentMessageText
The text response message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowV2IntentMessage
constructor
A new instance of GoogleCloudDialogflowV2IntentMessage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowV2IntentMessage
Returns a new instance of GoogleCloudDialogflowV2IntentMessage.
16735 16736 16737 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 16735 def initialize(**args) update!(**args) end |
Instance Attribute Details
#basic_card ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowV2IntentMessageBasicCard
The basic card message. Useful for displaying information.
Corresponds to the JSON property basicCard
16659 16660 16661 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 16659 def basic_card @basic_card end |
#browse_carousel_card ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowV2IntentMessageBrowseCarouselCard
Browse Carousel Card for Actions on Google. https://developers.google.com/
actions/assistant/responses#browsing_carousel
Corresponds to the JSON property browseCarouselCard
16665 16666 16667 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 16665 def browse_carousel_card @browse_carousel_card end |
#card ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowV2IntentMessageCard
The card response message.
Corresponds to the JSON property card
16670 16671 16672 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 16670 def card @card end |
#carousel_select ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowV2IntentMessageCarouselSelect
The card for presenting a carousel of options to select from.
Corresponds to the JSON property carouselSelect
16675 16676 16677 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 16675 def carousel_select @carousel_select end |
#image ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowV2IntentMessageImage
The image response message.
Corresponds to the JSON property image
16680 16681 16682 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 16680 def image @image end |
#link_out_suggestion ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowV2IntentMessageLinkOutSuggestion
The suggestion chip message that allows the user to jump out to the app or
website associated with this agent.
Corresponds to the JSON property linkOutSuggestion
16686 16687 16688 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 16686 def link_out_suggestion @link_out_suggestion end |
#list_select ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowV2IntentMessageListSelect
The card for presenting a list of options to select from.
Corresponds to the JSON property listSelect
16691 16692 16693 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 16691 def list_select @list_select end |
#media_content ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowV2IntentMessageMediaContent
The media content card for Actions on Google.
Corresponds to the JSON property mediaContent
16696 16697 16698 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 16696 def media_content @media_content end |
#payload ⇒ Hash<String,Object>
A custom platform-specific response.
Corresponds to the JSON property payload
16701 16702 16703 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 16701 def payload @payload end |
#platform ⇒ String
Optional. The platform that this message is intended for.
Corresponds to the JSON property platform
16706 16707 16708 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 16706 def platform @platform end |
#quick_replies ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowV2IntentMessageQuickReplies
The quick replies response message.
Corresponds to the JSON property quickReplies
16711 16712 16713 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 16711 def quick_replies @quick_replies end |
#simple_responses ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowV2IntentMessageSimpleResponses
The collection of simple response candidates. This message in QueryResult.
fulfillment_messages and WebhookResponse.fulfillment_messages should
contain only one SimpleResponse.
Corresponds to the JSON property simpleResponses
16718 16719 16720 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 16718 def simple_responses @simple_responses end |
#suggestions ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowV2IntentMessageSuggestions
The collection of suggestions.
Corresponds to the JSON property suggestions
16723 16724 16725 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 16723 def suggestions @suggestions end |
#table_card ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowV2IntentMessageTableCard
Table card for Actions on Google.
Corresponds to the JSON property tableCard
16728 16729 16730 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 16728 def table_card @table_card end |
#text ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowV2IntentMessageText
The text response message.
Corresponds to the JSON property text
16733 16734 16735 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 16733 def text @text end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16740 16741 16742 16743 16744 16745 16746 16747 16748 16749 16750 16751 16752 16753 16754 16755 16756 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 16740 def update!(**args) @basic_card = args[:basic_card] if args.key?(:basic_card) @browse_carousel_card = args[:browse_carousel_card] if args.key?(:browse_carousel_card) @card = args[:card] if args.key?(:card) @carousel_select = args[:carousel_select] if args.key?(:carousel_select) @image = args[:image] if args.key?(:image) @link_out_suggestion = args[:link_out_suggestion] if args.key?(:link_out_suggestion) @list_select = args[:list_select] if args.key?(:list_select) @media_content = args[:media_content] if args.key?(:media_content) @payload = args[:payload] if args.key?(:payload) @platform = args[:platform] if args.key?(:platform) @quick_replies = args[:quick_replies] if args.key?(:quick_replies) @simple_responses = args[:simple_responses] if args.key?(:simple_responses) @suggestions = args[:suggestions] if args.key?(:suggestions) @table_card = args[:table_card] if args.key?(:table_card) @text = args[:text] if args.key?(:text) end |