Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowV2SpeechWordInfo
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowV2SpeechWordInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
Information for a word recognized by the speech recognizer.
Instance Attribute Summary collapse
-
#confidence ⇒ Float
The Speech confidence between 0.0 and 1.0 for this word.
-
#end_offset ⇒ String
Time offset relative to the beginning of the audio that corresponds to the end of the spoken word.
-
#start_offset ⇒ String
Time offset relative to the beginning of the audio that corresponds to the start of the spoken word.
-
#word ⇒ String
The word this info is for.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowV2SpeechWordInfo
constructor
A new instance of GoogleCloudDialogflowV2SpeechWordInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowV2SpeechWordInfo
Returns a new instance of GoogleCloudDialogflowV2SpeechWordInfo.
18424 18425 18426 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 18424 def initialize(**args) update!(**args) end |
Instance Attribute Details
#confidence ⇒ Float
The Speech confidence between 0.0 and 1.0 for this word. A higher number
indicates an estimated greater likelihood that the recognized word is correct.
The default of 0.0 is a sentinel value indicating that confidence was not set.
This field is not guaranteed to be fully stable over time for the same audio
input. Users should also not rely on it to always be provided.
Corresponds to the JSON property confidence
18403 18404 18405 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 18403 def confidence @confidence end |
#end_offset ⇒ String
Time offset relative to the beginning of the audio that corresponds to the end
of the spoken word. This is an experimental feature and the accuracy of the
time offset can vary.
Corresponds to the JSON property endOffset
18410 18411 18412 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 18410 def end_offset @end_offset end |
#start_offset ⇒ String
Time offset relative to the beginning of the audio that corresponds to the
start of the spoken word. This is an experimental feature and the accuracy of
the time offset can vary.
Corresponds to the JSON property startOffset
18417 18418 18419 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 18417 def start_offset @start_offset end |
#word ⇒ String
The word this info is for.
Corresponds to the JSON property word
18422 18423 18424 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 18422 def word @word end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18429 18430 18431 18432 18433 18434 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 18429 def update!(**args) @confidence = args[:confidence] if args.key?(:confidence) @end_offset = args[:end_offset] if args.key?(:end_offset) @start_offset = args[:start_offset] if args.key?(:start_offset) @word = args[:word] if args.key?(:word) end |