Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1AgentCoachingSuggestionDuplicateCheckResultDuplicateSuggestion
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1AgentCoachingSuggestionDuplicateCheckResultDuplicateSuggestion
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
The duplicate suggestion details. Keeping answer_record and sources together as they are identifiers for duplicate suggestions.
Instance Attribute Summary collapse
-
#answer_record ⇒ String
Output only.
-
#similarity_score ⇒ Float
Output only.
-
#sources ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1AgentCoachingSuggestionSources
Sources for the suggestion.
-
#suggestion_index ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowV2beta1AgentCoachingSuggestionDuplicateCheckResultDuplicateSuggestion
constructor
A new instance of GoogleCloudDialogflowV2beta1AgentCoachingSuggestionDuplicateCheckResultDuplicateSuggestion.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowV2beta1AgentCoachingSuggestionDuplicateCheckResultDuplicateSuggestion
Returns a new instance of GoogleCloudDialogflowV2beta1AgentCoachingSuggestionDuplicateCheckResultDuplicateSuggestion.
19274 19275 19276 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 19274 def initialize(**args) update!(**args) end |
Instance Attribute Details
#answer_record ⇒ String
Output only. The answer record id of the past duplicate suggestion.
Corresponds to the JSON property answerRecord
19257 19258 19259 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 19257 def answer_record @answer_record end |
#similarity_score ⇒ Float
Output only. The similarity score of between the past and current suggestion.
Corresponds to the JSON property similarityScore
19262 19263 19264 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 19262 def similarity_score @similarity_score end |
#sources ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1AgentCoachingSuggestionSources
Sources for the suggestion.
Corresponds to the JSON property sources
19267 19268 19269 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 19267 def sources @sources end |
#suggestion_index ⇒ Fixnum
Output only. The index of the duplicate suggestion in the past suggestion list.
Corresponds to the JSON property suggestionIndex
19272 19273 19274 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 19272 def suggestion_index @suggestion_index end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19279 19280 19281 19282 19283 19284 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 19279 def update!(**args) @answer_record = args[:answer_record] if args.key?(:answer_record) @similarity_score = args[:similarity_score] if args.key?(:similarity_score) @sources = args[:sources] if args.key?(:sources) @suggestion_index = args[:suggestion_index] if args.key?(:suggestion_index) end |