Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1SmartReplyAnswer
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1SmartReplyAnswer
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
Represents a smart reply answer.
Instance Attribute Summary collapse
-
#answer_record ⇒ String
The name of answer record, in the format of "projects//locations// answerRecords/" Corresponds to the JSON property
answerRecord. -
#confidence ⇒ Float
Smart reply confidence.
-
#reply ⇒ String
The content of the reply.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowV2beta1SmartReplyAnswer
constructor
A new instance of GoogleCloudDialogflowV2beta1SmartReplyAnswer.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowV2beta1SmartReplyAnswer
Returns a new instance of GoogleCloudDialogflowV2beta1SmartReplyAnswer.
22904 22905 22906 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 22904 def initialize(**args) update!(**args) end |
Instance Attribute Details
#answer_record ⇒ String
The name of answer record, in the format of "projects//locations//
answerRecords/"
Corresponds to the JSON property answerRecord
22890 22891 22892 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 22890 def answer_record @answer_record end |
#confidence ⇒ Float
Smart reply confidence. The system's confidence score that this reply is a
good match for this conversation, as a value from 0.0 (completely uncertain)
to 1.0 (completely certain).
Corresponds to the JSON property confidence
22897 22898 22899 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 22897 def confidence @confidence end |
#reply ⇒ String
The content of the reply.
Corresponds to the JSON property reply
22902 22903 22904 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 22902 def reply @reply end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22909 22910 22911 22912 22913 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 22909 def update!(**args) @answer_record = args[:answer_record] if args.key?(:answer_record) @confidence = args[:confidence] if args.key?(:confidence) @reply = args[:reply] if args.key?(:reply) end |