Class: Google::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1ToolCallResult
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1ToolCallResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v3/classes.rb,
lib/google/apis/dialogflow_v3/representations.rb,
lib/google/apis/dialogflow_v3/representations.rb
Overview
The result of calling a tool's action.
Instance Attribute Summary collapse
-
#action ⇒ String
Optional.
-
#answer_record ⇒ String
Optional.
-
#content ⇒ String
Only populated if the response content is utf-8 encoded.
-
#create_time ⇒ String
Output only.
-
#error ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1ToolCallResultError
An error produced by the tool call.
-
#raw_content ⇒ String
Only populated if the response content is not utf-8 encoded.
-
#tool ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowV2beta1ToolCallResult
constructor
A new instance of GoogleCloudDialogflowV2beta1ToolCallResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowV2beta1ToolCallResult
Returns a new instance of GoogleCloudDialogflowV2beta1ToolCallResult.
23477 23478 23479 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 23477 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action ⇒ String
Optional. The name of the tool's action associated with this call.
Corresponds to the JSON property action
23442 23443 23444 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 23442 def action @action end |
#answer_record ⇒ String
Optional. The answer record associated with this tool call result.
Corresponds to the JSON property answerRecord
23447 23448 23449 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 23447 def answer_record @answer_record end |
#content ⇒ String
Only populated if the response content is utf-8 encoded.
Corresponds to the JSON property content
23452 23453 23454 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 23452 def content @content end |
#create_time ⇒ String
Output only. Create time of the tool call result.
Corresponds to the JSON property createTime
23457 23458 23459 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 23457 def create_time @create_time end |
#error ⇒ Google::Apis::DialogflowV3::GoogleCloudDialogflowV2beta1ToolCallResultError
An error produced by the tool call.
Corresponds to the JSON property error
23462 23463 23464 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 23462 def error @error end |
#raw_content ⇒ String
Only populated if the response content is not utf-8 encoded. (by definition
byte fields are base64 encoded).
Corresponds to the JSON property rawContent
NOTE: Values are automatically base64 encoded/decoded in the client library.
23469 23470 23471 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 23469 def raw_content @raw_content end |
#tool ⇒ String
Optional. The tool associated with this call. Format: projects//locations//
tools/.
Corresponds to the JSON property tool
23475 23476 23477 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 23475 def tool @tool end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23482 23483 23484 23485 23486 23487 23488 23489 23490 |
# File 'lib/google/apis/dialogflow_v3/classes.rb', line 23482 def update!(**args) @action = args[:action] if args.key?(:action) @answer_record = args[:answer_record] if args.key?(:answer_record) @content = args[:content] if args.key?(:content) @create_time = args[:create_time] if args.key?(:create_time) @error = args[:error] if args.key?(:error) @raw_content = args[:raw_content] if args.key?(:raw_content) @tool = args[:tool] if args.key?(:tool) end |